library('ncdf4')
library('cmaqtools')
library('ctmeval')

source('./handy_functions.R')
source('./list_stations.R')

## save(list = ls(all=TRUE), file = "inData_SIM_OBS_seaSaltScens.RData")
## load("inData_SIM_OBS_seaSaltScens.RData")

# Create plots for Daniel's publication I.
read.stats = FALSE
read.obs = FALSE
work.obs = FALSE
read.sim = FALSE
work.sim = FALSE
plot.dat.A = FALSE
plot.dat.B = FALSE
plot.dat.C = FALSE
plot.dat.D = FALSE
plot.dat.E = TRUE
plot.dat.F = TRUE
doStatistics = FALSE
write.dat = FALSE
writeOutData = FALSE

GRID_NAME = 'CD24'
myGrid = griddesc(GRID_NAME)

myAero = 'aero5'
# myAero = 'aero6'

# mech = 'yamo_cb05tump_ae6_aq'
# mech = 'cb05tump_ae6_aq_ssa'
mech = 'cb05tucl_ae5_aq_ssa'
# mech = 'cb05cl_ae5_aq'

# setup = 'sulfScen'
setup='effectSeaSalt.v5'

strYear='2008'
# strYear='2013'


# functions and constant ----
make_daily_mean <- function(series) {
  dim_old = dim(series)
  
  if (length(dim_old) <= 1) {
    n_old = length(series)
    n_new = n_old/24
    
    means = rep(0.0, n_new)
    
    for(i1 in 1:n_new) {
      means[i1] = mean(series[(1:24)+(i1-1)*24])
    }
  } else if (length(dim_old) == 2) {
    n_old = dim_old[2]
    n_new = n_old/24
    dim_new = c(dim_old[1], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,i1] = rowMeans(series[,(1:24)+(i1-1)*24], dims = 1)
    }
  } else if (length(dim_old) == 3) {
    n_old = dim_old[3]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,i1] = rowMeans(series[,,(1:24)+(i1-1)*24], dims = 2)
    }
  } else if (length(dim_old) == 4) {
    n_old = dim_old[4]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], dim_old[3], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,,i1] = rowMeans(series[,,,(1:24)+(i1-1)*24], dims = 3)
    }
  }
  
  return(means)
}


getYlim <- function(yMax, type) {
  if ( yMax == 0 ) {
    yLim = 1
  } else if ( type == 1 ) {
    yLim = ceiling(yMax/10^(floor(log10(yMax))-1))*10^(floor(log10(yMax))-1)
  } else if ( type == 2 ) {
    yLim = signif(yMax, digits = 1) * 2
  } else if ( type == 3 ) {
    yLim = signif(yMax, digits = 1)
    if(yLim < yMax) {
      yLim = signif(2*yMax-yLim, digits = 2)
    }
  } else {
    yLim = 1
  }
  
  return(yLim)
}


myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63, 'HONO' = 45,
                 'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62,
                 'NO3' = 62, 'PNA' = 79, 'PAN' = 121,
                 'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                 'N' = 15, 'N2O5' = 108,
                 'ASO4I' = 96, 'ASO4J' = 96, 'ASO4K' = 96, 'SO2' = 64, 'S' = 32)

R = 8.314462

if(myAero == 'aero6') {
  ssSO4Mass = 0.0776; ssClMass = 0.5538
  ssNaMass = 0.3086; ssMgMass = 0.0368; ssKMass = 0.0114; ssCaMass = 0.0118
  ssSeaCatMass = 0.3086+0.0368+0.0114+0.0118
  ssRealNa2Cat = 1.0
} else if (myAero == 'aero5') {
  ssSO4Mass = 0.0755; ssClMass = 0.5389
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
}

# set some parameters ----
DBaccess <- list(name="neumannd-pg-emep_v02.1",uid="neumannd",pwd="nd$1,")
inDir = '/storage/neumannd/data/cctm/CD24/analysis'

# MONs = c('win2008')
if (strYear == '2013') MONs = c('win2013', 'sum2013') else if(strYear == '2008') MONs = c('win2008', 'sum2008') else MONs = c('win', 'sum')

SPECs = c('SO4', 'Na', 'XSO4', 'SNH4', 'SNO3', 'NH4', 'NO3', 'SO2')
allSPECs = c('SO4', 'Na', 'XSO4', 'SNH4', 'SNO3', 'NH4', 'NO3', 'SO2', 'NH3', 'HNO3', 'SOX')
MATRICEs = list('SNH4'=c('air+aerosol'), 'SNO3'=c('air+aerosol'), 
                'SO4'=c('pm10', 'pm25', 'aerosol'), 'XSO4'=c('aerosol'), 
                'Na'=c('pm10', 'pm25', 'aerosol'), 
                'NH4'=c('pm10', 'pm25', 'aerosol'), 'NO3'=c('pm10', 'pm25', 'aerosol'),
                'SO2' = c('air'), 'NH3' = c('air'), 'HNO3' = c('air'),
                'SOX' = c('pm10'))
allMATRICEs = list('SNH4'=c('pm10'), 'SNO3'=c('pm10'), 
                   'SO4'=c('pm10', 'pm25'), 'XSO4'=c('pm10', 'pm25'), 
                   'Na'=c('pm10', 'pm25'), 
                   'NH4'=c('pm10', 'pm25'), 'NO3'=c('pm10', 'pm25'),
                   'SO2' = c('air'), 'NH3' = c('air'), 'HNO3' = c('air'),
                   'SOX' = c('pm10'))
exprMatrix = list('pm10' = expression('PM'[10]),
                  'pm25' = expression('PM'[2.5]),
                  'air' = expression('air + PM'[10]))
UNITS = list('SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3', 'NH4'='ug N/m3', 'NO3'='ug N/m3', 'SO4'='ug S/m3')

# SCENs = c('ALLsurf', 'NOSHIPSsurf', 'NOSALT', 'NOENERGY', 'SALT_OV14')
SCENs = c('base', 'sp13.corr', 'ov14.corr', 'zero')

myStations = c("DE0001R", "DE0002R", "DE0007R", "DE0009R", "DE0044R", "DK0003R", "DK0005R", "DK0008R", "DK0012R", "DK0031R", "FI0009R", "FI0017R", "LT0015R", "NL0091R", "NO0001R", "NO0002R", "NO0015R", "NO0039R", "NO0056R", "PL0002R", "PL0004R", "PL0005R", "SE0005R", "SE0011R", "SE0012R", "SE0014R")
nSTATIONS=length(myStations)
stationNames = list("DE0001R" = 'Westerland', "DE0002R" = "Waldhof", "DE0007R" = "Neuglobsow", "DE0009R" = 'Zingst', 
                    "DE0044R" = "Melpitz", "DK0003R" = "Tange", "DK0008R" = "Anholt", "DK0012R" = "Risoe", 
                    "DK0031R" = "Ulborg", "FI0009R" = "Uto", "FI0017R" = "Virolahti II", "LT0015R" = "Preila", 
                    "NL0091R" = "De Zilk", "NO0001R" = "Birkenes", "NO0002R" = "Birkenes II", "NO0015R" = "Tustervatn", 
                    "NO0039R" = "Karvatn", "NO0056R" = "Hurdal", "PL0002R" = "Jarczew", "PL0004R" = "Leba", 
                    "PL0005R" = "Diabla Gora", "SE0005R" = "Bredkalen", "SE0011R" = "Vavihill", 
                    "SE0012R" = "Aspvreten", "SE0014R" = "Rao")

# read station data ----
if (read.stats) {
  
  # get station data from the database
  myCon <- odbcConnect(dsn="neumannd-pg-emep_v02.1", uid="neumannd", pwd="nd$1,")
  stationInfo <- sqlQuery(myCon, paste("SELECT * FROM stations WHERE station_id IN ('", paste(myStations, collapse = "','"), "');", sep = ''))
  
  close(myCon)
  
  # write out coordiates and grid cells
  myPositions = list()
  myCells = list()
  
  for(iStat in myStations) {
    iPos = which(stationInfo$station_id == iStat)
    myPositions[[iStat]] = list('lat' = stationInfo$latitude[iPos],
                                'lon' = stationInfo$longitude[iPos])

    myCells[[iStat]] = findcell(myPositions[[iStat]], myGrid)
  }
  
}


# read observational data ----
if (read.obs) {
  
  rawOBS = list()
  for(iMon in MONs) { rawOBS[[iMon]] = list(); for(iSpec in SPECs) { rawOBS[[iMon]][[iSpec]] = list() } }
  
  for(iMon in MONs) {
    if(iMon == 'sum2008' || iMon == 'sum') {
      from = 2008183; to = 2008243; nT = 61
    } else if(iMon == 'win2008' || iMon == 'win') {
      from = 2008001; to = 2008060; nT = 60
    }
    nTh = nT * 24
  
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING OBSERVATIONAL DATA FROM DATABASE')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    for (iSpec in SPECs) {
      for (iMtrx in MATRICEs[[iSpec]]) {
        rawOBS[[iMon]][[iSpec]][[iMtrx]] <- getobservationts(from,to,iSpec, stations = myStations, matrix=iMtrx, vlevel = gsub('or', 'and', gsub(', 781,', ',', vlevel(1))))
      }      
    }
  }
}
 

# rework obs data ----
if(work.obs) {
  valOBS = list()
  for(iMon in MONs) { valOBS[[iMon]] = list(); for(iSpec in c(SPECs, 'SOX')) { valOBS[[iMon]][[iSpec]] = list() } }
  
  for(iMon in MONs) {
    for (iSpec in c('SO4', 'Na', 'XSO4', 'NH4', 'NO3')) {
      valOBS[[iMon]][[iSpec]]$pm10 = rawOBS[[iMon]][[iSpec]]$aerosol
      if ( !is.null(rawOBS[[iMon]][[iSpec]]$pm10) ) {
        if (is.null(rawOBS[[iMon]][[iSpec]]$pm10$station) ) {
          for(iStat in names(rawOBS[[iMon]][[iSpec]]$pm10)) {valOBS[[iMon]][[iSpec]]$pm10[[iStat]] = rawOBS[[iMon]][[iSpec]]$pm10[[iStat]]}
        } else {
          valOBS[[iMon]][[iSpec]]$pm10[[as.character(rawOBS[[iMon]][[iSpec]]$pm10$station$station_id)]] = rawOBS[[iMon]][[iSpec]]$pm10
        }
      }
      
      if (!is.null(rawOBS[[iMon]][[iSpec]]$pm25)) {
        if (is.null(rawOBS[[iMon]][[iSpec]]$pm25$station)) {
          valOBS[[iMon]][[iSpec]]$pm25 = rawOBS[[iMon]][[iSpec]]$pm25
        } else {
          valOBS[[iMon]][[iSpec]]$pm25 = list()
          valOBS[[iMon]][[iSpec]]$pm25[[as.character(rawOBS[[iMon]][[iSpec]]$pm25$station$station_id)]] = rawOBS[[iMon]][[iSpec]]$pm25
        }
      }
    }
    
    for (iSpec in c('SNH4', 'SNO3')) {
      valOBS[[iMon]][[iSpec]]$pm10 = rawOBS[[iMon]][[iSpec]][['air+aerosol']]
    }
    
    for (iSpec in c('SO2', 'NH3', 'HNO3')) {
      valOBS[[iMon]][[iSpec]]$air = rawOBS[[iMon]][[iSpec]]$air
    }
    
    valOBS[[iMon]]$SOX$pm10 = valOBS[[iMon]]$SO4$pm10
    for (iStat in names(valOBS[[iMon]]$SOX$pm10)) {
      if ( is.null(valOBS[[iMon]]$SO2$air[[iStat]]) ) {
        valOBS[[iMon]]$SOX$pm10[[iStat]] = NULL
      } else {
        valOBS[[iMon]]$SOX$pm10[[iStat]]$timeser$values = valOBS[[iMon]]$SOX$pm10[[iStat]]$timeser$values + valOBS[[iMon]]$SO2$air[[iStat]]$timeser$values
        valOBS[[iMon]]$SOX$pm10[[iStat]]$substance = 'SOX'
      }
    }
    
  }
}


# read model data ----
if(read.sim) {
  
  rawSIM = list()
  for(iMon in MONs) { rawSIM[[iMon]] = list()
    for(iScen in SCENs) { rawSIM[[iMon]][[iScen]] = list()
      for(iSpec in allSPECs) { rawSIM[[iMon]][[iScen]][[iSpec]] = list() }
    }
  }
  
  for(iMon in MONs) {
    if(iMon == 'sum2008' || iMon == 'sum') {
      from = 2008183; to = 2008243; nT = 61
    } else if(iMon == 'win2008' || iMon == 'win') {
      from = 2008001; to = 2008060; nT = 60
    }
    nTh = nT * 24
    
    
    #' METEO FILE +++++++++++++++++++++++++++++++++++++++++++
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('  READING MET FILE')
    ncMet <- nc_open(paste(inDir, paste('METCRO3D', iMon, 'short', sep = '.'), sep = '/'))
    
    nTSTEP = ncMet$dim$TSTEP$len
    nCOL = ncMet$dim$COL$len
    nROW = ncMet$dim$ROW$len
    
    valPRES = matrix(ncvar_get(ncMet, 'PRES')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    valTA   = matrix(ncvar_get(ncMet, 'TA')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    
    nc_close(ncMet)
    
    
    #' AEROSOL FILE +++++++++++++++++++++++++++++++++++++++++++
    print('  READING AERO FILE')
    inAero = paste('BL_AERODIAM', paste(GRID_NAME, paste(setup, iScen, sep = '.'), mech, iMon, sep = '_'), 'short', sep = '.')
    ncAero = nc_open(paste(inDir, inAero, sep = '/'))
    
    valPM25AT = matrix(ncvar_get(ncAero, 'PM25AT')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    valPM25AC = matrix(ncvar_get(ncAero, 'PM25AC')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    valPM25CO = matrix(ncvar_get(ncAero, 'PM25CO')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    
    nc_close(ncAero)
    
    
    #' CONCENTRATION FILE +++++++++++++++++++++++++++++++++++++++++++
    myStart = c(1,1,1,1)
    myCount = c(-1,-1,-1,nTSTEP)
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      inConc = paste('BL_CONC', paste(GRID_NAME, paste(setup, iScen, sep = '.'), mech, iMon, sep = '_'), 'short', sep = '.')
      ncId = nc_open(paste(inDir, inConc, sep = '/'))
      
      print('    Reading SNH4')
      tmpNH3 = matrix(ncvar_get(ncId, 'NH3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) * valPRES / valTA / R * myMolMass$N
      tmpNH4I = matrix(ncvar_get(ncId, 'ANH4I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4I * myMolMass$N
      tmpNH4J = matrix(ncvar_get(ncId, 'ANH4J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4J * myMolMass$N
      tmpNH4K = matrix(ncvar_get(ncId, 'ANH4K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4K * myMolMass$N
      
      rawSIM[[iMon]][[iScen]]$NH3$air = tmpNH3
      rawSIM[[iMon]][[iScen]]$NH4$pm25 = valPM25AT * tmpNH4I + valPM25AC * tmpNH4J + valPM25CO * tmpNH4K
      rawSIM[[iMon]][[iScen]]$NH4$pm10 = tmpNH4I + tmpNH4J + tmpNH4K
      rawSIM[[iMon]][[iScen]]$SNH4$pm10 = tmpNH3 + tmpNH4I + tmpNH4J + tmpNH4K 
      
      print('    Reading SNO3')
      tmpHNO3 = matrix(ncvar_get(ncId, 'HNO3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) * valPRES / valTA / R * myMolMass$N
      tmpNO3I = matrix(ncvar_get(ncId, 'ANO3I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3I * myMolMass$N
      tmpNO3J = matrix(ncvar_get(ncId, 'ANO3J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3J * myMolMass$N
      tmpNO3K = matrix(ncvar_get(ncId, 'ANO3K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3K * myMolMass$N
      
      rawSIM[[iMon]][[iScen]]$HNO3$air = tmpHNO3
      rawSIM[[iMon]][[iScen]]$NO3$pm25 = valPM25AT * tmpNO3I + valPM25AC * tmpNO3J + valPM25CO * tmpNO3K
      rawSIM[[iMon]][[iScen]]$NO3$pm10 = tmpNO3I + tmpNO3J + tmpNO3K
      rawSIM[[iMon]][[iScen]]$SNO3$pm10 = tmpHNO3 + tmpNO3I + tmpNO3J + tmpNO3K

            
      print('    Reading SO4')
      tmpSO2 = matrix(ncvar_get(ncId, 'SO2', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) * valPRES / valTA / R * myMolMass$S
      tmpSO4I = matrix(ncvar_get(ncId, 'ASO4I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4I * myMolMass$S
      tmpSO4J = matrix(ncvar_get(ncId, 'ASO4J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4J * myMolMass$S
      tmpSO4K = matrix(ncvar_get(ncId, 'ASO4K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4K * myMolMass$S
      
      rawSIM[[iMon]][[iScen]]$SO2$air = tmpSO2
      rawSIM[[iMon]][[iScen]]$SO4$pm25 = valPM25AT * tmpSO4I + valPM25AC * tmpSO4J + valPM25CO * tmpSO4K
      rawSIM[[iMon]][[iScen]]$SO4$pm10 = tmpSO4I + tmpSO4J + tmpSO4K
      rawSIM[[iMon]][[iScen]]$SOX$pm10 = tmpSO4I + tmpSO4J + tmpSO4K + tmpSO2
      
      print('    Reading Na')
      if (iScen %in% c('sp13.corr', 'ov14.corr')) { tmpNaI = matrix(ncvar_get(ncId, 'ANAI', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) * ssRealNa2Cat
      } else {                                      tmpNaI = matrix(0.0, ncol = nSTATIONS, nrow = nTSTEP) }
      
      tmpNaJ = matrix(ncvar_get(ncId, 'ANAJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) * ssRealNa2Cat
      if (myAero == 'aero6') {       tmpNaK = matrix(ncvar_get(ncId, 'ASEACAT', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / ssSeaCatMass * ssNaMass
      } else if(myAero == 'aero5') { tmpNaK = matrix(ncvar_get(ncId, 'ANAK', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) * ssRealNa2Cat
      }

      rawSIM[[iMon]][[iScen]]$Na$pm25 = valPM25AT * tmpNaI + valPM25AC * tmpNaJ + valPM25CO * tmpNaK
      rawSIM[[iMon]][[iScen]]$Na$pm10 = tmpNaI + tmpNaJ + tmpNaK
      
      print('    Reading corr SO4')
      rawSIM[[iMon]][[iScen]]$XSO4$pm25 = rawSIM[[iMon]][[iScen]]$SO4$pm25 - rawSIM[[iMon]][[iScen]]$Na$pm25 / ssNaMass * ssSO4Mass / 3
      rawSIM[[iMon]][[iScen]]$XSO4$pm10 = rawSIM[[iMon]][[iScen]]$SO4$pm10 - rawSIM[[iMon]][[iScen]]$Na$pm10 / ssNaMass * ssSO4Mass / 3
      
      nc_close(ncId)
    }
  }
}



# reworking model ----
if (work.sim) {
  valSIM = list()
  
  for (iMon in MONs) {
    valSIM[[iMon]] = list()
    for (iScen in SCENs) {
      valSIM[[iMon]][[iScen]] = list()
      for (iSpec in allSPECs) {
        valSIM[[iMon]][[iScen]][[iSpec]] = list()
        theseMTRCs = names(rawSIM[[iMon]][[iScen]][[iSpec]])
        for (iMtrx in theseMTRCs) {
          thisSIM = rawSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]]
          nDays = length(thisSIM[,1])/24
          
          tmpSIM = list()
          tmpSIM$unit = UNITS[[iSpec]]
          
          for (iLoc in 1:nSTATIONS) {
            iStat = myStations[iLoc]
            tmpSIM[[iStat]] = colMeans(array(thisSIM[,iLoc], dim = c(24,nDays)), na.rm = TRUE)
          }
          
          valSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]] = tmpSIM
        }
      }
    }
  }
}

gc()

# plot data A ----
if(plot.dat.A) {  
  
  yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SO4' = expression("SO"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'SO2' = expression("SO"[2] ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'Na' = expression("Na"^"+" ~ 'conc [' ~ mu * 'g/' * m^3 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NH3' = expression("NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3' = expression("HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  
  # plot A: define screens ----
  ShlB = 0.07 # left
  ShrB = 0.992 # right
  ShdB = 0.035 # Abstand
  SvtB = 0.93 # top
  SvbB = 0.05 # bottom
  SvdB = 0.01 # Abstand
  ShBox = 0.06
  ShcB = ShlB+(ShrB-ShlB)*3/6
  
  for(iSpec in c(SPECs, 'SOX')) {  
  # for(iSpec in SPECs[c(7)]) {  
  # for(iSpec in SPECs[c(5,4,3,1,2)]) {  
    for (iMtrx in allMATRICEs[[iSpec]]) {
      # postscript(file = paste('CONC.timeseries', setup, iSpec, 'moreStations', 'eps', sep = '.'), onefile=TRUE,
      #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
      postscript(file = paste('CONC.timeseries', setup, iSpec, iMtrx, 'allStations', 'eps', sep = '.'), onefile=TRUE,
                 horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
      # postscript(file = paste('CONC.timeseries', setup, iSpec, iMtrx, 'threeStations', 'eps', sep = '.'), onefile=TRUE,
      #           horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
      par(mar = c(0,0,0,0)+0, 
          mgp = c(1.5,0.5,0.0))
      
      iScreen = 0
      
      for(iStat in myStations){
        
        if(iScreen%%13 == 0) {
          if(iScreen != 0) plot.new()
          iScreen = 1
          
          split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                             # top left, time series
                             c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                             c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                             # top right, time series
                             c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                             c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                             # center left, time series
                             c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                             c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                             # center right, time series
                             c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                             c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                             # bottom left, time series
                             c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                             c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                             # bottom right, time series
                             c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                             c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
                             ))
          
          # plot A: make legend ----
          screen(iScreen)
          # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
          plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
          if(iSpec == 'Na') { tCol = 'orange'; tPch = 8; tLab = 'zero'
          } else {            tCol = 'green';  tPch = 4; tLab = 'ov14.corr'}
          
          if ( !(iSpec %in% c('NO3', 'NH4', 'HNO3', 'NH3')) ) {
            legend('left', legend = c('obs', 'GO03', 'SP13', 'OV14', 'zero', '  year 2008'),
                   col = c('darkgrey', 'cyan', 'orange', 'darkviolet', 'red', 'white'), 
                   lwd = c(10,2,2,2,2,NA), 
                   lty = c('solid', NA, NA, NA, NA, NA), pch = c(NA, 19, 1, 4, 8, NA),
                   bg = 'white', horiz = TRUE, inset = 0.02,
                   pt.cex = 2, seg.len = 0.5, text.width = 0.12, bty = 'n')
          } else {
            legend('left', legend = c('', 'GO03', 'SP13', 'OV14', 'zero', '  year 2008'),
                   col = c('white', 'cyan', 'orange', 'darkviolet', 'red', 'white'), 
                   lwd = c(10,2,2,2,2,NA), 
                   lty = c('solid', NA, NA, NA, NA, NA), pch = c(NA, 19, 1, 4, 8, NA),
                   bg = 'white', horiz = TRUE, inset = 0.02,
                   pt.cex = 2, seg.len = 0.5, text.width = 0.12, bty = 'n')
          }
        }
        
        myMax = 0
        for (iMon in MONs) {
          myMax = max(myMax, max(valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values, na.rm = TRUE))
          for(iScen in SCENs) { myMax = max(myMax, max(valSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]][[iStat]], na.rm = TRUE)) }
        }
        myLim = getYlim(myMax, 3)
        
        for(iMon in MONs) {
          refDate=2008001
          strYear='2008'
          if(iMon == 'sum2008' || iMon == 'sum') {
            from = 2008183; to = 2008243; nT = 61
          } else if(iMon == 'win2008' || iMon == 'win') {
            from = 2008001; to = 2008060; nT = 60
          }
          nTh = nT * 24
          
          # print(paste(iMon, iSpec, iMtrx, iStat))
          
          # plot A: prepare data ----
          timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
          # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
          
          pltOBS = rep(0.0, nT)
          pltOBS = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
          if ( is.null(pltOBS) || length(pltOBS) == 0) { pltOBS = rep(0.0, nT) }
        
          pltOBSnoNA = pltOBS
          pltOBSnoNA[is.na(pltOBS)] = 0
          
          # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
          pltSIM_base = valSIM[[iMon]][['base']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_sp13 = valSIM[[iMon]][['sp13.corr']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_ov14 = valSIM[[iMon]][['ov14.corr']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_zero = valSIM[[iMon]][['zero']][[iSpec]][[iMtrx]][[iStat]]
          
          myLim = getYlim(max(c(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), na.rm = TRUE), 3)
        
          # plot A: start plotting ----
          iScreen = iScreen + 1 
        
          screen(iScreen)
          plot(timeAxis[-nT-1], pltOBSnoNA,
               type = 'n', ann = FALSE, ylim = c(0,myLim),
               yaxt = 'n', xaxt = 'n')
        
          if ((iScreen-1)%%2 == 1) axis(2)
          # if(iScreen > 12) axis(1)
          
          yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
          yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
          if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
          if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
          if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
          if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
          # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
          if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
          if ((iScreen-1)%%4 == 3) title(paste(valOBS[[1]][[1]][[iStat]]$station$station_name, iStat, sep = ' '), line = -1)
          
          if (iSpec != 'NO3') {
            polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
                    col = 'darkgrey', border = FALSE)
          }
          
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_base,
                col = 'cyan', pch = 19, cex = 0.8)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_sp13,
                col = 'orange', pch = 1, cex = 0.8)
            points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_zero,
                  col = 'red', pch = 8, cex = 0.7)
            points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_ov14,
                  col = 'darkviolet', pch = 4, cex = 0.8)
          
          iScreen = iScreen + 1 
          screen(iScreen)
          # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
          #       are available as observations and measurements.
          if (iSpec == 'Na') {
            boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet'), range = 0)
            points(1:4, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet'))
          } else if (iSpec != 'NO3'){
            boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet'), range = 0)
            points(1:4, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet'))
          } else {
            boxplot(apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet'), range = 0)
            points(1:4, apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet'))
          }
          
        }
      }
      close.screen(all.screens = TRUE)
      dev.off()
    }
  }
}

# plot B: histograms ----
if(plot.dat.B) {
  orderedStations = c("DE0001R", "NL0091R", "NO0001R", "DE0009R", "PL0004R", "NO0039R", "DE0002R", "DE0007R", "PL0005R", "NO0056R", "DE0044R", "PL0002R")
  nOrdStat = length(orderedStations)
  namesStations = c()
  
  for(i1 in 1:nOrdStat) namesStations = c(namesStations, stationNames[[orderedStations[i1]]])
  
  
  yAxisLab = list('pm10SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'pm10NO3' = expression("PM"[10] ~ " " ~ "NO"[3]^"-" ~ 'conc [' * mu * 'g N/' * m^3 * ']'),
                  'pm25NO3' = expression("PM"[2.5] ~ " " ~ "NO"[3]^"-" ~ 'conc [' * mu * 'g N/' * m^3 * ']'))
  yMax = list('pm10NO3win2008' = 2.2,
              'pm25NO3win2008' = 2.2,
              'pm10SNO3win2008' = 2.2,
              'pm10NO3sum2008' = 1.1,
              'pm25NO3sum2008' = 1.1,
              'pm10SNO3sum2008' = 1.1)
  
  # postscript(file = 'CONC.mean.histograms.eps', paper = 'special', height = 4, width = 6, horizontal = FALSE)
  # par(mar = c(5,4,0.5,0.2)+0.1, mgp = c(2.2,1,0))
  
  for (iSpec in intersect(SPECs, c('NO3', 'SNO3'))) {
  # for (iSpec in c('NO3')) {
    for (iMon in MONs) {
    # for (iMon in MONs[1]) {
      for (iMtrx in allMATRICEs[[iSpec]]) {
      # for (iMtrx in c('pm10')) {
        # only observations
        myMeansO = list()
        myStdO = list()
        myNO = list()
        # all values
        myMeansA = list()
        myStdA = list()
        myNA = list()
        
        myMeansO$obs = rep(0.0, nOrdStat)
        myStdO$obs = rep(0.0, nOrdStat)
        myNO$obs = rep(as.integer(0), nOrdStat)
        
        for(iScen in SCENs) {
          myMeansO[[iScen]] = rep(0.0, nOrdStat)
          myStdO[[iScen]] = rep(0.0, nOrdStat)
          myNO[[iScen]] = rep(as.integer(0), nOrdStat)
          myMeansA[[iScen]] = rep(0.0, nOrdStat)
          myStdA[[iScen]] = rep(0.0, nOrdStat)
          myNA[[iScen]] = rep(as.integer(0), nOrdStat)
        }
          
        for (iS in 1:nOrdStat) {
          iStat = orderedStations[iS]
          
          tmpObs = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
          validVals = !is.na(tmpObs)
          
          myMeansO$obs[iS] = mean(tmpObs[validVals], na.rm = TRUE)
          myStdO$obs[iS] = sd(tmpObs[validVals], na.rm = TRUE)
          myNO$obs[iS] = sum(validVals)
          
          for(iScen in SCENs) {
            tmpDat = valSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]][[iStat]]
            
            a = 1+1
            
            myMeansO[[iScen]][iS] = mean(tmpDat[validVals], na.rm = TRUE)
            myMeansA[[iScen]][iS] = mean(tmpDat, na.rm = TRUE)
            
            myStdO[[iScen]][iS] = sd(tmpDat[validVals], na.rm = TRUE)
            myStdA[[iScen]][iS] = sd(tmpDat, na.rm = TRUE)
            
            myNO[[iScen]][iS] = sum(validVals)
            myNA[[iScen]][iS] = length(tmpDat)
          }
        }
        
        # plot B: make plots ----
        for (iType in c('A', 'O')) {
          pdf(file = paste(paste('CONC_mean_histograms', iMon, iSpec, iMtrx, iType, sep = '_'), 'pdf', sep = '.'), paper = 'special', height = 4, width = 6)
          par(mar = c(5,4,0.5,0.2)+0.1, mgp = c(2.2,1,0))
          if (iType == 'A') {
            nScen = 4
            allMeans = rbind(myMeansA$base, myMeansA$sp13.corr, myMeansA$ov14.corr, myMeansA$zero )
            allStds = rbind(myStdA$base, myStdA$sp13.corr, myStdA$ov14.corr, myStdA$zero )
            allNs = myNA$base
            allCol = c('cyan', 'orange', 'darkviolet', 'red')
            allLeg = c('GO03', 'SP13', 'OV14', 'zero')
          } else if (iType == 'O') {
            nScen = 5
            allMeans = rbind(myMeansO$base, myMeansO$sp13.corr, myMeansO$ov14.corr, myMeansO$zero, myMeansO$obs )
            allStds = rbind(myStdO$base, myStdO$sp13.corr, myStdO$ov14.corr, myStdO$zero, myStdO$obs )
            allNs = myNO$base
            allCol = c('cyan', 'orange', 'darkviolet', 'red', 'grey')
            allLeg = c('GO03', 'SP13', 'OV14', 'zero', 'obs')
          }
          
          if (iMon == 'win2008') allMon = 'winter 2008' else if(iMon == 'sum2008') allMon = 'summer 2008'
          
          barplot(allMeans,
                  beside = TRUE, col = allCol,
                  # names.arg = paste(substr(namesStations, 1, 2), substr(namesStations, 5, 6), sep = ""),
                  las = 2, border = NA, ylim = c(0,yMax[[paste(iMtrx,iSpec,iMon,sep='')]]),
                  ylab = yAxisLab[[paste(iMtrx,iSpec,sep='')]], 
                  legend.text = allLeg,
                  args.legend = list('x' = 'topright', 'horiz' = TRUE))
          mtext(allMon, at = 0, line = -0.5, cex = 1.2)
          # axis(1, at = (0:(nOrdStat-1)) * (nScen+1) + 3, 
          #      labels = allNs, 
          #      tick = FALSE, line = -0.4)
          # mtext('n values:', 1, line = 0.6, at = -4)
          axis(1, at = (0:(nOrdStat-1)) * (nScen+1) + 3,
               # labels = paste(substr(namesStations, 1, 2), substr(namesStations, 5, 6), sep = ""),
               labels = namesStations,
               tick = FALSE, line = -0.5,
               las = 2)
          dev.off()
        }
      }
    }
  }
  
}




# plot data C: Westerland+Jarczew, NO3 ----
if(plot.dat.C) {  
  
  theStations = array(c('DE0001R', 'PL0002R', 'PL0002R', 'PL0002R'), dim = c(2,2))
  theSubstances = array(c('NO3', 'SNO3', 'NO3', 'NO3'), dim = c(2,2))
  
  yAxisLab = list('SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3' = expression("HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  postscript(file = paste('CONC.timeseries', setup, 'AQ2016', 'A', 'eps', sep = '.'), onefile=TRUE,
             horizontal = FALSE, paper = 'special', width = 10, height = 5)
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  # plot C: define screens ----
  ShlB = 0.07 # left
  ShrB = 0.992 # 0.965 # right
  ShdB = 0.035 # Abstand
  SvtB = 0.828 # top      0.455
  SvbB = 0.065 # bottom   0.325
  SvdB = 0.013 # Abstand  0.065
  # SvtB = 0.92 # top      0.455
  # SvbB = 0.072 # bottom   0.325
  # SvdB = 0.014 # Abstand  0.065
  ShBox = 0.06
  ShcB = ShlB+(ShrB-ShlB)*3/6
  ShLeg = 1-SvtB-2*SvdB
  
  iScreen = 0
  
  for(iPage in 1:2) {
        
    if(iScreen != 0) plot.new()
    iScreen = 1
    
    split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB+ShLeg/4, 1.0-SvdB-ShLeg/4), # legend row
                       # top left, time series
                       c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)/2+SvdB/2, SvtB),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)/2+SvdB/2, SvtB),
                       # top right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)/2+SvdB/2, SvtB),
                       c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)/2+SvdB/2, SvtB),
                       # center left, time series
                       c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/2-SvdB/2),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/2-SvdB/2),
                       # center right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/2-SvdB/2),
                       c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/2-SvdB/2)
    ))
    
    # plot C: make legend ----
    screen(iScreen)
    # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
    plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
    
    if ( iPage == 2 ) {
      legend('left', legend = c('GO03', 'SP13', 'OV14', 'zero', 'obs', '  year 2008'),
             col = c('cyan', 'orange', 'darkviolet', 'red', 'darkgrey', 'white'), 
             lwd = NA, lty = NA, pch = c(19, 1, 4, 8, 15, NA),
             bg = 'white', horiz = TRUE, inset = 0.02,
             pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
    } else {
      legend('left', legend = c('GO03', 'SP13', 'OV14', 'zero', '', '  year 2008'),
             col = c('cyan', 'orange', 'darkviolet', 'red', 'white', 'white'), 
             lwd = NA, lty = NA, pch = c(19, 1, 4, 8, 15, NA),
             bg = 'white', horiz = TRUE, inset = 0.02,
             pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
    }
    
    for (iPlot in 1:2) {
      
      iMtrx = 'pm10'
      iStat = theStations[iPage,iPlot]
      iSpec = theSubstances[iPage,iPlot]
        
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'sum2008' || iMon == 'sum') {
          from = 2008183; to = 2008243; nT = 61
        } else if(iMon == 'win2008' || iMon == 'win') {
          from = 2008001; to = 2008060; nT = 60
        }
        nTh = nT * 24
        
        # print(paste(iMon, iSpec, iMtrx, iStat))
        
        # plot C: prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        pltOBS = rep(0.0, nT)
        pltOBS = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
        if ( is.null(pltOBS) || length(pltOBS) == 0) { pltOBS = rep(0.0, nT) }
        
        pltOBSnoNA = pltOBS
        pltOBSnoNA[is.na(pltOBS)] = 0
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIM_base = valSIM[[iMon]][['base']][[iSpec]][[iMtrx]][[iStat]]
        pltSIM_sp13 = valSIM[[iMon]][['sp13.corr']][[iSpec]][[iMtrx]][[iStat]]
        pltSIM_ov14 = valSIM[[iMon]][['ov14.corr']][[iSpec]][[iMtrx]][[iStat]]
        pltSIM_zero = valSIM[[iMon]][['zero']][[iSpec]][[iMtrx]][[iStat]]
        
        myLim = getYlim(max(c(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), na.rm = TRUE), 3)
        
        # plot C: start plotting ----
        iScreen = iScreen + 1 
        
        screen(iScreen)
        plot(timeAxis[-nT-1], pltOBSnoNA,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
        
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
        
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 6) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 8) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 2 && iPage == 1) mtext(yAxisLab[[iSpec]],2, line = 1.6, at = 0.0)
        if(iScreen == 2 && iPage == 2) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if(iScreen == 6 && iPage == 2) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        # if ((iScreen-1)%%4 == 3) title(paste(valOBS[[1]][[1]][[iStat]]$station$station_name, iStat, sep = ' '), line = -1)
        
        if (iSpec != 'NO3') {
          polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
                  col = 'darkgrey', border = FALSE)
        }
        
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_base,
               col = 'cyan', pch = 19, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_sp13,
               col = 'orange', pch = 1, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_zero,
               col = 'red', pch = 8, cex = 0.7)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_ov14,
               col = 'darkviolet', pch = 4, cex = 0.8)
        
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        if (iSpec == 'Na') {
          boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
          points(1:5, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
        } else if (iSpec != 'NO3'){
          boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
          points(1:5, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
        } else {
          boxplot(apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
          points(1:5, apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
        }
        
        if (iPage == 1 && iScreen == 5) mtext('Westerland', 4, cex = 1.3, line = 0.5)
        if (iPage == 1 && iScreen == 9) mtext('Jarczew', 4, cex = 1.3, line = 0.5)
        if (iPage == 2 && iScreen == 5) mtext('Jarczew', 4, cex = 1.3, line = 0.5, at = 0.0)
        
      }
    }
  }
  close.screen(all.screens = TRUE)
  dev.off()
}



# plot data D: Jarczew, NO3+SNO3 ----
if(plot.dat.D) {  
  
  yAxisLab = list('SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3' = expression("HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  postscript(file = paste('CONC.timeseries', setup, 'AQ2016', 'B', 'eps', sep = '.'), onefile=TRUE,
             horizontal = FALSE, paper = 'special', width = 5.215, height = 5)
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  # plot D: define screens ----
  ShlB = 0.134 # left
  ShrB = 0.985 # right
  ShdB = 0.067 # Abstand
  SvtB = 0.828 # top      0.455
  SvbB = 0.065 # bottom   0.325
  SvdB = 0.02 # Abstand  0.065
  # plot: 1.874166
  ShBox = 0.115
  
  split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                     # top right, time series
                     c(ShlB, ShrB-ShBox, SvbB+(SvtB-SvbB)/2+SvdB/2, SvtB),
                     c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)/2+SvdB/2, SvtB),
                     # bottom right, time series
                     c(ShlB, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/2-SvdB/2),
                     c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/2-SvdB/2),
                     c(ShlB*1/5, ShlB, SvbB, SvtB)
  ))
  
  iScreen = 1
  # plot D: make legend ----
  screen(iScreen)
  # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
  plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
  
  legend('topleft', legend = c('GO03', 'SP13', 'year 2008'),
         col = c('cyan', 'orange', 'white'),
         lwd = NA, lty = NA, pch = c(19,1,NA),
         bg = 'white', inset = 0.035, horiz = TRUE,  # ncol = 3, # horiz = TRUE, 
         pt.cex = 2, seg.len = 0.5, text.width = 0.3, bty = 'n')
  legend('bottomleft', legend = c('OV14', 'zero', 'obs'),
         col = c('darkviolet', 'red', 'darkgrey'),
         lwd = NA, lty = NA, pch = c(4,8,15),
         bg = 'white', inset = 0.035, horiz = TRUE, # ncol = 3, # 
         pt.cex = 2, seg.len = 0.5, text.width = 0.3, bty = 'n')
  
    
  for (iSpec in c('SNO3', 'NO3')) {
    
    iMtrx = 'pm10'
    # iStat = 'Jarczew'
    iStat = 'PL0002R'
    iMon = 'sum2008'
    
    refDate=2008001
    strYear='2008'
    if(iMon == 'sum2008' || iMon == 'sum') {
      from = 2008183; to = 2008243; nT = 61
    } else if(iMon == 'win2008' || iMon == 'win') {
      from = 2008001; to = 2008060; nT = 60
    }
    nTh = nT * 24
    
    # print(paste(iMon, iSpec, iMtrx, iStat))
    
    # plot D: prepare data ----
    timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
    # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
    
    pltOBS = rep(0.0, nT)
    pltOBS = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
    if ( is.null(pltOBS) || length(pltOBS) == 0) { pltOBS = rep(0.0, nT) }
    
    pltOBSnoNA = pltOBS
    pltOBSnoNA[is.na(pltOBS)] = 0
    
    # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
    pltSIM_base = valSIM[[iMon]][['base']][[iSpec]][[iMtrx]][[iStat]]
    pltSIM_sp13 = valSIM[[iMon]][['sp13.corr']][[iSpec]][[iMtrx]][[iStat]]
    pltSIM_ov14 = valSIM[[iMon]][['ov14.corr']][[iSpec]][[iMtrx]][[iStat]]
    pltSIM_zero = valSIM[[iMon]][['zero']][[iSpec]][[iMtrx]][[iStat]]
    
    # myLim = getYlim(max(c(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), na.rm = TRUE), 3)
    myLim = 1.15
    
    # plot D: start plotting ----
    iScreen = iScreen + 1 
    
    screen(iScreen)
    plot(timeAxis[-nT-1], pltOBSnoNA,
         type = 'n', ann = FALSE, ylim = c(0,myLim),
         yaxt = 'n', xaxt = 'n')
    
    if ((iScreen-1)%%2 == 1) axis(2)
    # if(iScreen > 12) axis(1)
    
    yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
    yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
    # if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
    # if(iScreen == 6) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
    if(iScreen %in% c(2,4)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
    if(iScreen == 4) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
    # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
    if(iScreen == 2) mtext(yAxisLab[[iSpec]],2, line = 1.6)
    if(iScreen == 4) mtext(yAxisLab[[iSpec]],2, line = 1.6)
    # if ((iScreen-1)%%4 == 3) title(paste(valOBS[[1]][[1]][[iStat]]$station$station_name, iStat, sep = ' '), line = -1)
    
    if (iSpec != 'NO3') {
      polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
              col = 'darkgrey', border = FALSE)
    }
    
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_base,
           col = 'cyan', pch = 19, cex = 0.8)
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_sp13,
           col = 'orange', pch = 1, cex = 0.8)
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_zero,
           col = 'red', pch = 8, cex = 0.7)
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_ov14,
           col = 'darkviolet', pch = 4, cex = 0.8)
    
    iScreen = iScreen + 1 
    screen(iScreen)
    # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
    #       are available as observations and measurements.
    if (iSpec == 'Na') {
      boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
      points(1:5, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
    } else if (iSpec != 'NO3'){
      boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
      points(1:5, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
    } else {
      boxplot(apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
      points(1:5, apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
    }
    
    if (iScreen == 5) mtext('Jarzcew', 4, cex = 1.3, line = 0.5, at = 0.0)
  }
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot data E: Westerland and Melpitz; PM2.5, PM10, sNO3 ----
if(plot.dat.E) {  
  
  yAxisLab = list('SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3pm10' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3pm10' = expression("NO"[3]^"-" ~ ' PM'[10] ~ ' concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3pm25' = expression("NO"[3]^"-" ~ ' PM'[2.5] ~ ' concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3' = expression("HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3air' = expression("HNO"[3] ~ ' concentration [' ~ mu * 'g N/' * m^3 * ']'))
  # myMaxi = list('NO3pm10' = list('DE0001R' = list('win' = , 'sum' = ), 
  #               'NO3pm25' = list('win' = , 'sum' = ),
  #               'HNO3air' = list('win' = , 'sum' = ))
  # myScales = list('NO3pm10' = list('win' = , 'sum' = ), 
  #                 'NO3pm25' = list('win' = , 'sum' = ),
  #                 'HNO3air' = list('win' = , 'sum' = ))
  
  
  pdf(file = paste(paste('CONC_timeseries', sub('.', '_', setup, fixed = TRUE), 'nitrate', 'allMtrcs', 'threeStations', sep = '_'), 
                   'pdf', sep = '.'), onefile=TRUE,
      paper = 'special', width = 10.53, height = 12.415) # 10;6.5
  
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  
  # plot E: define screens ----
  ShlB = 0.060 # 0.07 # left 0.066
  ShrB = 1 - 0.064 # 0.992 # right 0.058
  ShdB = 0.033 # 0.035 # Abstand
  ShBox = 0.057 # 0.06
  SvtB = 1-0.0366 # 0.93 # top
  SvbB = 0.0262 # 0.05 # bottom
  SvdB = 0.0052 # 0.01 # Abstand
  ShcB = ShlB+(ShrB-ShlB)*3/6
  SvP = (SvtB - SvbB - 9*SvdB) / 6
  ShP = (ShrB - ShlB - ShdB - 2*ShBox) / 2
  
  h1 = ShlB;      h2 = h1+ShP;   h3 = h2+ShBox
  h4 = h3+ShdB;   h5 = h4+ShP;   h6 = h5+ShBox # (=ShrB)
  v1 = SvbB;      v2 = v1+SvP;   v3 = v2+SvdB;   v4 = v3+SvP;
  v5 = v4+2.5*SvdB; v6 = v5+SvP;   v7 = v6+SvdB;   v8 = v7+SvP;
  v9 = v8+2.5*SvdB; v10= v9+SvP;   v11= v10+SvdB;  v12= v11+SvP;
  v13=SvtB+SvdB; v14=1.0-SvdB
  
  split.screen(rbind(c(h1,h6, v13, v14), # legend row
                     # 1st row time series
                     c(h1,h2,v11,v12), c(h2,h3,v11,v12), c(h4,h5,v11,v12), c(h5,h6,v11,v12),
                     # 1st row time series
                     c(h1,h2,v9,v10), c(h2,h3,v9,v10), c(h4,h5,v9,v10), c(h5,h6,v9,v10),
                     # 1st row time series
                     c(h1,h2,v7,v8), c(h2,h3,v7,v8), c(h4,h5,v7,v8), c(h5,h6,v7,v8),
                     # 1st row time series
                     c(h1,h2,v5,v6), c(h2,h3,v5,v6), c(h4,h5,v5,v6), c(h5,h6,v5,v6),
                     # 1st row time series
                     c(h1,h2,v3,v4), c(h2,h3,v3,v4), c(h4,h5,v3,v4), c(h5,h6,v3,v4),
                     # 1st row time series
                     c(h1,h2,v1,v2), c(h2,h3,v1,v2), c(h4,h5,v1,v2), c(h5,h6,v1,v2),
                     c(ShrB,1-(1-ShrB)*10/20,v9,v12),
                     c(ShrB,1-(1-ShrB)*10/20,v5,v8),
                     c(ShrB,1-(1-ShrB)*10/20,v1,v4)
  ))
  iScreen = 1
  
  # plot E: make legend ----
  screen(iScreen)
  # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
  plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
  if(iSpec == 'Na') { tCol = 'orange'; tPch = 8; tLab = 'zero'
  } else {            tCol = 'green';  tPch = 4; tLab = 'ov14.corr'}
  
  legend('left', legend = c('OBS', 'GO03', 'SP13', 'OV14', 'zero', '  year 2008'),
         col = c('darkgrey', 'cyan', 'orange', 'darkviolet', 'red', 'white'), 
         lwd = NA, lty = NA, pch = c(15, 19, 1, 4, 8, NA),
         bg = 'white', horiz = TRUE, inset = 0.02,
         pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
  
  for(iSpec in c('NO3', 'SNO3')) {  
    for (iMtrx in allMATRICEs[[iSpec]]) {
      for(iStat in c('DE0001R','DE0044R')){
        myMax = 0
        for (iMon in MONs) {
          myMax = max(myMax, max(valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values, na.rm = TRUE))
          for(iScen in SCENs) { myMax = max(myMax, max(valSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]][[iStat]], na.rm = TRUE)) }
        }
        myLim = getYlim(myMax, 3)
        
        for(iMon in MONs) {
          refDate=2008001; strYear='2008'
          if(iMon == 'sum2008' || iMon == 'sum') { from = 2008183; to = 2008243; nT = 61
          } else if(iMon == 'win2008' || iMon == 'win') { from = 2008001; to = 2008060; nT = 60 }
          nTh = nT * 24
          
          # print(paste(iMon, iSpec, iMtrx, iStat))
          
          # plot E: prepare data ----
          timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
          # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
          
          pltOBS = rep(0.0, nT)
          pltOBS = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
          if ( is.null(pltOBS) || length(pltOBS) == 0) { pltOBS = rep(0.0, nT) }
          pltOBSnoNA = pltOBS
          pltOBSnoNA[is.na(pltOBS)] = 0
          
          # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
          pltSIM_base = valSIM[[iMon]][['base']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_sp13 = valSIM[[iMon]][['sp13.corr']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_ov14 = valSIM[[iMon]][['ov14.corr']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_zero = valSIM[[iMon]][['zero']][[iSpec]][[iMtrx]][[iStat]]
          
          myLim = getYlim(max(c(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), na.rm = TRUE), 3)
          if(iStat == 'DE0044R' && iMon == 'sum2008' && iMtrx == 'pm10' && iSpec == 'NO3' ) myLim = 3.2
          if(iStat == 'DE0044R' && iMon == 'sum2008' && iMtrx == 'pm25' && iSpec == 'NO3' ) myLim = 2.2
          if(iStat == 'DE0044R' && iMon == 'sum2008' && iMtrx == 'pm10' && iSpec == 'SNO3' ) myLim = 3.2
          
          # plot E: start plotting ----
          iScreen = iScreen + 1 
          
          screen(iScreen)
          plot(timeAxis[-nT-1], pltOBSnoNA, type = 'n', ann = FALSE, ylim = c(0,myLim), yaxt = 'n', xaxt = 'n')
          
          # x-axis scaling
          yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
          yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
          if((iScreen-2)%%4 == 0) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
          if(iScreen == 22) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
          if(iScreen%%4 == 0) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
          if(iScreen == 24) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
          
          # y-axis scaling
          if((iScreen-2)%%8 == 0) mtext(yAxisLab[[paste(iSpec,iMtrx,sep='')]],2, line = 1.6, at = 0)
          # if ((iScreen-1)%%4 == 3) title(paste(valOBS[[1]][[1]][[iStat]]$station$station_name, iStat, sep = ' '), line = -1)
          
          # Special Cases
          if (iStat == 'DE0044R' && iMon == 'sum2008' && ( ( iMtrx == 'pm10' && iSpec == 'NO3' ) || ( iMtrx == 'pm10' && iSpec == 'SNO3' ) ) ) { 
            axis(2, labels = FALSE); axis(2, at = 0:3)
          } else if (iStat == 'DE0001R' && iMon == 'win2008' && iMtrx == 'pm25' && iSpec == 'NO3' ) { 
            axis(2, labels = FALSE); axis(2, at = 0:3)
          } else { 
            axis(2)
          }
          
          #if (iSpec != 'NO3') {
            polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
                    col = 'darkgrey', border = FALSE)
          #}
          
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_base,
                 col = 'cyan', pch = 19, cex = 0.8)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_sp13,
                 col = 'orange', pch = 1, cex = 0.8)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_zero,
                 col = 'red', pch = 8, cex = 0.7)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIM_ov14,
                 col = 'darkviolet', pch = 4, cex = 0.8)
          
          iScreen = iScreen + 1 
          screen(iScreen)
          # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
          #       are available as observations and measurements.
          if ( (iStat == 'DE0044R' && iSpec == 'NO3') || 
               (iStat == 'DE0001R' && iSpec == 'SNO3') || 
               (iStat == 'DE0001R' && iSpec == 'NO3' && iMtrx == 'pm10' && iMon == 'win2008' ) ){
            boxplot(apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
            points(1:5, apply(rbind(pltOBS, pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
          } else {
            boxplot(apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
            points(1:5, apply(rbind(rep(-100,length(pltOBS)), pltSIM_base, pltSIM_sp13, pltSIM_ov14, pltSIM_zero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', 'red'))
          }
          
          if((iScreen-1)%%4 == 0) mtext(list_stations[[iStat]], 4, cex = 1.5, line = 0.5)
        }
      }
      
      screen(25+((iScreen-1)/8))
      plot(c(0,1), c(0,1), ann = FALSE, type = 'n', xaxt ='n', yaxt = 'n', bty = 'n')
      lines(c(1.0,1.0), c(0,1))
      if(iSpec == 'NO3') mtext(exprMatrix[[iMtrx]], 4, cex = 1.5, line = 0.6)
      else mtext(exprMatrix[['air']], 4, cex = 1.5, line = 0.6)
    }
  }
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot F: histograms, one page ----
if(plot.dat.F) {
  orderedStations = c("DE0001R", "NL0091R", "NO0001R", "DE0009R", "PL0004R", "NO0039R", "DE0002R", "DE0007R", "PL0005R", "NO0056R", "DE0044R", "PL0002R")
  nOrdStat = length(orderedStations)
  namesStations = c()
  
  for(i1 in 1:nOrdStat) namesStations = c(namesStations, stationNames[[orderedStations[i1]]])
  
  
  yAxisLab = list('SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3pm10' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3pm10' = expression("NO"[3]^"-" ~ ' PM'[10] ~ ' concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3pm25' = expression("NO"[3]^"-" ~ ' PM'[2.5] ~ ' concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3' = expression("HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                  'HNO3air' = expression("HNO"[3] ~ ' concentration [' ~ mu * 'g N/' * m^3 * ']'))
  yMax = list('pm10NO3win2008' = 1.6,  # 2.2,
              'pm25NO3win2008' = 1.6, # 2.2,
              'pm10SNO3win2008' = 1.8, # 2.2,
              'pm10NO3sum2008' = 0.55,
              'pm25NO3sum2008' = 0.55,
              'pm10SNO3sum2008' = 1.1)
  
  pdf(file = paste(paste('CONC_mean_histograms', 'allMon', 'nitrate', 'allMtrcs', sep = '_'), 'pdf', sep = '.'), 
      paper = 'special', width = 10.53, height = 12.415 ) # , height = 4, width = 6
  # postscript(file = 'CONC.mean.histograms.eps', paper = 'special', height = 4, width = 6, horizontal = FALSE)
  # par(mar = c(5,4,0.5,0.2)+0.1, mgp = c(2.2,1,0))
  par(mar = c(0,0,0,0)+0, mgp = c(2.2,0.8,0.0))
  
  # plot F: define screens ----
  ShlB = 0.070 # 0.07 # left 0.066
  ShrB = 1 - 0.064 # 0.992 # right 0.058
  ShdB = 0.04 # 0.035 # Abstand
  ShBox = 0.057 # 0.06
  SvtB = 1-0.0366 # 0.93 # top
  SvbB = 0.09 # 0.05 # bottom
  SvdtB = 0.0052 # 0.01 # Abstand, top; legend
  SvdcB = 0.03 # 0.01 # Abstand, column titles
  SvdB = 0.07 # 0.01 # Abstand
  SvTitel = 0.005
  ShcB = ShlB+(ShrB-ShlB)*3/6
  SvP = (SvtB - SvbB - 2*SvdB - SvdcB - SvTitel) / 4
  ShP = (ShrB - ShlB - ShdB - 2*ShBox) / 2
  
  h1 = ShlB;      h2 = h1+ShP;   h3 = h2+ShBox
  h4 = h3+ShdB;   h5 = h4+ShP;   h6 = h5+ShBox # (=ShrB)
  v1 = SvbB;      v2 = v1+SvP;   v3 = v2;   v4 = v3+SvP;
  v5 = v4+SvdB; v6 = v5+SvP;   v7 = v6+SvdB;   v8 = v7+SvP;
  v13=SvtB+SvdtB; v14=1.0-SvdtB
  
  split.screen(rbind(c(h1,h6, v13, v14), # legend row
                     # 1st row time series
                     c(h1,h3,v7,v8), c(h4,h6,v7,v8), 
                     # 1st row time series
                     c(h1,h3,v5,v6), c(h4,h6,v5,v6), 
                     # 1st row time series
                     c(h1,h3,v3,v4), c(h4,h6,v3,v4), 
                     # 1st row time series
                     c(h1,h3,v1,v2), c(h4,h6,v1,v2), 
                     c(ShrB,1-(1-ShrB)*10/20,v6,v8),
                     c(ShrB,1-(1-ShrB)*10/20,v4,v6),
                     c(ShrB,1-(1-ShrB)*10/20,v1-SvdB,v4)
  ))
  iScreen = 1
  
  # plot E: make legend ----
  screen(iScreen)
  # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
  plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
  
  legend('left', legend = c('OBS', 'GO03', 'SP13', 'OV14', 'zero', '  year 2008'),
         lwd = NA, lty = NA, pch = 15,
         col = c('grey', 'cyan', 'orange', 'darkviolet', 'red', NA),
         horiz = TRUE, inset = 0.02, bg = 'white', 
         pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
  iScreen = 2
  
  # for (iSpec in intersect(SPECs, c('NO3', 'SNO3'))) {
  for (iSpec in c('NO3', 'SNO3')) {
    for (iMtrx in allMATRICEs[[iSpec]]) {
      for (iMon in MONs) {
        # for (iMtrx in c('pm10')) {
        # only observations
        myMeansO = list()
        myStdO = list()
        myNO = list()
        # all values
        myMeansA = list()
        myStdA = list()
        myNA = list()
        
        myMeansO$obs = rep(0.0, nOrdStat)
        myStdO$obs = rep(0.0, nOrdStat)
        myNO$obs = rep(as.integer(0), nOrdStat)
        
        for(iScen in SCENs) {
          myMeansO[[iScen]] = rep(0.0, nOrdStat)
          myStdO[[iScen]] = rep(0.0, nOrdStat)
          myNO[[iScen]] = rep(as.integer(0), nOrdStat)
          myMeansA[[iScen]] = rep(0.0, nOrdStat)
          myStdA[[iScen]] = rep(0.0, nOrdStat)
          myNA[[iScen]] = rep(as.integer(0), nOrdStat)
        }
        
        for (iS in 1:nOrdStat) {
          iStat = orderedStations[iS]
          
          tmpObs = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
          validVals = !is.na(tmpObs)
          myMeansO$obs[iS] = mean(tmpObs[validVals], na.rm = TRUE)
          myStdO$obs[iS] = sd(tmpObs[validVals], na.rm = TRUE)
          myNO$obs[iS] = sum(validVals)
          
          for(iScen in SCENs) {
            tmpDat = valSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]][[iStat]]
            
            a = 1+1
            
            myMeansO[[iScen]][iS] = mean(tmpDat[validVals], na.rm = TRUE)
            myMeansA[[iScen]][iS] = mean(tmpDat, na.rm = TRUE)
            
            myStdO[[iScen]][iS] = sd(tmpDat[validVals], na.rm = TRUE)
            myStdA[[iScen]][iS] = sd(tmpDat, na.rm = TRUE)
            
            myNO[[iScen]][iS] = sum(validVals)
            myNA[[iScen]][iS] = length(tmpDat)
          }
        }
        
        # plot F: make plots ----
        if (iSpec == 'SNO3') myTypes = c('A', 'O')
        else myTypes = c('A')
        
        for (iType in myTypes) {
          print(paste(iSpec, iType, iMon, iMtrx, iScreen))
          if (iType == 'A') {
            nScen = 4
            allMeans = rbind(myMeansA$base, myMeansA$sp13.corr, myMeansA$ov14.corr, myMeansA$zero )
            allStds = rbind(myStdA$base, myStdA$sp13.corr, myStdA$ov14.corr, myStdA$zero )
            allNs = myNA$base
            allCol = c('cyan', 'orange', 'darkviolet', 'red')
            allLeg = c('GO03', 'SP13', 'OV14', 'zero')
          } else if (iType == 'O') {
            nScen = 5
            allMeans = rbind(myMeansO$base, myMeansO$sp13.corr, myMeansO$ov14.corr, myMeansO$zero, myMeansO$obs )
            allStds = rbind(myStdO$base, myStdO$sp13.corr, myStdO$ov14.corr, myStdO$zero, myStdO$obs )
            allNs = myNO$base
            allCol = c('cyan', 'orange', 'darkviolet', 'red', 'grey')
            allLeg = c('GO03', 'SP13', 'OV14', 'zero', 'obs')
          }
          
          if (iMon == 'win2008') allMon = 'winter 2008' else if(iMon == 'sum2008') allMon = 'summer 2008'
          if(length(myTypes) == 2 && iType == 'A' && iMon == 'sum2008') jScreen = iScreen-1
          else if(length(myTypes) == 2 && iType == 'O' && iMon == 'win2008') jScreen = iScreen+1
          else jScreen = iScreen
          screen(jScreen)
          
          barplot(allMeans,
                  beside = TRUE, col = allCol, axes = if(iScreen==9) FALSE else TRUE,
                  # names.arg = paste(substr(namesStations, 1, 2), substr(namesStations, 5, 6), sep = ""),
                  las = 0, border = NA, ylim = c(0,yMax[[paste(iMtrx,iSpec,iMon,sep='')]]))#,
                  # ylab = yAxisLab[[paste(iMtrx,iSpec,sep='')]])
          theseTicks = axTicks(2)
          if(iScreen==9) axis(2, at = theseTicks[-length(theseTicks)])
          if (!(length(myTypes) == 2 && iType == 'A')) {
            axis(1, at = (0:(nOrdStat-1)) * (nScen+1) + 3,
                 # labels = paste(substr(namesStations, 1, 2), substr(namesStations, 5, 6), sep = ""),
                 labels = namesStations,
                 tick = FALSE, line = -0.5,
                 las = 2)
          }
          # mtext(paste(iSpec,iMtrx,iType),3)
          # box()
          # theseTicks = axTicks(2)
          
          # y-axis label
          if(jScreen%%2 == 0) {
            if(!(length(myTypes) == 2)) mtext(yAxisLab[[paste(iSpec,iMtrx,sep='')]], 2, line = 2.1)
            else if(iType == 'A') mtext(yAxisLab[[paste(iSpec,iMtrx,sep='')]], 2, line = 2.1, at = 0.0)
          }
          
          # column title
          if(jScreen%in%c(2,3)) mtext(allMon, 3, font = 1, cex = 1.5, line = 0.2)
          
          # text right of the plots: model/obs
          if(iType == 'A') vertText1 = 'only model' else vertText1 = 'obs. and model'
          if(jScreen%%2 == 1 && iScreen != 1) {
            if (jScreen == 9) mtext(vertText1, 4, cex = 1.5, line = 0.5, at = -theseTicks[2], adj = 0)
            else mtext(vertText1, 4, cex = 1.5, line = 0.5, at = 0, adj = 0)
          }
          
          # text right of the plots: compounds
          if(jScreen %in% c(3,5,7)) {
            screen(9+(jScreen-1)/2)
            plot(c(0,1), c(0,1), ann = FALSE, type = 'n', xaxt ='n', yaxt = 'n', bty = 'n')
            lines(c(1.0,1.0), c(0,1))
            if(iSpec == 'NO3') mtext(exprMatrix[[iMtrx]], 4, cex = 1.5, line = 0.6)
            else mtext(exprMatrix[['air']], 4, cex = 1.5, line = 0.6)
          }
          
          iScreen = iScreen + 1
        }
      }
    }
  }
  
  close.screen(all.screens = TRUE)
  dev.off()
  
}


# statistics ----
if(doStatistics) {
  units = list()
  # fStat = paste('statistic', setup, mech, strYear, 'csv', sep = '.')
  # fRAE = paste('rae', setup, mech, strYear, 'csv', sep = '.')
  fRAE = paste('stat', 'new', setup, mech, strYear, 'moreStations', 'csv', sep = '.')
  # fIdx = paste('statistic', setup, mech, strYear, 'idx', sep = '.')
  
  # file.remove(fStat)
  # file.remove(fRAE)
  # file.remove(fIdx)
  
  write('SPECIES,MATRIX,SEASON,STATION,CASE,n,rae,mnb,cor,mean.sim,mean.obs,median.sim,median.obs', 
        file = fRAE, append = FALSE)
  
  
  for(iMon in MONs) {
    refDate=2008001
    strYear='2008'
    if(iMon == 'sum2008' || iMon == 'sum') {
      from = 2008183; to = 2008243; nT = 61
    } else if(iMon == 'win2008' || iMon == 'win') {
      from = 2008001; to = 2008060; nT = 60
    }
    nTh = nT * 24
    
    for(iSpec in c(SPECs, 'SOX')) {
      for (iMtrx in allMATRICEs[[iSpec]]) {
        for (iStat in myStations) {
          obs = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$values
          
          for(iScen in SCENs) {
            # print(paste(iMon, iScen, iSpec, iStat))
            
            sim = valSIM[[iMon]][[iScen]][[iSpec]][[iMtrx]][[iStat]]
            validVals = !is.na(obs + sim)
            
            if ( !(is.null(sim) || is.null(obs) || sum(!is.na(sim)) == 0) ) {
            
              n = sum(validVals)
              rae = sum(abs(obs-sim), na.rm = TRUE)/sum(validVals)
              mean.sim = mean(sim[validVals])
              mean.obs = mean(obs[validVals])
              median.sim = median(sim[validVals])
              median.obs = median(obs[validVals])
              mnb = MNB(obs, sim)
              myCor = cor(sim[validVals], obs[validVals], method = 'spearman')
              
              # write(paste(iSpec, iMon, iStat, iScen, formatC(rae, format = 'f', width = 4), sep = ','), 
              #       file = fRAE, append = TRUE)
              write(paste(iSpec, iMtrx, iMon, iStat, iScen, n, rae, mnb, myCor, mean.sim, mean.obs, median.sim, median.obs, sep = ','), 
                    file = fRAE, append = TRUE)
            }
          }
          
        }
      }
    }
  }
  #' make the files nice with
  #' sed -r ':a;N;$!ba;s/([a-zA-Z]+_[a-zA-Z0-9]+_[a-zA-Z]+)\n"station"/\n"\1" "station"/g' statistic.effectSeaSalt.cb05cl_ae5_aq.2008.csv | sed ':a;N;$!ba;s/^\n//g' > statistic.effectSeaSalt.cb05cl_ae5_aq.2008.csv
  #' sed -r ':a;N;$!ba;s/([a-zA-Z0-9]+_[a-zA-Z0-9]+_[a-zA-Z]+)\n"station"/\n"\1" "station"/g' statistic.effectSeaSalt.v5.cb05tucl_ae5_aq_ssa.2008.csv | sed ':a;N;$!ba;s/^\n//g' > statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.csv
  #' first sed: Remove newline between 'index' and 'statistics' (see above) and add a new
  #'            line above 'index'. The column headings of stations are no move on column
  #'            to the right. The first column of the heading row contains index.
  #' second sed: Remove the newline before the first data set.
  #' 
  #' make it even more nicer :-)
  #' cat statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.csv | tr '\n' ';' | sed -r 's/("(win|sum)2008_(SNH4|SNO3|SO4|XSO4|Na)_(noSurf|base|zero|full)") ([^;]*);"[123]" ([^;]*);"[123]" ([^;]*);"[123]" ([^;]*);/\1 \5;\1 \6;\1 \7;\1 \8/g' | sed -r 's/;"([^;"]*)" "station" [^;]*;/;/g' | sed 's/^"[^"]*"/"setup"/g' | tr ';' '\n' > statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.A.csv
  #' 
}



# write out overview data ----
if (write.dat) {
  
  fData = paste('data', setup, mech, strYear, 'means', 'csv', sep = '.')
  
  write('Season,Station_ID,Species,Matrix,n_obs,meanOBS, meanOTHR_obs, meanENER_obs, meanSHIP_obs, meanSALT_GO03_obs, n_all, meanOTHR_all, meanENER_all, meanSHIP_all, meanSALT_GO03_all',
        file = fData, append = FALSE)
  
  for (iMon in MONs) {
    for (iSpec in c(SPECs, 'SOX')) {
      for (iMtrx in allMATRICEs[[iSpec]]) {
        for (iStat in myStations) {# get data ----
          pltOBS = rep(NA, nT)
          pltOBS = valOBS[[iMon]][[iSpec]][[iMtrx]][[iStat]]$timeser$value
          if ( is.null(pltOBS) || length(pltOBS) == 0) { pltOBS = rep(NA, nT) }
          
          pltSIM_base = valSIM[[iMon]][['base']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_sp13 = valSIM[[iMon]][['sp13.corr']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_ov14 = valSIM[[iMon]][['ov14.corr']][[iSpec]][[iMtrx]][[iStat]]
          pltSIM_zero = valSIM[[iMon]][['zero']][[iSpec]][[iMtrx]][[iStat]]
          
          pltSIM_SHIP = pltSIM_base - pltSIM_sp13
          pltSIM_ENER = pltSIM_base - pltSIM_zero
          pltSIM_SALT_GO03 = pltSIM_base - pltSIM_ov14
          pltSIM_OTHR = pltSIM_base - pltSIM_SHIP - pltSIM_ENER - pltSIM_SALT_GO03
          
          meanSALT_GO03_all = mean(pltSIM_SALT_GO03)
          meanSALT_GO03_obs = mean(pltSIM_SALT_GO03[!is.na(pltOBS)])
          meanSHIP_all = mean(pltSIM_SHIP)
          meanSHIP_obs = mean(pltSIM_SHIP[!is.na(pltOBS)])
          meanENER_all = mean(pltSIM_ENER)
          meanENER_obs = mean(pltSIM_ENER[!is.na(pltOBS)])
          meanOTHR_all = mean(pltSIM_OTHR)
          meanOTHR_obs = mean(pltSIM_OTHR[!is.na(pltOBS)])
          meanOBS = mean(pltOBS[!is.na(pltOBS)])
          
          n_obs = sum(!is.na(pltOBS))
          n_all = length(pltSIM_base)
          
          write(paste(iMon, iStat, iSpec, iMtrx, n_obs, meanOBS, meanOTHR_obs, meanENER_obs, meanSHIP_obs, meanSALT_GO03_obs, n_all, meanOTHR_all, meanENER_all, meanSHIP_all, meanSALT_GO03_all, sep = ','), 
                file = fData, append = TRUE)
        }
      }
    }
  }
}


# write out data for supplement ----
if(writeOutData) {
  myPos = names(myCells)
  nPos = length(myPos)
  headings = append(c('doy', 'hour'), myPos)
  
  
  for(iMon in MONs) {
    if(iMon == 'sum2008') {
      nT = 61*24
      from = 2008183
      to = 2008243
    } else if(iMon == 'win2008') {
      nT = 60*24
      from = 2008001
      to = 2008060
    }
    nDays = nT/24
    
    for(iScen in SCENs) {
      for(iSpec in SPECs[c(1,2,4,7)]) {
        fOut = paste('conc.timeseries.values', iMon, iScen, iSpec, 'moreStations','csv', sep = '.')
        
        tmpOut = array(0.0, dim = c(nT,nPos+2))
        tmpOut[,1] = rep(seq(from, length.out = nDays), each = 24)
        tmpOut[,2] = rep(0:23, nDays)
        
        for (iPos in 1:nPos) {
          strPos = myPos[iPos]
          tmpOut[,iPos+2] = valSIM[[iMon]][[iScen]][[iSpec]][1:nT,iPos]
        }
        write.table(tmpOut, fOut, col.names = headings, row.names = FALSE, sep = ',')
      }
    }
  }
  
}