library('ncdf4')
library('cmaqtools')
library('ctmeval')
source('./parser_v10_main.R')

# source('./handy_functions.R')

## save(list = ls(all=TRUE), file = "inData_SIM_OBS_n_wetdep.SCENs.RData")
## load("inData_SIM_OBS_n_wetdep.SCENs.RData")

### save(list = c('rawOBS', 'valOBS', 'myPositions', 'myCells', 'myGrid'), file = 'tmp.RData')

# Create plots for Daniel's publication I.
read.obs = FALSE
work.obs = FALSE
read.mod = FALSE
work.mod = FALSE
plot.dat = FALSE
plot.precip = FALSE
doStatistics = FALSE
writeOutData = TRUE

myGrid = griddesc('CD24')

# setup='effectSeaSalt'
# setup='seasalt3d'
setup='effectSeaSalt.v5'

if (setup %in% c('effectSeaSalt.v5', 'effectSeaSalt')) { myAero = 'aero5'
} else if (setup %in% c('seasalt3d')) { myAero = 'aero6'
} else { myAero = 'error'}

if (setup == 'seasalt3d') {
  mech = 'cb05tump_ae6_aq_ssa'
  strYear='2013'
} else if (setup == 'effectSeaSalt.v5') {
  mech = 'cb05tucl_ae5_aq_ssa'
  strYear='2008'
} else {
  mech = 'cb05cl_ae5_aq'
  strYear='2008'
}

if(myAero == 'aero6') {
  ssSO4Mass = 0.0776
  ssNaMass = 0.3086
  ssMgMass = 0.0368
  ssKMass = 0.0114
  ssCaMass = 0.0118
  ssClMass = 0.5538
  ssSeaCatMass = 0.3086+0.0368+0.0114+0.0118
} else if (myAero == 'aero5') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
}

myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63, 'HONO' = 45,
                 'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62,
                 'NO3' = 62, 'PNA' = 79, 'PAN' = 121,
                 'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                 'N' = 15, 'N2O5' = 108,
                 'ASO4I' = 96, 'ASO4J' = 96, 'ASO4K' = 96, 'SO2' = 64, 'S' = 32)

R = 8.314462



# functions ----
#' returns last character
#' 
#' @source http://stackoverflow.com/questions/7963898/extracting-the-last-n-characters-from-a-string-in-r
#' @author Andrie
#' @date Nov 1 '11 at 8:19
noLast = function(x, n = 1) {
  return(substr(x, 1, nchar(x)-n))
}
  

#' Test:
#' myInts = matrix(c(-1, 2, 3, 2, 3, 5), ncol = 2)
#' myTime = 1:7
#' myData1 = rep(1, length(myTime))
#' myData2 = myTime
sum_interval = function(ints, time, vals) {
  
  # if(iStat == 'DK0005R' && iSpec == 'Na') browser()
  if (length(vals) != length(time)) stop('Error in sum_interval: vals and time have different length')
  
  nInts = length(ints[,1])
  nVals = rep(0, nInts)
  otVals = rep(0, nInts)
  
  for (iI in 1:nInts) {
    tmpStrt = ints[iI, 1]
    tmpStop = ints[iI, 2]
    
    positions = as.logical(floor(((time >= tmpStrt)+(time < tmpStop))/2))
    
    nVals[iI] = sum(positions)
    otVals[iI] = sum(vals[positions])
  }
  
  otVals[nVals==0] = NaN
  
  return(list('otVals' = otVals, 'nVals' = nVals))
}

getYlim <- function(yMax, type) {
  if ( yMax == 0 ) {
    yLim = 1
  } else if ( type == 1 ) {
    yLim = ceiling(yMax/10^(floor(log10(yMax))-1))*10^(floor(log10(yMax))-1)
  } else if ( type == 2 ) {
    yLim = signif(yMax, digits = 1) * 2
  } else if ( type == 3 ) {
    yLim = signif(yMax, digits = 1)
    if(yLim < yMax) {
      yLim = signif(2*yMax-yLim, digits = 2)
    }
  } else {
    yLim = 1
  }
  
  return(yLim)
}



# input data ----
inDirOBS = '/media/neumannd/work_mn/66_Tools/pub_neumannd2015b/11_emep_wetdep_data/good'
inDirSIM = '/storage/neumannd/data/cctm/CD24/analysis'

MONs = c('win2008', 'sum2008')
SCENs = c('base', 'sp13.corr', 'ov14.corr', 'zero')
myStations = c('DE0001R', 'DE0002R', 'DE0007R', 'DE0009R', 'DE0044R', 'DK0005R', 'DK0008R', 'DK0031R', 'FI0017R', 'NO0001R', 'NO0056R', 'PL0002R', 'PL0004R', 'SE0014R')
nSTATIONS = length(myStations)
# all valid flags except of flag 781
validFlags = c(248, 247, 798, 797, 782, 781, 780, 771, 770, 741, 740, 680, 679, 678, 676, 675, 668, 665, 662, 660, 657, 656, 655, 654, 653, 652, 651, 650, 649, 648, 644, 640, 559, 558, 557, 556, 555, 532, 531, 521, 499, 498, 476, 475, 470, 458, 457, 450, 440, 420, 410, 394, 392, 390, 382, 380, 370, 299, 298, 276, 275, 258, 257, 250, 249, 220, 211, 210, 191, 190, 189, 188, 187, 186, 185, 147, 120, 111, 110, 103, 102, 101, 100, 0)
UNITs = list('NO' = 'kg N/ha','NO2' = 'kg N/ha', 'N' = 'kg N/ha',
             'HNO3' = 'kg N/ha', 'NO3' = 'kg N/ha', 'SNO3' = 'kg N/ha',
             'NH3' = 'kg N/ha', 'NH4'= 'kg N/ha', 'SNH4' = 'kg N/ha',
             'SO4' = 'kg S/ha', 'H2SO4' = 'kg S/ha', 'SO2' = 'kg N/ha', 'S' = 'kg S/ha',
             'precip' = 'mm')

if(myAero == 'aero6') { SPECs = c('NH4', 'NO3', 'SO4', 'Na', 'XSO4', 'Mg', 'K', 'Ca', 'N')
} else if (myAero == 'aero5') { SPECs = c('NH4', 'NO3', 'SO4', 'Na', 'XSO4', 'N')
}


# file list
## ls | sed -r 's/(^[A-Z]{2}[0-9]{4}[A-Z])/"\1"=c("\1/g' | tr '\n' ';' | sed 's/;/");/g' | tr ';' '\n'
myFiles = list("DE0001R"=c("DE0001R.20080101080000.20140501000000.wet_only_sampler.precipitation_amount.precip.52w.1w.DE03L_wados_1w_01.DE03L_by_volume..nas",
                           "DE0001R.20080101080000.20150130081645.wet_only_sampler..precip.52w.1w.DE03L_wados_1w_01.DE03L_IC.CORR.nas"),
               "DE0002R"=c("DE0002R.20080101080000.20101109000000.wet_only_sampler..precip.1y.1d.DE03L_wados_02...nas"),
               "DE0007R"=c("DE0007R.20080101080000.20090721000000.wet_only_sampler..precip.1y.1d.DE03L_wados_07...nas"),
               "DE0009R"=c("DE0009R.20080101080000.20140501000000.wet_only_sampler..precip.52w.1w.DE03L_wados_1w_09.DE03L_IC_a.CORR.nas",
                           "DE0009R.20080101080000.20140501000000.wet_only_sampler..precip.52w.1w.DE03L_wados_1w_09...nas"),
               "DE0044R"=c("DE0044R.20080101080000.20150130122413.wet_only_sampler..precip.52w.1w.DE03L_wados_1w_44...nas"),
               "DK0005R"=c("DK0005R.20071231070000.20140501000000.wet_only_sampler..precip.13mo.2w.DK01L_wados_05..CORR.nas",
                           "DK0005R.20071231070000.20140507065152.wet_only_sampler..precip.13mo.2w.DK01L_wados_05..CORR.nas"),
               "DK0008R"=c("DK0008R.20071231070000.20110901000000.wet_only_sampler.sulphate_corrected.precip.13mo.2w.DK01L_wados_08.DK01L_IC_a.CORR.nas",
                           "DK0008R.20071231070000.20140501000000.wet_only_sampler.precipitation_amount.precip.13mo.2w.DK01L_wados_08.DK01L_Precip_weighing.CORR.nas",
                           "DK0008R.20071231070000.20140507065104.wet_only_sampler..precip.13mo.2w.DK01L_wados_08..CORR.nas"),
               "DK0031R"=c("DK0031R.20071231070000.20150129114043.wet_only_sampler..precip.13mo.2w.DK01L_wados_31.DK01L_AAS..nas",
                           "DK0031R.20071231070000.20150129114852.wet_only_sampler..precip.13mo.2w.DK01L_wados_31.DK01L_ICan.CORR.nas"),
               "FI0017R"=c("FI0017R.20080107060000.20120601000000.bulk_sampler..precip.52w.1w.FI01L_ns17...nas"),
               "NO0001R"=c("NO0001R.20080101070000.20100416000000.bulk_sampler..precip.1y.1d.NO01L_bs_d_0001...nas"),
               "NO0056R"=c("NO0056R.20080101070000.20090506000000.bulk_sampler..precip.1y.1d.NO01L_bs_d_0056...nas"),
               "PL0002R"=c("PL0002R.20080101060000.20150128134338.bulk_sampler..precip.1y.1d.PL01L_bs_02...nas"),
               "PL0004R"=c("PL0004R.20080101060000.20140501000000.bulk_sampler..precip.1y.1d.PL01L_bs_04...nas",
                           "PL0004R.20080101060000.20150128134855.bulk_sampler.precipitation_amount.precip.1y.1d.PL01L_bs_04.PL01L_by_weight.CORR.nas"),
               "SE0014R"=c("SE0014R.20080101060000.20150127103342.wet_only_sampler..precip.1y.1d.SE01L_wados_14...nas"))


# read station data ----
if (read.obs) {
  rawOBS = list()
  
  for (iStat in myStations) {
    rawOBS[[iStat]] = list()
    theseFiles = myFiles[[iStat]]
    for (i1 in 1:length(theseFiles)) {
      rawOBS[[iStat]][[formatC(i1, format='d')]] = emep_file_parser(inDirOBS, theseFiles[i1])
    }
  }
  
  rm('theseFiles')
  gc()
  
}


# reworking observations ----
if (work.obs) {
  valOBS = list()
  
  for (iStat in myStations) {
    tmpOBS = list()
    
    skip = FALSE
    
    # get station location
    tmpOBS[['location']] = list('lat' = rawOBS[[iStat]][[1]]$addDataInfo[['Station latitude']],
                                  'lon' = rawOBS[[iStat]][[1]]$addDataInfo[['Station longitude']])
    
    # get station time
    tmpOBS[['start_time_yyyyddd']] = rawOBS[[iStat]][[1]]$timing$times[,1]
    tmpOBS[['start_time_hh']] = rawOBS[[iStat]][[1]]$timing$times[,2]
    tmpOBS[['end_time_yyyyddd']] = rawOBS[[iStat]][[1]]$timing$times[,3]
    tmpOBS[['end_time_hh']] = rawOBS[[iStat]][[1]]$timing$times[,4]
    
    tmpOBS[['start_time']] = rawOBS[[iStat]][[1]]$timing$times[,1] * 100 + rawOBS[[iStat]][[1]]$timing$times[,2]
    tmpOBS[['end_time']] = rawOBS[[iStat]][[1]]$timing$times[,3] * 100 + rawOBS[[iStat]][[1]]$timing$times[,4]
    
    tmpOBS[['vals']] = list()
    tmpOBS[['total_area']] = list()
    tmpOBS[['total_area_time']] = list()
    tmpOBS[['flags']] = list()
    tmpOBS[['units_v']] = list()
    tmpOBS[['units_ta']] = list()
    tmpOBS[['units_tat']] = list()
    
    for (i1 in 1:length(rawOBS[[iStat]])) {
      if(!skip) {
        theseOBS = rawOBS[[iStat]][[i1]]
        
        tmpStart = theseOBS$timing$times[,1] * 100 + theseOBS$timing$times[,2]
        tmpEnd = theseOBS$timing$times[,3] * 100 + theseOBS$timing$times[,4]
        
        if( (sum(tmpStart != tmpOBS[['start_time']]) != 0) 
            || (sum(tmpEnd != tmpOBS[['end_time']]) != 0) 
            || (length(tmpStart) != length(tmpOBS[['start_time']])) ) {
          # print(tmpStart)
          # print(tmpOBS[['start_time']])
          skip = TRUE
          warning(paste('Times at station', iStat, 'do not fit', sep = ' '))
        }
        
        if(!skip) {
          for (i2 in 1:theseOBS$nVars) {
            iSpec = theseOBS$measurements$titleVarsShort[i2]
            if (!(iSpec%in%names(tmpOBS$vals))) {
              tmpVals = theseOBS$measurements$variables[,i2]
              tmpFlags = theseOBS$flags$numflags[,i2,]
              tmpOBS$units_v[[iSpec]] = theseOBS$measurements$units[i2]
              
              # remove bad values (flags != valid)
              tmpOBS$flags[[iSpec]] = tmpFlags
              badVals = as.logical(rowSums(array(!(tmpFlags %in% validFlags), dim = dim(tmpFlags))))
              tmpVals[badVals] = NaN
              
              tmpOBS$vals[[iSpec]] = tmpVals
            }
          }
          
          if (sum(c('NO3', 'NH4') %in% names(tmpOBS$vals)) == 2) {
            tmpOBS$units_v[['N']] = tmpOBS$units_v[['NO3']]
            tmpOBS$flags[['N']] = cbind(tmpOBS$flags[['NO3']],tmpOBS$flags[['NH4']])
            tmpOBS$vals[['N']] = tmpOBS$vals[['NO3']] + tmpOBS$vals[['NH4']]
          }
        }
      }
    }
    
    # convert to 'mg X/m2' or to 'kg X/ha'
    # and correct units
    theseSpecs = intersect(names(tmpOBS$vals),SPECs)
    for(iSpec in theseSpecs) {
      ## mg/m2
      # tmpOBS$total_area[[iSpec]] = tmpOBS$vals[[iSpec]] * tmpOBS$vals$precip
      # tmpOBS$units_ta[[iSpec]] = paste(noLast(tmpOBS$units_v[[iSpec]]), 'm2', sep = '')
      
      ## kg/ha
      tmpOBS$total_area[[iSpec]] = tmpOBS$vals[[iSpec]] * tmpOBS$vals$precip * 10^(-2)
      tmpOBS$units_ta[[iSpec]] = paste('k', noLast(substr(tmpOBS$v_units[[iSpec]],2,100)), 'ha', sep = '')
      
      ## kg/hg/h
      tmpPeriods = tmpOBS$end_time_yyyyddd - tmpOBS$start_time_yyyyddd - (tmpOBS$start_time_yyyyddd < 2008000) * 635
      tmpOBS$total_area_time[[iSpec]] = tmpOBS$total_area[[iSpec]] / tmpPeriods
      tmpOBS$units_tat[[iSpec]] = paste(tmpOBS$units_ta[[iSpec]], '/d', sep = '')
    }
    
    valOBS[[iStat]] = tmpOBS
  }
  
  myPositions = list()
  myCells = list()
  for(iPos in myStations) {
    myPositions[[iPos]] = NULL
    
    for(iSpec in SPECs) {
      if(!is.null(valOBS[[iPos]]$location)) {
        myPositions[[iPos]] = list('lat' = as.numeric(valOBS[[iPos]]$location$lat),
                                   'lon' = as.numeric(valOBS[[iPos]]$location$lon))
      }
    }
    
    if (is.null(myPositions[[iPos]])) {
      stop(paste('No data available for station ', iStat, '.', sep = ''))
    } else {
      myCells[[iPos]] = findcell(myPositions[[iPos]], myGrid)
    }
  }
  
  rm('tmpOBS', 'tmpStart', 'tmpEnd', 'theseOBS', 
     'skip', 'tmpVals', 'tmpFlags', 'badVals',
     'tmpPeriods')
  gc()
  
}




# read model data ----
if (read.mod) {
  rawSIM = list()
  
  for (iMon in MONs) {
    if(iMon == 'sum2008' || iMon == 'sum') {
      nT = 61
      from = 2008183
      to = 2008243
    } else if(iMon == 'win2008' || iMon == 'win') {
      nT = 60
      from = 2008001
      to = 2008060
    }
    nTh = nT * 24
    
    rawSIM[[iMon]] = list()
    rawSIM[[iMon]]$time_yyyyddd = rep((from:to)*100, each = 24)
    rawSIM[[iMon]]$time_hh = rep((0:23), length.out = nT*24)
    rawSIM[[iMon]]$time = rep((from:to)*100, each = 24)+rep((0:23), length.out = nT*24)
    
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('  READING MET FILE')
    ncMet <- nc_open(paste(inDirSIM, paste('METCRO2D', iMon, 'short', sep = '.'), sep = '/'))
    
    nTSTEP = ncMet$dim$TSTEP$len
    nCOL = ncMet$dim$COL$len
    nROW = ncMet$dim$ROW$len
    
    valRC = matrix(ncvar_get(ncMet, 'RC')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    valRN = matrix(ncvar_get(ncMet, 'RN')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    
    
    nc_close(ncMet)
    
    myStart = c(1,1,1,1)
    myCount = c(-1,-1,-1,nTSTEP)
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      if (iScen %in% c('surf','sp13.corr', 'ov14.corr','sp13.noSp')) {
        ncId = nc_open(paste(inDirSIM, paste('WETDEP1.CD24_', setup, '.', iScen,
                                          '_', mech, '_', iMon, '.short', sep = ''), 
                             sep = '/'))
      } else {
        ncId = nc_open(paste(inDirSIM, paste('WETDEP1.CD24_', setup, '.', iScen,
                                          '_', mech, '_', iMon, sep = ''), 
                             sep = '/'))
      }
      
      print('    Reading sNH4')
      tmpNH3 = ( matrix(ncvar_get(ncId, 'NH3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) 
                 / myMolMass$NH3 * myMolMass$N )
      tmpNH4 = ( matrix(ncvar_get(ncId, 'ANH4I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4I
                 + matrix(ncvar_get(ncId, 'ANH4J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4J
                 + matrix(ncvar_get(ncId, 'ANH4K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4K
      ) * myMolMass$N
      rawSIM[[iMon]][[iScen]]$NH3 = tmpNH3
      rawSIM[[iMon]][[iScen]]$NH4 = tmpNH3 + tmpNH4
      
      print('    Reading sNO3')
      tmpHNO3 = ( matrix(ncvar_get(ncId, 'HNO3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) 
                  / myMolMass$HNO3 * myMolMass$N )
      tmpNO3 = ( matrix(ncvar_get(ncId, 'ANO3I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3I
                 + matrix(ncvar_get(ncId, 'ANO3J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3J
                 + matrix(ncvar_get(ncId, 'ANO3K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3K
                 ) * myMolMass$N
      tmpNothr = ( matrix(ncvar_get(ncId, 'NO', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$NO
                   + matrix(ncvar_get(ncId, 'NO2', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$NO2
                   + matrix(ncvar_get(ncId, 'NO3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$NO3
                   + matrix(ncvar_get(ncId, 'N2O5', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$N2O5
                   + matrix(ncvar_get(ncId, 'HONO', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$HONO
                   + matrix(ncvar_get(ncId, 'PAN', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$PAN
                   + matrix(ncvar_get(ncId, 'PNA', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$PNA
                   ) * myMolMass$N
      rawSIM[[iMon]][[iScen]]$HNO3 = tmpHNO3
      rawSIM[[iMon]][[iScen]]$NO3m = tmpHNO3 + tmpNO3
      rawSIM[[iMon]][[iScen]]$NO3 = tmpHNO3 + tmpNO3 + tmpNothr
      rawSIM[[iMon]][[iScen]]$N = tmpHNO3 + tmpNO3 + tmpNothr + tmpNH3 + tmpNH4
      
      print('    Reading SO4')
      rawSIM[[iMon]][[iScen]]$SO4 = ( matrix(ncvar_get(ncId, 'ASO4I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4I
                                      + matrix(ncvar_get(ncId, 'ASO4J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4J
                                      + matrix(ncvar_get(ncId, 'ASO4K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4K
      ) * myMolMass$S
      if (myAero == 'aero6') {
        print('    Reading Na')
        rawSIM[[iMon]][[iScen]]$Na = ( matrix(ncvar_get(ncId, 'ANAJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       + matrix(ncvar_get(ncId, 'ASEACAT', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / ssSeaCatMass*ssNaMass
        )
        print('    Reading corr SO4')
        rawSIM[[iMon]][[iScen]]$XSO4 = (rawSIM[[iMon]][[iScen]]$SO4 -
                                          rawSIM[[iMon]][[iScen]]$Na / ssNaMass * ssSO4Mass / 3)
        print('    Reading other cations')
        rawSIM[[iMon]][[iScen]]$Mg = ( matrix(ncvar_get(ncId, 'AMGJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       + matrix(ncvar_get(ncId, 'ASEACAT', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / ssSeaCatMass*ssMgMass
        )
        rawSIM[[iMon]][[iScen]]$K = ( matrix(ncvar_get(ncId, 'AKJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                      + matrix(ncvar_get(ncId, 'ASEACAT', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / ssSeaCatMass*ssKMass
        )
        rawSIM[[iMon]][[iScen]]$Ca = ( matrix(ncvar_get(ncId, 'ACAJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       + matrix(ncvar_get(ncId, 'ASEACAT', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / ssSeaCatMass*ssCaMass
        )
      } else {
        print('    Reading Na')
        rawSIM[[iMon]][[iScen]]$Na = ( matrix(ncvar_get(ncId, 'ANAJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       + matrix(ncvar_get(ncId, 'ANAK', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       )*ssRealNa2Cat
        
        print('    Reading corr SO4')
        rawSIM[[iMon]][[iScen]]$XSO4 = (rawSIM[[iMon]][[iScen]]$SO4 -
                                          rawSIM[[iMon]][[iScen]]$Na / ssRealNa2Cat / ssNaMass * ssSO4Mass / 3)
      }
      
      nc_close(ncId)
      
      rawSIM[[iMon]][[iScen]]$precip = valRN + valRC
    }
  }
  
  rm('tmpNH3', 'tmpNH4', 'tmpNO3', 'tmpHNO3', 'tmpNothr', 'valRC', 'valRN', 'ncId')
  gc()
  
}


# reworking model ----
if (work.mod) {
  valSIM = list()
  
  theseTimes = c(rawSIM$win2008$time, rawSIM$sum2008$time)
  
  for (iLoc in 1:nSTATIONS) {
    iStat = myStations[iLoc]
    tmpSIM = list()
    
    tmpSIM$start_time_yyyyddd = valOBS$start_time_yyyyddd
    tmpSIM$start_time_hh = valOBS$start_time_hh
    tmpSIM$end_time_yyyyddd = valOBS$end_time_yyyyddd
    tmpSIM$end_time_hh = valOBS$end_time_hh
    tmpSIM$start_time = valOBS$start_time
    tmpSIM$end_time = valOBS$end_time
    
    theseSpecs = intersect(names(valOBS[[iStat]]$vals),SPECs)
    theseInts = matrix(c(valOBS[[iStat]]$start_time, valOBS[[iStat]]$end_time), ncol = 2)
    
    for(iScen in SCENs) {
      tmpSIM[[iScen]] = list()
      # print(theseSpecs)
      for (iSpec in c(theseSpecs, 'precip')) { # TODO
      # for (iSpec in theseSpecs[if(length(which('N' == theseSpecs)) == 0){1:length(theseSpecs)}else{-which('N' == theseSpecs)}]) { # TODO
        # print(paste(iLoc, iStat, iScen, iSpec))
        theseData = c(rawSIM$win2008[[iScen]][[iSpec]][,iLoc], rawSIM$sum2008[[iScen]][[iSpec]][,iLoc])
        
        ## kg/ha/[time periods defined in theseInts]
        tmpVALS = sum_interval(theseInts, theseTimes, theseData)
        names(tmpVALS)[which(names(tmpVALS)=='otVals')] = 'otVals_area'
        tmpSIM[[iScen]][[iSpec]] = tmpVALS
        tmpSIM[[iScen]][[iSpec]]$unit_a = if(iSpec %in% names(UNITs)) UNITs[[iSpec]] else 'kg/ha'
        
        ## kg/ha/h
        tmpSIM[[iScen]][[iSpec]]$otVals_area_time = tmpVALS$otVals_area / (tmpVALS$nVals / 24)
        tmpSIM[[iScen]][[iSpec]]$unit_at = paste(tmpSIM[[iScen]][[iSpec]]$unit_a, '/d', sep = '')
        
        if(iSpec == 'precip') {
          tmpSIM[[iScen]][[iSpec]]$otVals_area_time = tmpSIM[[iScen]][[iSpec]]$otVals_area_time * 10
          tmpSIM[[iScen]][[iSpec]]$otVals_area = tmpSIM[[iScen]][[iSpec]]$otVals_area * 10
        }
      }
    }
    
    valSIM[[iStat]] = tmpSIM 
  }
  
  # rm('theseSpecs', 'theseInts', 'theseTimes', 'theseData', 'iStat')
  rm('theseInts', 'theseTimes', 'theseData', 'iStat')
  gc()
  
}


# plot data ----
if (plot.dat) {
  
#   # iSpec = 'NH4'
#   iSpec = 'Na'
#   # iSpec = 'SO4'
#   
#   # iStat = 'DE0001R'
#   iStat = 'DK0005R'
#   
#   tmpO = valOBS[[iStat]]$total_area_time[[iSpec]]
#   tmpM = valSIM[[iStat]]$base[[iSpec]]$otVals_area_time
#   tmpSt = valOBS[[iStat]]$start_time
#   tmpSp = valOBS[[iStat]]$end_time
#   
#   plot(tmpSp, tmpO)
#   lines(tmpSp, tmpM)
  
  
  # plot data: define output file type ----
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'A4')
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
  
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('SO4' = expression("SO4"[4]^"2-" ~ 'dep [kg S' ~ ha^-1 ~ d^-1 * ']'),
                  'Na' = expression("Na"^"+" ~ 'dep [kg' ~ ha^-1 ~ d^-1 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'dep [kg S' ~ ha^-1 ~ d^-1 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'dep [kg N' ~ ha^-1 ~ d^-1 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'dep [kg N' ~ ha^-1 ~ d^-1 * ']'),
                  'N' = expression("N"['total'] ~ 'dep [kg N' ~ ha^-1 ~ d^-1 * ']'))
  
  for(iSpec in SPECs) {  
#     postscript(file = paste('WETDEP.timeseries', setup, iSpec, 'moreStations', 'eps', sep = '.'), onefile=TRUE,
#                horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # postscript(file = paste('WETDEP.timeseries', setup, iSpec, 'threeStations', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # pdf(file = paste('WETDEP.timeseries', setup, iSpec, 'threeStations', 'SCENs', 'pdf', sep = '.'), onefile=TRUE,
    #     paper = 'special', width = 10, height = 6.5)
    pdf(file = paste('WETDEP.timeseries', setup, iSpec, 'allStations', 'SCENs', 'pdf', sep = '.'), onefile=TRUE,
              paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # plot data: define screens ----
    ShlB = 0.07;  ShrB = 0.992; ShdB = 0.035 # left, right, distance
    SvtB = 0.93;  SvbB = 0.05;  SvdB = 0.01  # top, bottom, distance
    ShBox = 0.06
    ShcB = ShlB+(ShrB-ShlB)*3/6
    
    iScreen = 0
    goodStations = c()
    for(iStat in myStations) if(iSpec %in% names(valOBS[[iStat]]$vals) || iSpec == 'N') goodStations = c(goodStations, iStat)
    
    for(iStat in goodStations){
    # for(iStat in goodStations[goodStations %in% c('DE0001R', 'DE0002R', 'DE0009R')]){
      if(iScreen%%13 == 0) {
        if(iScreen != 0) plot.new()
        iScreen = 1
        
        split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                           # top left, time series
                           c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # top right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # center left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # center right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # bottom left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           # bottom right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
        ))
        
        # make legend ----
        screen(iScreen)
        plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
        
        legend('left', legend = c('obs', 'GO03', 'SP13', 'OV14', 'zero', '  year 2008'),
               col = c('darkgrey', 'cyan', 'orange', 'darkviolet', 'red', 'white'), lwd = c(NA,2,2,2,2, NA), 
               lty = c(NA, NA, NA, NA, NA, NA), pch = c(15, 19, 1, 8, 4, NA),
               bg = 'white', horiz = TRUE, inset = 0.02,
               pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
      }
      
      #for(iMon in c('win2008', 'win2008')) {
      for(iMon in MONs) {
        refDate=2008001
        refPOSIXint = 1199145600
        strYear='2008'
        if(iMon == 'sum2008') {
          from = 2008183;  to = 2008243
        } else if(iMon == 'win2008') {
          from = 2008001;  to = 2008060
        }
        xLims = refPOSIXint+c(from-refDate, to-refDate)*3600*24
        
        # prepare data ----
        tmpStrt = valOBS[[iStat]]$start_time_yyyyddd + valOBS[[iStat]]$start_time_hh/24
        tmpStop = valOBS[[iStat]]$end_time_yyyyddd + valOBS[[iStat]]$end_time_hh/24
        tmpStrt[tmpStrt < 2008001] = 2008001 + tmpStrt[tmpStrt < 2008001] - 2007366 - 1
        tmpStop[tmpStop < 2008001] = 2008001 + tmpStop[tmpStop < 2008001] - 2007366 - 1
        
        timeAxisStrt = as.POSIXct((tmpStrt - refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        timeAxisStop = as.POSIXct((tmpStop - refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        timeAxisMean = as.POSIXct(((tmpStrt + tmpStop)/2-refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        timeAxisMean[timeAxisMean < refPOSIXint] = as.POSIXct(0, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        pltOBS = valOBS[[iStat]]$total_area_time[[iSpec]]
        pltSIMbase = valSIM[[iStat]][['base']][[iSpec]]$otVals_area_time
        pltSIMsp13 = valSIM[[iStat]][['sp13.corr']][[iSpec]]$otVals_area_time
        pltSIMov14 = valSIM[[iStat]][['ov14.corr']][[iSpec]]$otVals_area_time
        pltSIMzero = valSIM[[iStat]][['zero']][[iSpec]]$otVals_area_time
        pltOBSnoNA = pltOBS
        pltOBSnoNA[is.na(pltOBS)] = 0.0
        
        #' positions in the data arrays which will be considered for y-axis
        #' scaling and box plots.
        dX = as.integer(timeAxisStop[1]) - as.integer(timeAxisStrt[1])
        indices = as.logical(floor(((timeAxisStrt > (xLims[1] - dX/7)) + (timeAxisStop < (xLims[2] + dX/7)))/2))
        
        # if(iStat == 'DK0031R' && iSpec == 'NO3') browser()
        
        myMax = max(c(max(pltOBS[indices], na.rm = TRUE), 
                      max(pltSIMbase[indices]),
                      max(pltSIMsp13[indices]),
                      max(pltSIMov14[indices]),
                      max(pltSIMzero[indices])), na.rm = TRUE)
        myLim = getYlim(myMax, 3)
        if (iStat == 'DE0009R') { myLim = 0.05
        } else if (iStat == 'DE0002R') { myLim = 0.25
        } else if (iStat == 'DE0001R') { if (iMon == 'win2008') myLim = 0.035 else myLim = 0.1}
        
        # start plotting ----
        iScreen = iScreen + 1 
        
        screen(iScreen)
        plot(timeAxisStrt, pltOBS,
             ylim = c(0,myLim), xlim = xLims,
             type = 'n', ann = FALSE, 
             yaxt = 'n', xaxt = 'n')
        
        polygon(c(timeAxisStrt[1],drop(array(t(matrix(c(timeAxisStrt, timeAxisStop), ncol = 2)), dim = c(length(timeAxisStrt)*2))), timeAxisStop[length(timeAxisStop)]), 
                  append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
                col = 'darkgrey', border = FALSE)
        
        points(timeAxisMean, pltSIMbase,
               col = 'cyan', pch = 19, cex = 0.8)
        points(timeAxisMean, pltSIMsp13,
               col = 'orange', pch = 1, cex = 0.8)
        points(timeAxisMean, pltSIMov14,
               col = 'darkviolet', pch = 8, cex = 0.8)
        points(timeAxisMean, pltSIMzero,
               col = 'red', pch = 4, cex = 0.7)
        
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
        
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(rawOBS[[iStat]][['1']]$addDataInfo[['Station name']], line = -1)
        
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        boxplot(apply(rbind(pltOBS[indices], pltSIMbase[indices], pltSIMsp13[indices], pltSIMov14[indices], pltSIMzero[indices])[,!is.na(pltOBS[indices])], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'cyan', 'orange', 'darkviolet', 'red'), range = 0)
        points(1:5, apply(rbind(pltOBS[indices], pltSIMbase[indices], pltSIMsp13[indices], pltSIMov14[indices], pltSIMzero[indices]), MARGIN = 1, FUN = mean, na.rm = TRUE),
               pch = 18, col = c('black', 'cyan', 'red', 'darkviolet', 'red'))
        
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
  
}


# plot precip ----
if (plot.precip) {
  
  yAxisLab = list('precip' = 'precipitation [mm]')
  iSpec = 'precip'
  
  # pdf(file = paste('WETDEP.timeseries', setup, iSpec, 'threeStations', 'SCENs', 'pdf', sep = '.'), onefile=TRUE,
  #     paper = 'special', width = 10, height = 6.5)
  pdf(file = paste('WETDEP.timeseries', setup, iSpec, 'allStations', 'SCENs', 'pdf', sep = '.'), onefile=TRUE,
      paper = 'special', width = 10, height = 6.5)
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  
  # plot data: define screens ----
  ShlB = 0.07;  ShrB = 0.992; ShdB = 0.035 # left, right, distance
  SvtB = 0.93;  SvbB = 0.05;  SvdB = 0.01  # top, bottom, distance
  ShBox = 0.06
  ShcB = ShlB+(ShrB-ShlB)*3/6
  
  iScreen = 0
  goodStations = c()
  for(iStat in myStations) if(iSpec %in% names(valOBS[[iStat]]$vals) || iSpec == 'N') goodStations = c(goodStations, iStat)
  
  for(iStat in goodStations){
    # for(iStat in goodStations[goodStations %in% c('DE0001R', 'DE0002R', 'DE0009R')]){
    if(iScreen%%13 == 0) {
      if(iScreen != 0) plot.new()
      iScreen = 1
      
      split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                         # top left, time series
                         c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                         c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                         # top right, time series
                         c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                         c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                         # center left, time series
                         c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                         c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                         # center right, time series
                         c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                         c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                         # bottom left, time series
                         c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                         c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                         # bottom right, time series
                         c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                         c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
      ))
      
      # make legend ----
      screen(iScreen)
      plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
      
      legend('left', legend = c('obs', 'mod', '  year 2008'),
             col = c('darkgrey', 'blue', 'white'), lwd = NA, lty = NA,
             pch = c(15, 19, NA),
             bg = 'white', horiz = TRUE, inset = 0.02,
             pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
    }
    
    #for(iMon in c('win2008', 'win2008')) {
    for(iMon in MONs) {
      refDate=2008001
      refPOSIXint = 1199145600
      strYear='2008'
      if(iMon == 'sum2008') {
        from = 2008183;  to = 2008243
      } else if(iMon == 'win2008') {
        from = 2008001;  to = 2008060
      }
      xLims = refPOSIXint+c(from-refDate, to-refDate)*3600*24
      
      # prepare data ----
      tmpStrt = valOBS[[iStat]]$start_time_yyyyddd + valOBS[[iStat]]$start_time_hh/24
      tmpStop = valOBS[[iStat]]$end_time_yyyyddd + valOBS[[iStat]]$end_time_hh/24
      tmpStrt[tmpStrt < 2008001] = 2008001 + tmpStrt[tmpStrt < 2008001] - 2007366 - 1
      tmpStop[tmpStop < 2008001] = 2008001 + tmpStop[tmpStop < 2008001] - 2007366 - 1
      
      timeAxisStrt = as.POSIXct((tmpStrt - refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
      timeAxisStop = as.POSIXct((tmpStop - refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
      timeAxisMean = as.POSIXct(((tmpStrt + tmpStop)/2-refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
      timeAxisMean[timeAxisMean < refPOSIXint] = as.POSIXct(0, tz = 'UTC', origin = "2008-01-01 00:00:00")
      
      pltOBS = valOBS[[iStat]]$vals[[iSpec]]
      pltSIMbase = valSIM[[iStat]][['base']][[iSpec]]$otVals_area
      pltOBSnoNA = pltOBS
      pltOBSnoNA[is.na(pltOBS)] = 0.0
      
      #' positions in the data arrays which will be considered for y-axis
      #' scaling and box plots.
      dX = as.integer(timeAxisStop[1]) - as.integer(timeAxisStrt[1])
      indices = as.logical(floor(((timeAxisStrt > (xLims[1] - dX/7)) + (timeAxisStop < (xLims[2] + dX/7)))/2))
      
      myMax = max(c(max(pltOBS[indices], na.rm = TRUE), 
                    max(pltSIMbase[indices])), na.rm = TRUE)
      myLim = getYlim(myMax, 3)
      # if (iStat == 'DE0009R') { myLim = 0.05
      # } else if (iStat == 'DE0002R') { myLim = 0.25
      # } else if (iStat == 'DE0001R') { if (iMon == 'win2008') myLim = 0.035 else myLim = 0.1}
      
      # start plotting ----
      iScreen = iScreen + 1 
      
      screen(iScreen)
      plot(timeAxisStrt, pltOBS,
           ylim = c(0,myLim), xlim = xLims,
           type = 'n', ann = FALSE, 
           yaxt = 'n', xaxt = 'n')
      
      polygon(c(timeAxisStrt[1],drop(array(t(matrix(c(timeAxisStrt, timeAxisStop), ncol = 2)), dim = c(length(timeAxisStrt)*2))), timeAxisStop[length(timeAxisStop)]), 
              append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
              col = 'darkgrey', border = FALSE)
      
      points(timeAxisMean, pltSIMbase,
             col = 'blue', pch = 19, cex = 0.8)
      
      if ((iScreen-1)%%2 == 1) axis(2)
      # if(iScreen > 12) axis(1)
      
      yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
      yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
      if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
      if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
      if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
      if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
      # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
      if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
      if ((iScreen-1)%%4 == 3) title(rawOBS[[iStat]][['1']]$addDataInfo[['Station name']], line = -1)
      
      iScreen = iScreen + 1 
      screen(iScreen)
      # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
      #       are available as observations and measurements.
      boxplot(apply(rbind(pltOBS[indices], pltSIMbase[indices])[,!is.na(pltOBS[indices])], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'blue'), range = 0)
      points(1:2, apply(rbind(pltOBS[indices], pltSIMbase[indices]), MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'blue'))
      
    }
  }
  close.screen(all.screens = TRUE)
  dev.off()
}


# do statistics ----
if(doStatistics) {
  units = list()
  fRAE = paste('stat', 'wetdep', setup, mech, strYear, 'moreStations', 'SCENs', 'csv', sep = '.')
  
  write('SPECIES,SEASON,STATION,CASE,n,rae,mnb,cor,mean.sim,mean.obs,median.sim,median.obs', 
        file = fRAE, append = FALSE)
  
  for(iMon in MONs) {
    refDate=2008001
    refPOSIXint = 1199145600
    strYear='2008'
    if(iMon == 'sum2008') {
      from = 2008183;  to = 2008243
    } else if(iMon == 'win2008') {
      from = 2008001;  to = 2008060
    }
    xLims = refPOSIXint+c(from-refDate, to-refDate)*3600*24
    
    for(iScen in SCENs) {
      if (iScen == 'base') { mySPECs = c(SPECs[c(1,2,4,6)], 'precip')
      } else {mySPECs = SPECs[c(1,2,4,6)]}
      # for(iSpec in SPECs) {
      # for(iSpec in SPECs) {
      # for(iSpec in SPECs[c(1,2,4,6)]) {
      for(iSpec in mySPECs) {
        
        goodStations = c()
        for(iStat in myStations) if(iSpec %in% names(valOBS[[iStat]]$vals)) goodStations = c(goodStations, iStat)
        
        for (iStat in goodStations) {
          # print(paste(iMon, iScen, iSpec, iStat))
          
          # time axis
          tmpStrt = valOBS[[iStat]]$start_time_yyyyddd + valOBS[[iStat]]$start_time_hh/24
          tmpStop = valOBS[[iStat]]$end_time_yyyyddd + valOBS[[iStat]]$end_time_hh/24
          tmpStrt[tmpStrt < 2008001] = 2008001 + tmpStrt[tmpStrt < 2008001] - 2007366 - 1
          tmpStop[tmpStop < 2008001] = 2008001 + tmpStop[tmpStop < 2008001] - 2007366 - 1
          
          timeAxisStrt = as.POSIXct((tmpStrt - refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
          timeAxisStop = as.POSIXct((tmpStop - refDate)*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
          
          #' positions in the data arrays which will be considered for y-axis
          #' scaling and box plots.
          dX = as.integer(timeAxisStop[1]) - as.integer(timeAxisStrt[1])
          indices = as.logical(floor(((timeAxisStrt > (xLims[1] - dX/7)) + (timeAxisStop < (xLims[2] + dX/7)))/2))
          
          if (iSpec == 'precip') {
            obs = valOBS[[iStat]]$vals[[iSpec]][indices]
            sim = valSIM[[iStat]][[iScen]][[iSpec]]$otVals_area[indices]
            validVals = !is.na(valOBS[[iStat]]$total_area_time[['N']][indices] + valSIM[[iStat]][[iScen]][['N']]$otVals_area_time[indices])
          } else {
            obs = valOBS[[iStat]]$total_area_time[[iSpec]][indices]
            sim = valSIM[[iStat]][[iScen]][[iSpec]]$otVals_area_time[indices]
            validVals = !is.na(obs + sim)
          }
          
          n = sum(validVals)
          rae = sum(abs(obs-sim), na.rm = TRUE)/sum(validVals)
          mean.sim = mean(sim[validVals])
          mean.obs = mean(obs[validVals])
          median.sim = median(sim[validVals])
          median.obs = median(obs[validVals])
          mnb = MNB(obs, sim)
          myCor = cor(sim[validVals], obs[validVals], method = 'spearman')
          # if (iStat == 'DE0002R' && iSpec == 'precip') browser()
          
          # write(paste(iSpec, iMon, iStat, iScen, formatC(rae, format = 'f', width = 4), sep = ','), 
          #       file = fRAE, append = TRUE)
          write(paste(iSpec, iMon, iStat, iScen, n, rae, mnb, myCor, mean.sim, mean.obs, median.sim, median.obs, sep = ','), 
                file = fRAE, append = TRUE)
        }
      }
    }
  }
}



# write out data for supplement ----
if(writeOutData) {
  mySpecs = c('NH4', 'NO3', 'N', 'precip')
  
  for (iScen in SCENs) {
    for (iStat in myStations) {
      fOut = paste('wetdep.timeseries.values', iStat, iScen, 'moreStations','csv', sep = '.')
      
      tmpVals = valSIM[[iStat]][[iScen]]
      validVals = !is.na(tmpVals[[mySpecs[1]]]$otVals_area_time)
      
      headings = c('doy_start', 'hour_start', 'doy_end', 'hour_end', 'n_vals')
      for (iSpec in mySpecs) {headings = c(headings, paste(iSpec, 'in', tmpVals[[iSpec]]$unit_at, sep = ' '))}
      
      tmpOut = array(0.0, dim = c(sum(validVals),5+length(mySpecs)))
      tmpOut[,1] = valOBS[[iStat]]$start_time_yyyyddd[validVals]
      tmpOut[,2] = valOBS[[iStat]]$start_time_hh[validVals]
      tmpOut[,3] = valOBS[[iStat]]$end_time_yyyyddd[validVals]
      tmpOut[,4] = valOBS[[iStat]]$end_time_hh[validVals]
      tmpOut[,5] = tmpVals[[mySpecs[1]]]$nVals[validVals]
      
      for (iS in 1:length(mySpecs)) {
        tmpOut[,iS+5] = tmpVals[[mySpecs[iS]]]$otVals_area_time[validVals]
      }
      write.table(tmpOut, fOut, col.names = headings, row.names = FALSE, sep = ',')
    }
  }
}