library('ncdf4')
library('cmaqtools')
library('ctmeval')

source('./handy_functions.R')

## save(list = ls(all=TRUE), file = "inData_SIM_OBS_moreStations_NO2_std_pub.RData")
## load("inData_SIM_OBS_moreStations_NO2_std_pub.RData")

# Create plots for Daniel's extended Abstract for the ITM 2015 in Montpellier.
getObsData = FALSE
getSimData = FALSE
plotData = FALSE
plotType = 2 # 1 == lines/steps; 2 == points; 
doStatistics = TRUE
doSalImpact = FALSE
doCorr = FALSE
writeOutData = FALSE

myGrid = griddesc('CD24')

# setup='effectSeaSalt'
# setup='seasalt3d'
setup='effectSeaSalt.v5'

if (setup == 'seasalt3d') {
  mech = 'cb05tump_ae6_aq_ssa'
  strYear='2013'
} else if (setup == 'effectSeaSalt.v5') {
  mech = 'cb05tucl_ae5_aq_ssa'
  strYear='2008'
} else {
  mech = 'cb05cl_ae5_aq'
  strYear='2008'
}

if(setup == 'seasalt3d') {
  ssSO4Mass = 0.0776
  ssNaMass = 0.3086
  ssClMass = 0.5538
  ssSeaCatMass = 0.3086+0.0368+0.0114+0.0118
} else if (setup == 'effectSeaSalt') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
} else if (setup == 'effectSeaSalt.v5') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
}

# functions and constant ----
make_daily_mean <- function(series) {
  dim_old = dim(series)
  
  if (length(dim_old) <= 1) {
    n_old = length(series)
    n_new = n_old/24
    
    means = rep(0.0, n_new)
    
    for(i1 in 1:n_new) {
      means[i1] = mean(series[(1:24)+(i1-1)*24])
    }
  } else if (length(dim_old) == 2) {
    n_old = dim_old[2]
    n_new = n_old/24
    dim_new = c(dim_old[1], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,i1] = rowMeans(series[,(1:24)+(i1-1)*24], dims = 1)
    }
  } else if (length(dim_old) == 3) {
    n_old = dim_old[3]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,i1] = rowMeans(series[,,(1:24)+(i1-1)*24], dims = 2)
    }
  } else if (length(dim_old) == 4) {
    n_old = dim_old[4]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], dim_old[3], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,,i1] = rowMeans(series[,,,(1:24)+(i1-1)*24], dims = 3)
    }
  }
  
  return(means)
}


getYlim <- function(yMax, type) {
  if ( yMax == 0 ) {
    yLim = 1
  } else if ( type == 1 ) {
    yLim = ceiling(yMax/10^(floor(log10(yMax))-1))*10^(floor(log10(yMax))-1)
  } else if ( type == 2 ) {
    yLim = signif(yMax, digits = 1) * 2
  } else if ( type == 3 ) {
    yLim = signif(yMax, digits = 1)
    if(yLim < yMax) {
      yLim = signif(2*yMax-yLim, digits = 2)
    }
  } else {
    yLim = 1
  }
  
  return(yLim)
}


myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63,
                 'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62,
                 'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                 'N' = 15,
                 'ASO4I' = 96, 'ASO4J' = 96, 'ASO4K' = 96, 'SO2' = 64, 'S' = 32)

R = 8.314462


# set some parameters ----
CD24 = griddesc('CD24')
DBaccess <- list(name="neumannd-pg-emep_v02.1",uid="neumannd",pwd="nd$1,")

inDir = '/storage/neumannd/data/cctm/CD24/analysis'

# MONs = c('win2007', 'sum2008', 'win2008')
# MONs = c('win2008')
MONs = c('win2008', 'sum2008')
# MONs = c('win2007', 'win2008')

# SPECs = c('SNH4', 'SNO3', 'SO4', 'XSO4', 'Na')
# MATRICES = list('SNH4'='air+aerosol', 'SNO3'='air+aerosol', 'SO4'='aerosol', 'XSO4'='aerosol', 'Na'='aerosol')
# UNITS = list('SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3')
# SPECs = c('Na', 'SNH4')
SPECs = c('NO2')
MATRICES = list('NO2' = 'air', 'SNH4'='air+aerosol', 'SNO3'='air+aerosol', 'SO4'='aerosol', 'XSO4'='aerosol', 'Na'='aerosol', 'NH4'='aerosol', 'NO3'='aerosol')
UNITS = list('NO2'='ug N/m3', 'SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3', 'NH4'='ug N/m3', 'NO3'='ug N/m3')
# SPECs = c('SNH4', 'SNO3', 'SO4', 'XSO4', 'Na', 'NH4', 'NO3')
# MATRICES = list('SNH4'='air+aerosol', 'SNO3'='air+aerosol', 'SO4'='aerosol', 'XSO4'='aerosol', 'Na'='aerosol', 'SNH4'='aerosol', 'SNO3'='aerosol')
# UNITS = list('SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3', 'NH4'='ug N/m3', 'NO3'='ug N/m3')

# SCENs = c('base')
if ( setup == 'effectSeaSalt' || setup == 'effectSeaSalt.v5' ) {
#   SCENs = c('base', 'noSurf', 'zero')
  SCENs = c('base', 'noSurf', 'zero', 'full')
} else if (setup =='seasalt3d') {
  SCENs = c('base', 'noSurf', 'noSalt')
}

nSTATION=-1

if(getObsData) {
  valOBS = list()
  for(iMon in MONs) {
    valOBS[[iMon]] = list()
    for(iSpec in SPECs) {
      valOBS[[iMon]][[iSpec]] = list()
    }
  }
}

if (getSimData) {
  nCOL=-1
  nROW=-1
  nTSTEP=-1
  valSIM = list()
  for(iMon in MONs) {
    valSIM[[iMon]] = list()
    for(iScen in SCENs) {
      valSIM[[iMon]][[iScen]] = list()
      for(iSpec in SPECs) {
        valSIM[[iMon]][[iScen]][[iSpec]] = list()
      }
    }
  }
}


# get data ----
for(iMon in MONs) {
  #' for case effectSeaSalt.v5
  if(iMon == 'sum2008' || iMon == 'sum') {
    # from = 2008151
    # to = 2008242
    nT = 61
    from = 2008183
    to = 2008243
  } else if(iMon == 'win2008' || iMon == 'win') {
    # from = 2008336
    # to = 2008365
    nT = 60
    from = 2008001
    to = 2008060
  }
  nTh = nT * 24

  # myStations = stations[-c(11, 12, 13, 14, 16, 17, 18, 19, 25)]
  # myStations = c("DE0001R", "DE0002R", "DE0003R", "DE0007R", "DE0009R", "DK0003R", "DK0005R", "DK0008R", "DK0031R", "FR0009R", "NO0001R", "NO0056R", "PL0002R", "PL0003R", "PL0004R", "SE0014R")
  # myStations = c("DE0001R", "DE0002R", "DE0003R", "DE0007R", "DE0009R", "DK0003R", "DK0005R", "DK0008R", "DK0031R", "NO0001R", "NO0056R", "PL0002R", "PL0003R", "PL0004R", "SE0014R")
  myStations = c("DE0001R", "DE0002R", "DE0007R", "DE0009R", "DK0005R", "DK0008R", # "DK0009R", "DK0041R", 
                 "FI0009R", "FI0017R", "FI0022R", "FI0037R", "NL0007R", "NL0010R", "NL0011R", # "NL0009R", 
                 "NL0091R", "NO0001R", "NO0015R", "NO0039R", "NO0056R", "PL0002R", "PL0004R", "PL0005R", 
                 "SE0005R", "SE0008R", "SE0014R")
#   myStations = c("DE0001R", "DE0002R", "DE0009R")
  nSTATIONS=length(myStations)
  
  if(getObsData && setup != 'seasalt3d') {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING OBSERVATIONAL DATA FROM DATABASE')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    for (iSpec in SPECs) {
      valOBS[[iMon]][[iSpec]] <- getobservationts(from,to,iSpec, stations = myStations, matrix=MATRICES[[iSpec]], vlevel = gsub('or', 'and', gsub(', 781,', ',', vlevel(1))))
      # tmpOBS <- getobservationts(from,to,iSpec, stations = myStations, matrix=MATRICES[[iSpec]], vlevel = gsub('or', 'and', gsub(', 781,', ',', vlevel(1))))
      # 
      # if (MATRICES[[iSpec]] == 'aerosol' && iSpec %in% c('Na', 'SO4', 'NO3', 'NH4')) tmpOBS$DE0044R = getobservationts(from,to,iSpec, stations = 'DE0044R', matrix='pm10', vlevel = gsub('or', 'and', gsub(', 781,', ',', vlevel(1))))
      # if (iSpec == 'XSO4') tmpOBS[['DE0044R']] = valOBS[[iMon]][['SO4']][['DE0044R']] - valOBS[[iMon]][['Na']][['DE0044R']] * 0.077/0.306/3
      # 
      # for (iStat in myStations) {
      #   valOBS[[iMon]][[iSpec]][[iStat]] = tmpOBS[[iStat]]
      #   
      #   tmpVals = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$values
      #   tmpVals[tmpVals > 10] = NaN
      #   valOBS[[iMon]][[iSpec]][[iStat]]$timeser$values = tmpVals
      # }
    }
    
    myPositions = list()
    myCells = list()
    for(iPos in myStations) {
      myPositions[[iPos]] = NULL
      
      for(iSpec in SPECs) {
        if(!is.null(valOBS[[iMon]][[iSpec]][[iPos]]$station)) {
          myPositions[[iPos]] = list('lat' = valOBS[[iMon]][[iSpec]][[iPos]]$station$latitude,
                                     'lon' = valOBS[[iMon]][[iSpec]][[iPos]]$station$longitude)
        }
      }
      
      if (is.null(myPositions[[iPos]])) {
        stop(paste('No data available for station ', iStat, '.', sep = ''))
      } else {
        myCells[[iPos]] = findcell(myPositions[[iPos]], CD24)
      }
    }
  }
  
  if(getSimData) {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('  READING MET FILE')
    ncMet <- nc_open(paste(inDir, paste('METCRO3D', iMon, 'short', sep = '.'), sep = '/'))
    
    nTSTEP = ncMet$dim$TSTEP$len
    nCOL = ncMet$dim$COL$len
    nROW = ncMet$dim$ROW$len
    
    valPRES = matrix(ncvar_get(ncMet, 'PRES')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    valTA   = matrix(ncvar_get(ncMet, 'TA')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    
    nc_close(ncMet)
    
    myStart = c(1,1,1,1)
    myCount = c(-1,-1,-1,nTSTEP)
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      if (iScen %in% c('surf','base','zero')) {
        ncId = nc_open(paste(inDir, paste('BL_CONC.CD24_', setup, '.', iScen,
                                          '_', mech, '_', iMon, '.short', sep = ''), 
                             sep = '/'))
      } else {
        ncId = nc_open(paste(inDir, paste('BL_CONC.CD24_', setup, '.', iScen,
                                          '_', mech, '_', iMon, sep = ''), 
                             sep = '/'))
      }
      
      #if (nTSTEP != ncId$dim$TSTEP$len || nCOL != ncId$dim$COL$len || nROW != ncId$dim$ROW$len )
      #  stop(paste('Problem with dimensions of netCDF file', ncMet$filename, sep = ' '))
      
      print('    Reading NO2')
      valSIM[[iMon]][[iScen]]$NO2 = ( matrix(ncvar_get(ncId, 'NO2', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) 
                                      * valPRES / valTA / R * myMolMass$N )
      
      nc_close(ncId)
    }
  }
}

gc()

# plot data ----
if(plotData) {  
  # define output file type ----
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'A4')
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
  
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SO4' = expression("SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'Na' = expression("Na"^"+" ~ 'conc [' ~ mu * 'g/' * m^3 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO2' = expression("NO"[2] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  
  for(iSpec in SPECs) {  
  # for(iSpec in SPECs[c(7)]) {  
  # for(iSpec in SPECs[c(5,4,3,1,2)]) {  
    # postscript(file = paste('CONC.timeseries', setup, iSpec, 'moreStations', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # postscript(file = paste('CONC.timeseries', setup, iSpec, 'allStations', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # postscript(file = paste('CONC.timeseries', setup, iSpec, 'threeStations', 'eps', sep = '.'), onefile=TRUE,
    #           horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # pdf(file = paste('CONC.timeseries', setup, iSpec, 'threeStations', 'pdf', sep = '.'), onefile=TRUE,
    #            paper = 'special', width = 10, height = 6.5)
    pdf(file = paste('CONC.timeseries', setup, iSpec, 'moreStations', 'pdf', sep = '.'), onefile=TRUE,
        paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6

    iScreen = 0
    
    
    
    
    # for(iLoc in 13:15){
    for(iLoc in 1:nSTATIONS){
    # for(iLoc in c(1,2,5)){
      # print(iScreen)
      if(iScreen%%13 == 0) {
        if(iScreen != 0) plot.new()
        iScreen = 1
        
        split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                           # top left, time series
                           c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # top right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # center left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # center right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # bottom left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           # bottom right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
        ))
        
        # make legend ----
        screen(iScreen)
        # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
        plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
        if(iSpec == 'Na') {
          tCol = 'orange'
          tPch = 8
          tLab = 'sim, full'
        } else {
          tCol = 'green'
          tPch = 4
          tLab = 'sim, zero'
        }
        if(plotType == 1) {
          legend('left', legend = c('obs', 'sim, base', 'sim, noSurf', tLab, '  year 2008'),
                 col = c('darkgrey', 'blue', 'red', tCol, 'white'), lwd = c(10,4,3,3, NA), 
                 lty = c('solid', 'solid', 'dotted','dashed', NA), bg = 'white', horiz = TRUE)
        } else if (plotType == 2) {
          if (iSpec != 'NO3') {
            legend('left', legend = c('obs', 'sim, base', 'sim, noSurf', tLab, '  year 2008'),
                   col = c('darkgrey', 'blue', 'red', tCol, 'white'), lwd = c(10,2,2,2, NA), 
                   lty = c('solid', NA, NA, NA, NA), pch = c(NA, 19, 1, tPch, NA),
                   bg = 'white', horiz = TRUE, inset = 0.02,
                   pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
          } else {
            legend('left', legend = c('', 'sim, base', 'sim, noSurf', tLab, '  year 2008'),
                   col = c('white', 'blue', 'red', tCol, 'white'), lwd = c(10,2,2,2, NA), 
                   lty = c('solid', NA, NA, NA, NA), pch = c(NA, 19, 1, tPch, NA),
                   bg = 'white', horiz = TRUE, inset = 0.02,
                   pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
          }
        }
      }
      iStat = myStations[iLoc]
      myLoc = myCells[[iStat]]
      
      # print(paste(iMon, iSpec, iStat, sep = ', '))
      
      myMax = 0
      for (iMon in MONs) {
        myMax = max(myMax, max(valOBS[[iMon]][[iSpec]][[iStat]]$timeser$value, na.rm = TRUE))
        for(iScen in SCENs) {
          myMax = max(myMax, max(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][,iLoc]), na.rm = TRUE))
        }
      }
      myLim = getYlim(myMax, 3)
      
      #for(iMon in c('win2008', 'win2008')) {
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'win2007') {
          nT = 60
          from = 2008001
          to = 2008060
        } else if(iMon == 'sum2008') {
          # nT = 92
          # from = 2008151
          # to = 2008242
          # nT = 91
          # from = 2008183
          # to = 2008273
          nT = 61
          from = 2008183
          to = 2008243
        } else if(iMon == 'win2008') {
          # nT = 30
          # from = 2008336
          # to = 2008365
          # nT = 91
          # from = 2008001
          # to = 2008091
          nT = 60
          from = 2008001
          to = 2008060
        }

        # prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        pltOBS = rep(0.0, nT)
        pltOBS = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$value[1:nT]
        if ( is.null(pltOBS) ||
               length(pltOBS) == 0) {
          pltOBS = rep(0.0, nT)
        }
      
        pltOBSnoNA = pltOBS
        pltOBSnoNA[is.na(pltOBS)] = 0
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIMbase = make_daily_mean(valSIM[[iMon]][[SCENs[1]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMnoSu = make_daily_mean(valSIM[[iMon]][[SCENs[2]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMzero = make_daily_mean(valSIM[[iMon]][[SCENs[3]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMfull = make_daily_mean(valSIM[[iMon]][[SCENs[4]]][[iSpec]][1:(24*nT),iLoc])
      
        myMax = max(c(max(pltOBS, na.rm = TRUE), 
                      max(pltSIMbase),
                      max(pltSIMnoSu),
                      max(pltSIMzero),
                      max(pltSIMfull)), na.rm = TRUE)
        myLim = getYlim(myMax, 3)
      
        # start plotting ----
        iScreen = iScreen + 1 
      
        screen(iScreen)
        plot(timeAxis[-nT-1], pltOBSnoNA,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
      
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
      
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(paste(valOBS[[1]][[1]][[iStat]]$station$station_name, iStat, sep = ' '), line = -1)
        
        if (iSpec != 'NO3') {
          polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
                  col = 'darkgrey', border = FALSE)
        }
      
        if (plotType == 1) {
          lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMbase, each = 2),
                col = 'blue', lwd =3)
          lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMnoSu, each = 2),
                col = 'red', lwd =2, lty = 'dotted')
          lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMnoSu, each = 2),
                col = 'red', lwd =1)
          if (iSpec == 'Na') {
            lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMfull, each = 2),
                  col = 'orange', lwd =1)
          } else {
            lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMzero, each = 2),
                  col = 'green', lwd =2, lty = 'dashed')
            lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMzero, each = 2),
                  col = 'green', lwd =1, lty = 'dotted')
          }
        } else {
          # lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMbase, each = 2),
          #       col = 'blue', lwd = 1)
          # lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMnoSu, each = 2),
          #       col = 'red', lwd = 1)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
                col = 'blue', pch = 19, cex = 0.8)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMnoSu,
                col = 'red', pch = 1, cex = 0.8)
          if (iSpec == 'Na') {
            points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMfull,
                  col = 'orange', pch = 8, cex = 0.7)
          } else {
            points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
                  col = 'green', pch = 4, cex = 0.8)
          }
        }
      
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        if (iStat != 'SE0005R') {
          if (iSpec == 'Na') {
            boxplot(apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMfull)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'blue', 'red', 'orange'), range = 0)
            points(1:4, apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMfull), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'blue', 'red', 'orange'))
          } else if (iSpec != 'NO3'){
            boxplot(apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMzero)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'blue', 'red', 'green'), range = 0)
            points(1:4, apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMzero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'blue', 'red', 'green'))
          } else {
            boxplot(apply(rbind(rep(-100,length(pltOBS)), pltSIMbase, pltSIMnoSu, pltSIMzero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                    yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'blue', 'red', 'green'), range = 0)
            points(1:4, apply(rbind(rep(-100,length(pltOBS)), pltSIMbase, pltSIMnoSu, pltSIMzero), MARGIN = 1, FUN = mean, na.rm = TRUE),
                   pch = 18, col = c('black', 'blue', 'red', 'green'))
          }
        }
      
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
  
}


if(doStatistics) {
  units = list()
  # fStat = paste('statistic', setup, mech, strYear, 'csv', sep = '.')
  # fRAE = paste('rae', setup, mech, strYear, 'csv', sep = '.')
  fRAE = paste('stat', 'new', setup, mech, strYear, 'moreStations', 'NO2', 'csv', sep = '.')
  # fIdx = paste('statistic', setup, mech, strYear, 'idx', sep = '.')
  
  # file.remove(fStat)
  # file.remove(fRAE)
  # file.remove(fIdx)
  
  write('SPECIES,SEASON,STATION,CASE,n,rae,mnb,cor,mean.sim,mean.obs,median.sim,median.obs', 
        file = fRAE, append = FALSE)
  
  
  # for(iMon in c('win2008')) {
  for(iMon in MONs) {
    for(iScen in SCENs) {
#     for(iSpec in SPECs) {
      for(iSpec in SPECs[c(1,2,4)]) {
        # print(paste(iMon, iScen, iSpec))
        obsDat = valOBS[[iMon]][[iSpec]]
        # simDat = griddata.lambert(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]]), 
        #                           grid = myGrid, var = iSpec, unit = UNITS[[iSpec]])
        # statDat = summary.observationts(obsDat, simDat)
        # write(paste(iMon, iSpec, iScen, sep = "_"), file = fStat, append = TRUE) # add index
        # write.table(statDat, file = fStat, append=TRUE) # add statistics
        
        for (iStat in names(obsDat)) {
        # for (iStat in myStations) {
          # print(paste(iMon, iScen, iSpec, iStat))
          
          if(iMon == 'sum2008') {
            nT = 61
            from = 2008183
            to = 2008243
          } else if(iMon == 'win2008') {
            nT = 60
            from = 2008001
            to = 2008060
          }
          
          iLoc = which(iStat == myStations)
          obs = obsDat[[iStat]]$timeser$values[1:nT]
          sim = make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][1:(24*nT),iLoc])
          validVals = !is.na(obs + sim)
          
          n = sum(validVals)
          rae = sum(abs(obs-sim), na.rm = TRUE)/sum(validVals)
          mean.sim = mean(sim[validVals])
          mean.obs = mean(obs[validVals])
          median.sim = median(sim[validVals])
          median.obs = median(obs[validVals])
          mnb = MNB(obs, sim)
          myCor = cor(sim[validVals], obs[validVals], method = 'spearman')
          
          # write(paste(iSpec, iMon, iStat, iScen, formatC(rae, format = 'f', width = 4), sep = ','), 
          #       file = fRAE, append = TRUE)
          write(paste(iSpec, iMon, iStat, iScen, n, rae, mnb, myCor, mean.sim, mean.obs, median.sim, median.obs, sep = ','), 
                file = fRAE, append = TRUE)
        }
        
        # remove(obsDat,simDat,statDat)
      }
    }
  }
  #' make the files nice with
  #' sed -r ':a;N;$!ba;s/([a-zA-Z]+_[a-zA-Z0-9]+_[a-zA-Z]+)\n"station"/\n"\1" "station"/g' statistic.effectSeaSalt.cb05cl_ae5_aq.2008.csv | sed ':a;N;$!ba;s/^\n//g' > statistic.effectSeaSalt.cb05cl_ae5_aq.2008.csv
  #' sed -r ':a;N;$!ba;s/([a-zA-Z0-9]+_[a-zA-Z0-9]+_[a-zA-Z]+)\n"station"/\n"\1" "station"/g' statistic.effectSeaSalt.v5.cb05tucl_ae5_aq_ssa.2008.csv | sed ':a;N;$!ba;s/^\n//g' > statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.csv
  #' first sed: Remove newline between 'index' and 'statistics' (see above) and add a new
  #'            line above 'index'. The column headings of stations are no move on column
  #'            to the right. The first column of the heading row contains index.
  #' second sed: Remove the newline before the first data set.
  #' 
  #' make it even more nicer :-)
  #' cat statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.csv | tr '\n' ';' | sed -r 's/("(win|sum)2008_(SNH4|SNO3|SO4|XSO4|Na)_(noSurf|base|zero|full)") ([^;]*);"[123]" ([^;]*);"[123]" ([^;]*);"[123]" ([^;]*);/\1 \5;\1 \6;\1 \7;\1 \8/g' | sed -r 's/;"([^;"]*)" "station" [^;]*;/;/g' | sed 's/^"[^"]*"/"setup"/g' | tr ';' '\n' > statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.A.csv
  #' 
}


# salinity impact ----
if(doSalImpact) {
  units = list()
  fImpH = paste('stat', 'salImpact', setup, mech, strYear, 'h', 'moreStations', 'csv', sep = '.')
  fImpD = paste('stat', 'salImpact', setup, mech, strYear, 'd', 'moreStations', 'csv', sep = '.')
  
  write('SPECIES,SEASON,STATION,n,mnb,mean.base,mean.full,median.base,median.full', 
        file = fImpH, append = FALSE)
  write('SPECIES,SEASON,STATION,n,mnb,mean.base,mean.full,median.base,median.full', 
        file = fImpD, append = FALSE)
  
  for(iMon in MONs) {
    for(iSpec in SPECs) {
      for (iStat in myStations) {
        
        if(iMon == 'sum2008') {
          nT = 61
          from = 2008183
          to = 2008243
        } else if(iMon == 'win2008') {
          nT = 60
          from = 2008001
          to = 2008060
        }
        
        iLoc = which(iStat == myStations)
        dBaseH = valSIM[[iMon]][['base']][[iSpec]][1:(24*nT),iLoc]
        dZeroH = valSIM[[iMon]][['zero']][[iSpec]][1:(24*nT),iLoc]
        dBaseD = make_daily_mean(valSIM[[iMon]][['base']][[iSpec]][1:(24*nT),iLoc])
        dZeroD = make_daily_mean(valSIM[[iMon]][['zero']][[iSpec]][1:(24*nT),iLoc])
        
        n.h = length(dBaseH)
        n.d = length(dBaseD)
        mean.base.h = mean(dBaseH)
        mean.zero.h = mean(dZeroH)
        mean.base.d = mean(dBaseD)
        mean.zero.d = mean(dZeroD)
        median.base.h = median(dBaseH)
        median.zero.h = median(dZeroH)
        median.base.d = median(dBaseD)
        median.zero.d = median(dZeroD)
        mnb.h = MNB(dBaseH, dZeroH)
        mnb.d = MNB(dBaseD, dZeroD)
        write(paste(iSpec, iMon, iStat, n.h, mnb.h, mean.base.h, mean.zero.h, median.base.h, median.zero.h, sep = ','), 
              file = fImpH, append = TRUE)
        write(paste(iSpec, iMon, iStat, n.d, mnb.d, mean.base.d, mean.zero.d, median.base.d, median.zero.d, sep = ','), 
              file = fImpD, append = TRUE)
      }
    }
  }
}


# do some correlation calculations ----
if(doCorr) {
  units = list()
  fCorr = paste('n_corr', setup, mech, strYear, 'csv', sep = '.')
  
  file.remove(fCorr)
  write('season,station,case,n,Robs,Rsim,species1,species2', file = fCorr, append = TRUE)
  
  NO3s = c('SNO3', 'NO3', 'HNO3')
  NH4s = c('SNH4', 'NH4', 'NH3')
  
  # for(iMon in c('win2008')) {
  for(iSpec in 1:2) {
    for(iMon in MONs) {
      for(iScen in SCENs) {
        for (iStat in names(valOBS[[iMon]]$SNH4)) {
          print(paste(iMon, iScen, iStat))
          iLoc = which(iStat == myStations)
          myLoc = myCells[[iStat]]
          
          tmpObsSNH4 = valOBS[[iMon]][[NH4s[iSpec]]][[iStat]]$timeser$values
          tmpObsSNO3 = valOBS[[iMon]][[NO3s[iSpec]]][[iStat]]$timeser$values
          tmpSimSNH4 = make_daily_mean(valSIM[[iMon]][[iScen]][[NH4s[iSpec]]][,iLoc])
          tmpSimSNO3 = make_daily_mean(valSIM[[iMon]][[iScen]][[NO3s[iSpec]]][,iLoc])
          validVals = !is.na(tmpObsSNH4+tmpObsSNO3+tmpSimSNH4+tmpSimSNO3)
          nVals = sum(validVals)
          
          corObs = cor(tmpObsSNH4[validVals], tmpObsSNO3[validVals], method = 'spearman')
          corSim = cor(tmpSimSNH4[validVals], tmpSimSNO3[validVals], method = 'spearman')
          
          write(paste(iMon, iStat, iScen, formatC(nVals, format = 'd'), 
                      formatC(corObs, format = 'f', width = 4), formatC(corSim, format = 'f', width = 4), 
                      NH4s[iSpec], NO3s[iSpec], sep = ','), 
                file = fCorr, append = TRUE)
        }
      }
    }
  }
}


# write out data for supplement ----
if(writeOutData) {
  myPos = names(myCells)
  nPos = length(myPos)
  headings = append(c('doy', 'hour'), myPos)
  
  
  for(iMon in MONs) {
    if(iMon == 'sum2008') {
      nT = 61*24
      from = 2008183
      to = 2008243
    } else if(iMon == 'win2008') {
      nT = 60*24
      from = 2008001
      to = 2008060
    }
    nDays = nT/24
    
    for(iScen in SCENs) {
      for(iSpec in SPECs[c(1,2,4,7)]) {
        fOut = paste('conc.timeseries.values', iMon, iScen, iSpec, 'moreStations','csv', sep = '.')
        
        tmpOut = array(0.0, dim = c(nT,nPos+2))
        tmpOut[,1] = rep(seq(from, length.out = nDays), each = 24)
        tmpOut[,2] = rep(0:23, nDays)
        
        for (iPos in 1:nPos) {
          strPos = myPos[iPos]
          tmpOut[,iPos+2] = valSIM[[iMon]][[iScen]][[iSpec]][1:nT,iPos]
        }
        write.table(tmpOut, fOut, col.names = headings, row.names = FALSE, sep = ',')
      }
    }
  }
  
}