library('ncdf4')
library('cmaqtools')
library('ctmeval')

source('./handy_functions.R')

## save(list = ls(all=TRUE), file = "inData_combine_sim_and_obs_withSurf.RData")
## load("inData_combine_sim_and_obs_withSurf.RData")


# Create plots for Daniel's extended Abstract for the ITM 2015 in Montpellier.
getObsData = FALSE
getSimData = FALSE
plotData = TRUE

myGrid = griddesc('CD24')

# setup='effectSeaSalt'
# setup='seasalt3d'
setup='effectSeaSalt.v5'

if (setup == 'seasalt3d') {
  mech = 'cb05tump_ae6_aq_ssa'
  strYear='2013'
} else if (setup == 'effectSeaSalt.v5') {
  mech = 'cb05tucl_ae5_aq_ssa'
  strYear='2008'
} else {
  mech = 'cb05cl_ae5_aq'
  strYear='2008'
}

if(setup == 'seasalt3d') {
  ssSO4Mass = 0.0776
  ssNaMass = 0.3086
  ssClMass = 0.5538
  ssSeaCatMass = 0.3086+0.0368+0.0114+0.0118
} else if (setup == 'effectSeaSalt') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
} else if (setup == 'effectSeaSalt.v5') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
}

# functions and constant ----
make_daily_mean <- function(series) {
  dim_old = dim(series)
  
  if (length(dim_old) <= 1) {
    n_old = length(series)
    n_new = n_old/24
    
    means = rep(0.0, n_new)
    
    for(i1 in 1:n_new) {
      means[i1] = mean(series[(1:24)+(i1-1)*24])
    }
  } else if (length(dim_old) == 2) {
    n_old = dim_old[2]
    n_new = n_old/24
    dim_new = c(dim_old[1], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,i1] = rowMeans(series[,(1:24)+(i1-1)*24], dims = 1)
    }
  } else if (length(dim_old) == 3) {
    n_old = dim_old[3]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,i1] = rowMeans(series[,,(1:24)+(i1-1)*24], dims = 2)
    }
  } else if (length(dim_old) == 4) {
    n_old = dim_old[4]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], dim_old[3], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,,i1] = rowMeans(series[,,,(1:24)+(i1-1)*24], dims = 3)
    }
  }
  
  return(means)
}


getYlim <- function(yMax, type) {
  if ( yMax == 0 ) {
    yLim = 1
  } else if ( type == 1 ) {
    yLim = ceiling(yMax/10^(floor(log10(yMax))-1))*10^(floor(log10(yMax))-1)
  } else if ( type == 2 ) {
    yLim = signif(yMax, digits = 1) * 2
  } else if ( type == 3 ) {
    yLim = signif(yMax, digits = 1)
    if(yLim < yMax) {
      yLim = signif(2*yMax-yLim, digits = 2)
    }
  } else {
    yLim = 1
  }
  
  return(yLim)
}


myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63,
                 'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62,
                 'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                 'N' = 15,
                 'ASO4I' = 96, 'ASO4J' = 96, 'ASO4K' = 96, 'SO2' = 64, 'S' = 32)

R = 8.314462


# set some parameters ----
CD24 = griddesc('CD24')
DBaccess <- list(name="neumannd-pg-emep_v02.1",uid="neumannd",pwd="nd$1,")

inDir = '/storage/neumannd/data/cctm/CD24/analysis'

# MONs = c('win2007', 'sum2008', 'win2008')
# MONs = c('sum2008')
MONs = c('win2008', 'sum2008')
# MONs = c('win2007', 'win2008')

# SPECs = c('SNH4', 'SNO3', 'SO4', 'XSO4', 'Na')
# MATRICES = list('SNH4'='air+aerosol', 'SNO3'='air+aerosol', 'SO4'='aerosol', 'XSO4'='aerosol', 'Na'='aerosol')
# UNITS = list('SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3')
# SPECs = c('Na', 'SNH4')
SPECs = c('SNH4', 'SNO3', 'SO4', 'XSO4', 'Na', 'NH4', 'NO3')
MATRICES = list('SNH4'='air+aerosol', 'SNO3'='air+aerosol', 'SO4'='aerosol', 'XSO4'='aerosol', 'Na'='aerosol', 'SNH4'='aerosol', 'SNO3'='aerosol')
UNITS = list('SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3', 'NH4'='ug N/m3', 'NO3'='ug N/m3')
# SPECs = c('SNH4', 'SNO3', 'SO4', 'XSO4', 'Na', 'NH4', 'NO3')
# MATRICES = list('SNH4'='air+aerosol', 'SNO3'='air+aerosol', 'SO4'='aerosol', 'XSO4'='aerosol', 'Na'='aerosol', 'SNH4'='aerosol', 'SNO3'='aerosol')
# UNITS = list('SNH4'='ug N/m3', 'SNO3'='ug N/m3', 'SO4'='ug S/m3', 'XSO4'='ug S/m3', 'Na'='ug/m3', 'NH4'='ug N/m3', 'NO3'='ug N/m3')

# SCENs = c('base')
if ( setup == 'effectSeaSalt' || setup == 'effectSeaSalt.v5' ) {
#   SCENs = c('base', 'noSurf', 'zero')
  SCENs = c('base', 'noSurf', 'zero', 'full', 'surf')
} else if (setup =='seasalt3d') {
  SCENs = c('base', 'noSurf', 'noSalt')
}

nSTATION=-1

if(getObsData) {
  valOBS = list()
  for(iMon in MONs) {
    valOBS[[iMon]] = list()
    for(iSpec in SPECs) {
      valOBS[[iMon]][[iSpec]] = list()
    }
  }
}

if (getSimData) {
  nCOL=-1
  nROW=-1
  nTSTEP=-1
  valSIM = list()
  for(iMon in MONs) {
    valSIM[[iMon]] = list()
    for(iScen in SCENs) {
      valSIM[[iMon]][[iScen]] = list()
      for(iSpec in SPECs) {
        valSIM[[iMon]][[iScen]][[iSpec]] = 0.0
      }
    }
  }
}


# get data ----
for(iMon in MONs) {
  #' for case effectSeaSalt.v5
  if(iMon == 'win2007') {
    from = 2008001
    to = 2008060
  } else if(iMon == 'sum2008' || iMon == 'sum') {
  # from = 2008151
  # to = 2008242
    from = 2008183
    to = 2008273
  } else if(iMon == 'win2008' || iMon == 'win') {
  # from = 2008336
  # to = 2008365
    from = 2008001
    to = 2008091
  }

  # myStations = stations[-c(11, 12, 13, 14, 16, 17, 18, 19, 25)]
  # myStations = c("DE0001R", "DE0002R", "DE0003R", "DE0007R", "DE0009R", "DK0003R", "DK0005R", "DK0008R", "DK0031R", "FR0009R", "NO0001R", "NO0056R", "PL0002R", "PL0003R", "PL0004R", "SE0014R")
  myStations = c("DE0001R", "DE0002R", "DE0003R", "DE0007R", "DE0009R", "DK0003R", "DK0005R", "DK0008R", "DK0031R", "NO0001R", "NO0056R", "PL0002R", "PL0003R", "PL0004R", "SE0014R")
#   myStations = c("DE0001R", "DE0002R", "DE0009R")
  nSTATIONS=length(myStations)
  
  if(getObsData && setup != 'seasalt3d') {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING OBSERVATIONAL DATA FROM DATABASE')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    for (iSpec in SPECs) {
      valOBS[[iMon]][[iSpec]] <- getobservationts(from,to,iSpec, stations = myStations, matrix=MATRICES[[iSpec]], vlevel = gsub('or', 'and', gsub(', 781,', ',', vlevel(1))))
      for (iStat in myStations) {
        
        tmpVals = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$values
        tmpVals[tmpVals > 10] = NaN
        valOBS[[iMon]][[iSpec]][[iStat]]$timeser$values = tmpVals
      }
    }
    
    myPositions = list()
    myCells = list()
    for(iPos in myStations) {
      myPositions[[iPos]] = list('lat' = valOBS[[iMon]][[1]][[iPos]]$station$latitude,
                                 'lon' = valOBS[[iMon]][[1]][[iPos]]$station$longitude)
      myCells[[iPos]] = findcell(myPositions[[iPos]], CD24)
    }
  }
  
  if(getSimData) {
    nTSTEP = -1
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('  READING MET FILE')
    ncMet <- nc_open(paste(inDir, paste('METCRO3D', iMon, 'short', sep = '.'), sep = '/'))
    
    nTSTEP = ncMet$dim$TSTEP$len
    nCOL = ncMet$dim$COL$len
    nROW = ncMet$dim$ROW$len
    
    valPRES = matrix(ncvar_get(ncMet, 'PRES')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    valTA   = matrix(ncvar_get(ncMet, 'TA')[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
    
    nc_close(ncMet)
    
    myStart = c(1,1,1,1)
    myCount = c(-1,-1,-1,nTSTEP)
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      if (iScen %in% c('surf','base','zero')) {
        ncId = nc_open(paste(inDir, paste('BL_CONC.CD24_', setup, '.', iScen,
                                          '_', mech, '_', iMon, '.short', sep = ''), 
                             sep = '/'))
      } else {
        ncId = nc_open(paste(inDir, paste('BL_CONC.CD24_', setup, '.', iScen,
                                          '_', mech, '_', iMon, sep = ''), 
                             sep = '/'))
      }
      
      #if (nTSTEP != ncId$dim$TSTEP$len || nCOL != ncId$dim$COL$len || nROW != ncId$dim$ROW$len )
      #  stop(paste('Problem with dimensions of netCDF file', ncMet$filename, sep = ' '))
      
      print('    Reading SNH4')
      valSIM[[iMon]][[iScen]]$NH3 = ( matrix(ncvar_get(ncId, 'NH3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) 
                                      * valPRES / valTA / R * myMolMass$N )
      valSIM[[iMon]][[iScen]]$NH4 = ( matrix(ncvar_get(ncId, 'ANH4I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4I
                                      + matrix(ncvar_get(ncId, 'ANH4J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4J
                                      + matrix(ncvar_get(ncId, 'ANH4K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANH4K
                                      ) * myMolMass$N
      valSIM[[iMon]][[iScen]]$SNH4 = valSIM[[iMon]][[iScen]]$NH3 + valSIM[[iMon]][[iScen]]$NH4
      
      print('    Reading SNO3')
      valSIM[[iMon]][[iScen]]$HNO3 = ( matrix(ncvar_get(ncId, 'HNO3', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) 
                                       * valPRES / valTA / R * myMolMass$N )
      valSIM[[iMon]][[iScen]]$NO3 = ( matrix(ncvar_get(ncId, 'ANO3I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3I
                                      + matrix(ncvar_get(ncId, 'ANO3J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3J
                                      + matrix(ncvar_get(ncId, 'ANO3K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ANO3K
                                      ) * myMolMass$N
      valSIM[[iMon]][[iScen]]$SNO3 = valSIM[[iMon]][[iScen]]$HNO3 + valSIM[[iMon]][[iScen]]$NO3
      
      print('    Reading SO4')
      valSIM[[iMon]][[iScen]]$SO4 = ( matrix(ncvar_get(ncId, 'ASO4I', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4I
                                      + matrix(ncvar_get(ncId, 'ASO4J', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4J
                                      + matrix(ncvar_get(ncId, 'ASO4K', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / myMolMass$ASO4K
                                      ) * myMolMass$S
      if (setup == 'seasalt3d') {
        print('    Reading Na')
        valSIM[[iMon]][[iScen]]$Na = ( matrix(ncvar_get(ncId, 'ANAJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       + matrix(ncvar_get(ncId, 'ASEACAT', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS) / ssSeaCatMass*ssNaMass
                                       )
        print('    Reading corr SO4')
        valSIM[[iMon]][[iScen]]$XSO4 = (valSIM[[iMon]][[iScen]]$SO4 -
                                          valSIM[[iMon]][[iScen]]$Na / ssNaMass * ssSO4Mass / 3)
      } else {
        print('    Reading Na')
        valSIM[[iMon]][[iScen]]$Na = ( matrix(ncvar_get(ncId, 'ANAJ', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       + matrix(ncvar_get(ncId, 'ANAK', start = myStart, count = myCount)[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTSTEP),rep(1:nTSTEP, nSTATIONS)), dim = c(nTSTEP*nSTATIONS,3))], ncol=nSTATIONS)
                                       )*ssRealNa2Cat
        
        print('    Reading corr SO4')
        valSIM[[iMon]][[iScen]]$XSO4 = (valSIM[[iMon]][[iScen]]$SO4 -
                                          valSIM[[iMon]][[iScen]]$Na / ssRealNa2Cat / ssNaMass * ssSO4Mass / 3)
      }
      
      nc_close(ncId)
    }
  }
}

gc()

# plot data ----
if(plotData) {  
  # define output file type ----
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'A4')
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
  
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SO4' = expression("SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'Na' = expression("Na"^"+" ~ 'conc [' ~ mu * 'g/' * m^3 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  
  # for(iSpec in SPECs[c(5,4,3,1,2,6, 7)]) {  
  for(iSpec in SPECs[c(5)]) {  
  # for(iSpec in SPECs[c(6, 7)]) {  
  # for(iSpec in SPECs[c(5,4,3,1,2)]) {  
    # postscript(file = paste('CONC.timeseries', setup, iSpec, 'allStations', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # postscript(file = paste('CONC.timeseries', setup, iSpec, 'threeStations', 'withSurf', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    pdf(file = paste(paste('figS03','CONC','timeseries', setup, iSpec, 'threeStations', 'withSurf', sep = '_'), 'pdf', sep = '.'),
        onefile=TRUE, paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6

    iScreen = 0
    
    # for(iLoc in 13:15){
    # for(iLoc in 1:nSTATIONS){
    # for(iLoc in c(1,2,5)){
    for(iLoc in c(1,5,9)){
      # print(iScreen)
      if(iScreen%%13 == 0) {
        if(iScreen != 0) plot.new()
        iScreen = 1
        
        split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                           # top left, time series
                           c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # top right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # center left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # center right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # bottom left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           # bottom right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
        ))
        
        # make legend ----
        screen(iScreen)
        # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
        plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
        if(iSpec == 'Na') {
          tCol = 'orange'
          tPch = 8
          tLab = 'sim, full'
        } else {
          tCol = 'green'
          tPch = 4
          tLab = 'sim, zero'
        }
        legend('left', legend = c('obs', 'sim, base', 'sim, noSurf', tLab, 'sim, no cap', '  year 2008'),
               col = c('darkgrey', 'blue', 'red', tCol, 'cyan', 'white'), lwd = c(10,2,2,2,2, NA), 
               lty = c('solid', NA, NA, NA, NA,NA), pch = c(NA, 19, 1, tPch, 3, NA),
               bg = 'white', horiz = TRUE, inset = 0.02,
               pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
      }
      iStat = myStations[iLoc]
      myLoc = myCells[[iStat]]
      
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'win2007') {
          nT = 60; from = 2008001; to = 2008060
        } else if(iMon == 'sum2008') {
          nT = 61; from = 2008183; to = 2008243
        } else if(iMon == 'win2008') {
          nT = 60; from = 2008001; to = 2008060
        }

        # prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        pltOBS = rep(0.0, nT)
        pltOBS = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$value[1:nT]
        if ( is.null(pltOBS) || length(pltOBS) == 0) { pltOBS = rep(0.0, nT) }
      
        pltOBSnoNA = pltOBS
        pltOBSnoNA[is.na(pltOBS)] = 0
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIMbase = make_daily_mean(valSIM[[iMon]][[SCENs[1]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMnoSu = make_daily_mean(valSIM[[iMon]][[SCENs[2]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMzero = make_daily_mean(valSIM[[iMon]][[SCENs[3]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMfull = make_daily_mean(valSIM[[iMon]][[SCENs[4]]][[iSpec]][1:(24*nT),iLoc])
        pltSIMsurf = make_daily_mean(valSIM[[iMon]][[SCENs[5]]][[iSpec]][1:(24*nT),iLoc])
      
        myMax = max(c(max(pltOBS, na.rm = TRUE), 
                      max(pltSIMbase),
                      max(pltSIMnoSu),
                      max(pltSIMzero),
                      max(pltSIMfull)), na.rm = TRUE)
        myLim = getYlim(myMax, 3)
      
        # start plotting ----
        iScreen = iScreen + 1 
      
        screen(iScreen)
        plot(timeAxis[-nT-1], pltOBSnoNA,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
      
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
      
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(paste(valOBS[[1]][[1]][[iStat]]$station$station_name, iStat, sep = ' '), line = -1)
        
        polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
                col = 'darkgrey', border = FALSE)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
              col = 'blue', pch = 19, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMnoSu,
              col = 'red', pch = 1, cex = 0.8)
        if (iSpec == 'Na') {
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMfull,
                col = 'orange', pch = 8, cex = 0.7)
        } else {
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
                col = 'green', pch = 4, cex = 0.8)
        }
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMsurf,
               col = 'cyan', pch = 3, cex = 0.8)
      
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        if (iSpec == 'Na') {
          boxplot(apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMfull, pltSIMsurf)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'blue', 'red', 'orange', 'cyan'), range = 0)
          points(1:5, apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMfull, pltSIMsurf), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('black', 'blue', 'red', 'orange', 'cyan'))
        } else {
          boxplot(apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMzero, pltSIMsurf)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('black', 'blue', 'red', 'green', 'cyan'), range = 0)
          points(1:5, apply(rbind(pltOBS, pltSIMbase, pltSIMnoSu, pltSIMzero, pltSIMsurf), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('black', 'blue', 'red', 'green', 'cyan'))
        }
      
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
  
}

