#' This script reads different ocean files a plots two of their differences:
#'  - sea surface fraction with (base) and without (full) salinity scaling
#'  - surf zone fraction (base) and part of surf zone fraction which was
#'     removed by the capping (surf-base)
#' 
#' @author Daniel Neumann, daniel.neumann@hzg.de
#' @date 2016-01-05
#' @version 1.0.0
#' 
#' original version: area_plots_v1.0.0.R
#' converted to: sail_emis_plots_v1.1.0.R
#' converted to: plot_ssemis_map_v1.2.0.R
#' converted to: plot_OCEANfile_map_v1.0.0.R


## save(list = ls(all=TRUE), file = "inData_OCEANfile_map.RData")
## load("inData_OCEANfile_map.RData")


# load libraries ----
library('ncdf4')
library('cmaqtools')
source('plot.griddata.mod.R')
source('plot.griddata.lambert.mod.R')


# path and control parameters ----
dIn = './02_data_version2/oceans'
dOt = '.'

gridName = 'CD24'
gridDesc = griddesc(gridName)

data.read = FALSE
data.plot.1 = TRUE
data.plot.2 = TRUE


# functions and constants ----
color.my.pub <- function(lut, min, max=-min, nticks=11, ticks=seq(min, max, len=nticks), title='', title1='', title2='', numbPos = 8) {
  scale = (length(lut)-1)/(max-min)
  
  #   dev.new(width=1.75, height=5)
  par(adj = 0.6)
  plot(c(0,10), c(min,max+(max-min)*0.2), type='n', bty='n', xaxt='n', xlab='', yaxt='n', ylab='')
  # plot(c(0,10), c(min,max+(max-min)*0.2), type='n', xlab='', yaxt='n', ylab='')
  # title(title, line = 0)
  text(5, max+(max-min)*0.25, labels = title1, pos = 1, cex = 1.5)
  text(5, max+(max-min)*0.15, labels = title2, pos = 1, cex = 1.5)
  # axis(4, ticks, las=1, pos = 12, lwd = 0, lwd.tick = 4, font = 2, cex.axis = 2)
  axis(4, as.numeric(ticks), labels = rep('',length(ticks)), las=1, pos = 3, lwd = 0, lwd.tick = 2, 
       font = 1)
  axis(4, as.numeric(ticks), labels = ticks, las=1, pos = numbPos, lwd = 0, lwd.tick = 0, 
       font = 1, cex.axis = 1.8, hadj = 1.0)
  for (i in 1:(length(lut)-1)) {
    y = (i-1)/scale + min
    rect(0.5,y,3,y+1/scale, col=lut[i], border=NA)
  }
}

# parameters ----

# hotcolor_19lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
# hotcolor_20lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(1,1,1), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
## rain.bow = rev(append(rainbow(16)[1:5],rainbow(12)[c(5, 7, 8, 9)]))
## rain.bow = rev(rainbow(18)[1:13])
# rain.bow = rev(rainbow(24)[1:17])

#' seasons to read in
SCENs = c('base', 'full', 'surf', 'noSurf')
VARs = c('OPEN', 'SURF', 'MASK')
myVARs = c('OPEN' = 'open ocean', 'SURF' = 'surf zone', 'MASK' = 'mask')
scenFILEs = c('base' = 'sf050m_GIS_ubound_sal', 'full' = 'sf050m_GIS_ubound', 
            'surf' = 'sf050m_GIS_sal', 'noSurf' = 'sf000m_GIS_ubound_sal')


# read data ----
if (data.read) {
  
  data.raw = list()
  for (iScen in SCENs) data.raw[[iScen]] = list()
  
  # get data ----
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('READING OCEAN NETCDF FILES')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  for (iScen in SCENs) {
    ncFile = paste(dIn, 
                   paste(paste('OCEAN', gridName, scenFILEs[[iScen]], sep = '_'), 
                         'nc', 
                         sep = '.'),
                   sep = '/')
    
    for (iVar in VARs) data.raw[[iScen]][[iVar]] = read.griddata.lambert(iVar, file = ncFile, grid = gridDesc)
  }
  
  tmpLAND = array(1, dim = dim(data.raw$full$OPEN$val)) - data.raw$full$OPEN$val - data.raw$full$SURF$val
  data.raw$full$LAND = data.raw$full$OPEN
  data.raw$full$LAND$val = tmpLAND
  data.raw$full$LAND$var = 'LAND'
  rm(tmpLAND)
  for (iScen in SCENs[!(SCENs == 'full')]) data.raw[[iScen]]$LAND = data.raw$full$LAND
}



# plot A - map for pub.: salinity scaling ----
if(data.plot.1) {
  print('')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('CREATING PLOT FOR PUBLICATION: SAL SCALING')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  # plot A - set output device ----
  # postscript(file = paste('figS04_salScaling', 'eps', sep = '.'), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 3.84)
  pdf(file = paste('figS04_salScaling', 'pdf', sep = '.'), onefile=TRUE,
             paper = 'special', width = 10, height = 3.84)
  
  
  # plot A - set page layout ----
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  bL = 0.01 # left boundary
  bR = 0.01 # right boundary
  bT = 0.0391 # top boundary
  bB = 0.0391 # bottom boundary
  dHor = 0.016 # horizontal distance between maps
  dLeg = 0.15 # width of the legend
  
  plWidth = (1 - bL - bR - 2*dHor - dLeg) / 2 # width per map
  plHeight = 1 - bT - bB # height per map
  
  split.screen(rbind(c(bL, bL + plWidth, bB, 1 - bT),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, bB, 1 - bT),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR, bB, 1 - bT)))
  
  #   set some plotting parameters
  myUnit = expression('fraction [%]')
  myVar = 'sea surface'
  myLim.rain.bow = c(0,1.0625)
  rain.bow = rev(rainbow(24)[1:17])
  myHires = FALSE
  
  # plot A - plot map a) ----
  screen(1)
  plot.griddata.lambert.mod(data.raw$base$OPEN + data.raw$base$SURF,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'a)')
  
  # plot A - plot map b) ----
  screen(2)
  plot.griddata.lambert.mod(data.raw$full$OPEN + data.raw$full$SURF,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'b)')
  
  # plot A - plot legend ----
  screen(3)
  myTicks = formatC(100*(0:4)*(myLim.rain.bow[2]-myLim.rain.bow[1])/17*16/4, format = 'd')
  myCol = append(rain.bow, rain.bow[1])
  color.my.pub(myCol, min = 100*myLim.rain.bow[1], max = 100*myLim.rain.bow[2], ticks = myTicks,
               title1 = myVar, title2 = myUnit, numbPos = 7)
  
  # plot A - close screens and graphic device ----
  close.screen(all.screens = TRUE)
  dev.off()
}



# plot B - map for pub.: surf zone size capping ----
if(data.plot.2) {
  print('')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('CREATING PLOT FOR PUBLICATION: surf zone size capping')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  # plot B - set output device ----
  # postscript(file = paste('figS02_surfCapping', 'eps', sep = '.'), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 5.85, height = 7.5)
  pdf(file = paste('figS02_surfCapping', 'pdf', sep = '.'), onefile=TRUE,
             paper = 'special', width = 5.85, height = 7.5)
  
  
  # plot B - set page layout ----
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  bL = 0.0171 # left boundary
  bR = 0.0171 # right boundary
  bT = 0.02 # top boundary
  bB = 0.02 # bottom boundary
  dHor = 0.0274 # horizontal distance between maps
  dVert = 0.016 # vertical distance between maps
  dLeg = 0.2564 # width of the legend
  
  plWidth = 1 - bL - bR - dHor - dLeg # width per map
  plHeight = (1 - bT - bB - dVert) / 2 # height per map
  
  split.screen(rbind(c(bL, bL + plWidth, 1 - bT - plHeight, 1 - bT),
                     c(bL + plWidth + dHor, 1 - bR, 1 - bT - plHeight, 1 - bT),
                     c(bL, bL + plWidth, bB, bB + plHeight),
                     c(bL + plWidth + dHor, 1 - bR,bB, bB + plHeight)))
  
  #   set some plotting parameters
  myVarA = 'base surf'
  myUnitA = expression('zone frac. [%]')
  myVarB = 'removed surf '
  myUnitB = expression('zone frac. [%]')
  myLim.rain.bow = c(0,0.0068)
  rain.bow = rev(rainbow(24)[1:17])
  myHires = FALSE
  
  # plot B - plot map a) ----
  screen(1)
  plot.griddata.lambert.mod(data.raw$base$SURF,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'a)')
  
  # plot B - plot map b) ----
  screen(3)
  plot.griddata.lambert.mod(data.raw$surf$SURF - data.raw$base$SURF,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'b)')
  
  
  # plot B - plot legend top row ----
  screen(2)
  myTicks = formatC(100*(0:5)*(myLim.rain.bow[2]-myLim.rain.bow[1])/17*15/5, digits = 2, format = 'f')
  myCol = append(rain.bow, rain.bow[1])
  color.my.pub(myCol, min = 100*myLim.rain.bow[1], max = 100*myLim.rain.bow[2], ticks = myTicks,
               title1 = myVarA, title2 = myUnitA, numbPos = 8)
  
  # plot B - plot legend bottom row ----
  screen(4)
  myTicks = formatC(100*(0:5)*(myLim.rain.bow[2]-myLim.rain.bow[1])/17*15/5, digits = 2, format = 'f')
  myCol = append(rain.bow, rain.bow[1])
  color.my.pub(myCol, min = 100*myLim.rain.bow[1], max = 100*myLim.rain.bow[2], ticks = myTicks,
               title1 = myVarB, title2 = myUnitB, numbPos = 8)
  
  # plot B - close screens and graphic device ----
  close.screen(all.screens = TRUE)
  dev.off()
}