#' This script will read in processed CMAQ deposition files
#' and plot the nitrogen deposition.
#' 
#' @author Daniel Neumann, daniel.neumann@hzg.de
#' @date 2016-01-06
#' @version 1.0.0
#' 
#' original version: area_plots_v1.0.0.R
#' converted to: sail_emis_plots_v1.1.0.R
#' converted to: plot_ssemis_map_v1.2.0.R
#' converted to: plot_ndep_map_v1.0.0.R


## save(list = ls(all=TRUE), file = "inData_SIM_ndep.RData")
## load("inData_SIM_ndep.RData")


# load libraries ----
library('ncdf4')
library('cmaqtools')
source('plot.griddata.mod.R')
source('plot.griddata.lambert.mod.R')


# path and control parameters ----
dIn = '/storage/neumannd/data/cctm/CD24/analysis'
dOt = ''

gridName = 'CD24'
gridDesc = griddesc(gridName)
mech = 'cb05tucl_ae5_aq_ssa'
setup='effectSeaSalt.v5'

data.read = FALSE
test.plot = FALSE
data.plot = TRUE


# functions and constants ----
getDepN = function(fName, unit = 'mg/(day m2)') {
  #   myNames = c('NO','NO2', 'HNO3', 'ANO3I', 'ANO3J', 'ANO3K',
  #               'NH3', 'ANH4I', 'ANH4J', 'ANH4K')
  myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63, 'N2O5' = 108,
                   'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62,'NO3' = 62,
                   'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                   'N' = 14, 'PNA' = 79, 'PAN' = 121, 'HONO' = 47)
#   myNDep <- read.griddata.lambert('NO','NO2', 'HNO3', 'ANO3I', 'ANO3J', 'ANO3K',
#                                   'NH3', 'ANH4I', 'ANH4J', 'ANH4K', 'HONO', 
#                                   'PAN', 'NO3', 'N2O5', 
#                                   file = fName, grid=gridDesc)
  myNDep <- read.griddata.lambert('NO','NO2', 'HNO3', 'ANO3I', 'ANO3J', 'ANO3K',
                                  'NH3', 'ANH4I', 'ANH4J', 'ANH4K', 'HONO', 
                                  'PAN', 'PNA', 'NO3', 'N2O5', 
                                  file = fName, grid=gridDesc)
#   myNDep <- read.griddata.lambert('NO','NO2', 'HNO3', 'ANO3I', 'ANO3J', 'ANO3K',
#                                   'NH3', 'ANH4I', 'ANH4J', 'ANH4K',
#                                   file = fName, grid=gridDesc)
  myNames = names(myNDep)
  
  # sum dry dep
  myMass = myNDep[[myNames[1]]] / myMolMass[[myNames[1]]]
  for (i1 in 2:length(myNames)) myMass = myMass + myNDep[[myNames[i1]]] / myMolMass[[myNames[i1]]]
  ## only SNH4
  # myMass = myNDep[['NH3']] / myMolMass[['NH3']]
  # for (i1 in c('ANH4I', 'ANH4J', 'ANH4K')) myMass = myMass + myNDep[[i1]] / myMolMass[[i1]]
  
  myMass$val = myMass$val * myMolMass$N 
  myMass$var = 'Total_Nitrogen'
  
  if (unit == 'mg/(day m2)') {
    myMass$val = myMass$val* 2.4 * 10^3 # kg/hectare/hour * 24 h/day * 10^-4 hectare/m2 * 10^6 mg/kg = mg/m2/day
    myMass$unit = 'mg/(day*m2)'
  } else if (unit == 'kg/hectare' || unit == 'kg/hectare/hour') {
    myMass$unit = 'kg/hectare/hour'
  } else if (unit == 'kt/(gridcell*h)') {
    #' * 24^2 => 24 km grid
    #' * 10^2 => hetare to km2
    #' * 10^(-6) => kg to kt (kilo ton)
    myMass$val = myMass$val * 24^2 * 10^(-4)
    myMass$unit = 'kt/(gridcell*h)'
  }
  return(myMass)
}

color.my.pub <- function(lut, min, max=-min, nticks=11, ticks=seq(min, max, len=nticks), title='', title1='', title2='', numbPos = 8) {
  scale = (length(lut)-1)/(max-min)
  
  #   dev.new(width=1.75, height=5)
  par(adj = 0.6)
  plot(c(0,10), c(min,max+(max-min)*0.2), type='n', bty='n', xaxt='n', xlab='', yaxt='n', ylab='')
  # plot(c(0,10), c(min,max+(max-min)*0.2), type='n', xlab='', yaxt='n', ylab='')
  # title(title, line = 0)
  text(5, max+(max-min)*0.25, labels = title1, pos = 1, cex = 1.5)
  text(5, max+(max-min)*0.15, labels = title2, pos = 1, cex = 1.4)
  # axis(4, ticks, las=1, pos = 12, lwd = 0, lwd.tick = 4, font = 2, cex.axis = 2)
  axis(4, as.numeric(ticks), labels = rep('',length(ticks)), las=1, pos = 3, lwd = 0, lwd.tick = 2, 
       font = 1)
  axis(4, as.numeric(ticks), labels = ticks, las=1, pos = numbPos, lwd = 0, lwd.tick = 0, 
       font = 1, cex.axis = 1.8, hadj = 1.0)
  for (i in 1:(length(lut)-1)) {
    y = (i-1)/scale + min
    rect(0.5,y,3,y+1/scale, col=lut[i], border=NA)
  }
}



# parameters ----
hotcolor_19lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
hotcolor_20lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(1,1,1), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
# rain.bow = rev(append(rainbow(16)[1:5],rainbow(12)[c(5, 7, 8, 9)]))
# rain.bow = rev(rainbow(18)[1:13])
rain.bow = rev(rainbow(24)[1:17])

#' unit conversion
# g/s into t/y => *31.536e+6 *1e-6
uConFac = 31.536
# Unit CONversion FACtor


#' seasons to read in
SCENs = c('base', 'noSurf', 'zero', 'full')
MONs = c('win2008', 'sum2008')
myMONs = c('win2008' = 'winter 2008', 'sum2008' = 'summer 2008')
myModes = c('MASSJ' = 'J mode', 'MASSK' = 'K mode', 'MASST' = 'total',
            'NUMJ' = 'J mode', 'NUMK' = 'K mode', 'NUMT' = 'total')

# read data ----
if (data.read ) {
  
  data.raw = list()
  for (iMon in MONs) data.raw[[iMon]] = list()  
  
  # get data ----
  for(iMon in MONs) {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      pIn = paste(dIn, 
                  paste('TOTDEP.CD24_', setup, '.', iScen, '_', mech, '_', iMon, '.short.timmean', sep = ''), 
                  sep = '/')
      
      data.raw[[iMon]][[iScen]] = getDepN(pIn, unit = 'mg/(day m2)')
    }
  }
}



# simple test plot ----
if(test.plot) {
  myLimitsTotl = c(0.0025, 0.002,0.0015,0.001,0.0005, 0.00025, 0.0001, 0.00005) / 2
  myLimitsDiff = ((-4):3)/10^5
  for(iMon in MONs) {
    for (iScen in SCENs) {
      plot.griddata.lambert(data.raw[[iMon]][[iScen]], hires=FALSE, limits = myLimitsTotl, title = paste(iScen, iMon, sep = ', '))
      if (iScen != 'base') {
        plot.griddata.lambert(data.raw[[iMon]][[iScen]] - data.raw[[iMon]][['base']], hires=FALSE, limits = myLimitsDiff, title = paste(iScen, iMon, sep = ', '))
      }
    }
  }
}



# plot data ----
if (data.plot) {
  print('')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('CREATING PLOT FOR PUBLICATION')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  #   source functions ----
  
  
  #   set output device ----
  # postscript(file = paste('fig10_ndep_maps', 'eps', sep = '.'), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 11.16)
  pdf(file = paste('fig09_ndep_maps', 'pdf', sep = '.'), onefile=TRUE,
             paper = 'special', width = 10, height = 11.16)
  
  
  #   set page layout ----
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  bL = 0.01 # left boundary
  bR = 0.01 # right boundary
  bT = 0.01344 # 0.02 # top boundary
  bB = 0.01344 # 0.02 # bottom boundary
  dHor = 0.016 # horizontal distance between maps
  dVert = 0.01075 # 0.016 # vertical distance between maps
  dLeg = 0.15 # width of the legend
  
  plWidth = (1 - bL - bR - 2*dHor - dLeg) / 2 # width per map
  plHeight = (1 - bT - bB - 2*dVert) / 3 # height per map
  
  split.screen(rbind(c(bL, bL + plWidth, 1 - bT - plHeight, 1 - bT),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, 1 - bT - plHeight, 1 - bT),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR, 1 - bT - plHeight, 1 - bT),
                     c(bL, bL + plWidth, bB + plHeight + dVert, 1 - bT - plHeight - dVert),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, bB + plHeight + dVert, 1 - bT - plHeight - dVert),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR, bB + plHeight + dVert, 1 - bT - plHeight - dVert),
                     c(bL, bL + plWidth, bB, bB + plHeight),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, bB, bB + plHeight),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR, bB, bB + plHeight)))
  
  #   set some plotting parameters
  myUnit = expression('[mg d'^-1 ~ 'm'^-2 * ']')
  myVar = 'N deposition'
  myLim.rain.bow = c(0,8.5)
  myLim.hotA = c(-0.070, 0.070)
  myIntervs.hotA = seq(from = myLim.hotA[1], to = myLim.hotA[2], length.out = 22)
  myIntervs.hotA[22] = 1
  myIntervs.hotA[1] = -1
  myLim.hotB = c(-0.35, 0.35)
  myIntervs.hotB = seq(from = myLim.hotB[1], to = myLim.hotB[2], length.out = 22)
  myIntervs.hotB[22] = 1
  myIntervs.hotB[1] = -1
  hotcolor_20lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(1,1,1), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
  rain.bow = rev(rainbow(24)[1:17])
  myHires = FALSE
  myLegScale1 = 1 # 10^0
  myLegScale2 = 1 # 10^2
  myLegScale3 = 1 # 10^1
  myUnit1 = myUnit # expression('[mg d'^-1 ~ 'm'^-2 * ']')
  myUnit2 = myUnit # expression('[10'^-2 ~ 'mg d'^-1 ~ 'm'^-2 * ']')
  myUnit3 = myUnit # expression('[10'^-1 ~ 'mg d'^-1 ~ 'm'^-2 * ']')
  myVar1 = 'N dep., base'
  myVar2 = 'N dep., diff'
  myVar3 = 'N dep., diff'
  
  
  #   plot map a) ----
  screen(1)
  plot.griddata.lambert.mod(data.raw$win2008$base,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'a)')
  
  #   plot map b) ----
  screen(2)
  plot.griddata.lambert.mod(data.raw$sum2008$base,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'b)')
  
  #   plot map c) ----
  screen(4)
  plot.griddata.lambert.mod(data.raw$win2008$noSurf - data.raw$win2008$base,
                            limits = myIntervs.hotA, col = hotcolor_20lev, levels = 22, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'c)')
  
  #   plot map d) ----
  screen(5)
  plot.griddata.lambert.mod(data.raw$sum2008$noSurf - data.raw$sum2008$base,
                            limits = myIntervs.hotA, col = hotcolor_20lev, levels = 22, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'd)')
  
  #   plot map e) ----
  screen(7)
  plot.griddata.lambert.mod(data.raw$win2008$zero - data.raw$win2008$base,
                            limits = myIntervs.hotB, col = hotcolor_20lev, levels = 22, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'e)')
  
  #   plot map f) ----
  screen(8)
  plot.griddata.lambert.mod(data.raw$sum2008$zero - data.raw$sum2008$base,
                            limits = myIntervs.hotB, col = hotcolor_20lev, levels = 22, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'f)')
  
  #   plot legend top row ----
  screen(3)
  myTicks = formatC((0:5)*(myLim.rain.bow[2]-myLim.rain.bow[1])/17*15/5*myLegScale1, format = 'f', digits = 1)
  myCol = append(rain.bow, rain.bow[1])
  color.my.pub(myCol, min = myLim.rain.bow[1]*myLegScale1, max = myLim.rain.bow[2]*myLegScale1, ticks = myTicks,
               title1 = myVar1, title2 = myUnit1, numbPos = 7)
  
  #   plot legend bottom row ----
  screen(6)
  myTicks = formatC(((-3):3)/3*myLim.hotA[2]/10.5*9*myLegScale2, flag = "+", width = 5)
  myTicks[4] = '0.00'
  myCol = append(hotcolor_20lev, hotcolor_20lev[1])
  color.my.pub(myCol, min = myLim.hotA[1]*myLegScale2, max = myLim.hotA[2]*myLegScale2, ticks = myTicks,
               title1 = myVar2, title2 = myUnit2, numbPos = 9)
  
  #   plot legend bottom row ----
  screen(9)
  myTicks = formatC(((-3):3)/3*myLim.hotB[2]/10.5*9*myLegScale3, flag = "+", width = 4, format = 'f', digits = 1)
  myTicks[4] = '0.0'
  # myTicks[4] = '0'
  myCol = append(hotcolor_20lev, hotcolor_20lev[1])
  color.my.pub(myCol, min = myLim.hotB[1]*myLegScale3, max = myLim.hotB[2]*myLegScale3, ticks = myTicks,
               title1 = myVar3, title2 = myUnit3, numbPos = 9)
  
  # close screens and graphic device ----
  close.screen(all.screens = TRUE)
  dev.off()
}
