#' This script will read in processed CMAQ deposition files
#' and plot the nitrogen deposition.
#' 
#' @author Daniel Neumann, daniel.neumann@hzg.de
#' @date 2016-01-25
#' @version 1.2.0
#' 
#' original version: area_plots_v1.0.0.R
#' converted to: sail_emis_plots_v1.1.0.R
#' converted to: plot_ssemis_map_v1.2.0.R
#' converted to: plot_ndep_map_v1.0.0.R


## save(list = ls(all=TRUE), file = "inData_ndep_write.RData")
## load("inData_ndep_write.RData")


# load libraries ----
library('ncdf4')
library('cmaqtools')
source('plot.griddata.mod.R')
source('plot.griddata.lambert.mod.R')


# path and control parameters ----
dIn = '/storage/neumannd/data/cctm/CD24/analysis'
dOt = ''

gridName = 'CD24'
gridDesc = griddesc(gridName)
mech = 'cb05tucl_ae5_aq_ssa'
setup='effectSeaSalt.v5'

data.read = FALSE
ocean.read = FALSE
test.plot = FALSE
data.write = FALSE
ocean.map = TRUE
uncert.bar = FALSE


# functions and constants ----
getDepN = function(fName, unit = 'mg/(day m2)') {
  #   myNames = c('NO','NO2', 'HNO3', 'ANO3I', 'ANO3J', 'ANO3K',
  #               'NH3', 'ANH4I', 'ANH4J', 'ANH4K')
  myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63, 'N2O5' = 108,
                   'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62, 'NO3' = 62,
                   'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                   'N' = 15, 'PNA' = 79, 'PAN' = 121, 'HONO' = 47)
  myNDep <- read.griddata.lambert('NO','NO2', 'HNO3', 'ANO3I', 'ANO3J', 'ANO3K',
                                  'NH3', 'ANH4I', 'ANH4J', 'ANH4K', 'HONO', 
                                  'PAN', 'PNA', 'NO3', 'N2O5', 
                                  file = fName, grid=gridDesc)
  myNames = names(myNDep)
  
  # sum dry dep
  myMass = myNDep[[myNames[1]]] / myMolMass[[myNames[1]]]
  for (i1 in 2:length(myNames)) myMass = myMass + myNDep[[myNames[i1]]] / myMolMass[[myNames[i1]]]
  ## only SNH4
  # myMass = myNDep[['NH3']] / myMolMass[['NH3']]
  # for (i1 in c('ANH4I', 'ANH4J', 'ANH4K')) myMass = myMass + myNDep[[i1]] / myMolMass[[i1]]
  
  myMass$val = myMass$val * myMolMass$N 
  myMass$var = 'Total_Nitrogen'
  
  if (unit == 'mg/(day m2)') {
    myMass$val = myMass$val* 2.4 * 10^3 # kg/hectare/hour * 24 h/day * 10^-4 hectare/m2 * 10^6 mg/kg = mg/m2/day
    myMass$unit = 'mg/(day*m2)'
  } else if (unit == 'kg/hectare' || unit == 'kg/hectare/hour') {
    myMass$unit = 'kg/hectare/hour'
  } else if (unit == 'kt/(gridcell*h)') {
    #' * 24^2 => 24 km grid
    #' * 10^2 => hetare to km2
    #' * 10^(-6) => kg to kt (kilo ton)
    myMass$val = myMass$val * 24^2 * 10^(-4)
    myMass$unit = 'kt/(gridcell*h)'
  } else if (unit == 'kt/(gridcell*a)') {
    #' * 24^2 => 24 km grid
    #' * 10^2 => hetare to km2
    #' * 10^(-6) => kg to kt (kilo ton)
    #' * 24 * 365 => h to a
    myMass$val = myMass$val * 2.4^3 * 36.5
    myMass$unit = 'kt/(gridcell*a)'
  }
  return(myMass)
}

color.my.pub <- function(lut, min, max=-min, nticks=11, ticks=seq(min, max, len=nticks), title='', title1='', title2='', numbPos = 8) {
  scale = (length(lut)-1)/(max-min)
  
  #   dev.new(width=1.75, height=5)
  par(adj = 0.6)
  plot(c(0,10), c(min,max+(max-min)*0.2), type='n', bty='n', xaxt='n', xlab='', yaxt='n', ylab='')
  # plot(c(0,10), c(min,max+(max-min)*0.2), type='n', xlab='', yaxt='n', ylab='')
  # title(title, line = 0)
  text(5, max+(max-min)*0.25, labels = title1, pos = 1, cex = 1.5)
  text(5, max+(max-min)*0.15, labels = title2, pos = 1, cex = 1.4)
  # axis(4, ticks, las=1, pos = 12, lwd = 0, lwd.tick = 4, font = 2, cex.axis = 2)
  axis(4, as.numeric(ticks), labels = rep('',length(ticks)), las=1, pos = 3, lwd = 0, lwd.tick = 2, 
       font = 1)
  axis(4, as.numeric(ticks), labels = ticks, las=1, pos = numbPos, lwd = 0, lwd.tick = 0, 
       font = 1, cex.axis = 1.8, hadj = 1.0)
  for (i in 1:(length(lut)-1)) {
    y = (i-1)/scale + min
    rect(0.5,y,3,y+1/scale, col=lut[i], border=NA)
  }
}

getLims = function(max , min = 0, type = 3) {
  return(c(floor(min), ceiling(max)))
}


# parameters ----
hotcolor_19lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
hotcolor_20lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(1,1,1), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
# rain.bow = rev(append(rainbow(16)[1:5],rainbow(12)[c(5, 7, 8, 9)]))
# rain.bow = rev(rainbow(18)[1:13])
rain.bow = rev(rainbow(24)[1:17])

#' unit conversion
# g/s into t/y => *31.536e+6 *1e-6
uConFac = 31.536
# Unit CONversion FACtor


#' seasons to read in
SCENs = c('base', 'noSurf', 'zero', 'full')
MONs = c('win2008', 'sum2008')
myMONs = c('win2008' = 'winter 2008', 'sum2008' = 'summer 2008')
myModes = c('MASSJ' = 'J mode', 'MASSK' = 'K mode', 'MASST' = 'total',
            'NUMJ' = 'J mode', 'NUMK' = 'K mode', 'NUMT' = 'total')

# read data ----
if (data.read ) {
  
  data.raw = list()
  for (iMon in MONs) data.raw[[iMon]] = list()  
  
  # get data ----
  for(iMon in MONs) {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      pIn = paste(dIn, 
                  paste('TOTDEP.CD24_', setup, '.', iScen, '_', mech, '_', iMon, '.short.timmean', sep = ''), 
                  sep = '/')
      
      data.raw[[iMon]][[iScen]] = getDepN(pIn, unit = 'kt/(gridcell*a)')
    }
  }
}


# read ocean file ----
if(ocean.read) {
  
  ocean.raw = list()
  ocean.ns = list()
  ocean.bs = list()
  
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('READING OCEAN FILE DATA')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  
  ncFile = paste('02_data_version2', 'oceans', 
                 paste('OCEAN', gridName, 'sf050m_GIS_ubound.nc', sep = '_'),
                 sep = '/')
  
  ncId = nc_open(ncFile)
  for (iVar in c('MASK', 'OPEN', 'SURF')) ocean.raw[[iVar]] = ncvar_get(ncId, iVar)
  nc_close(ncId)
  
  #' WE MAKE OUR OWN MASK
  #' 
  #' 1 where ocMASK > 0, else 0
  #' ((ocMASK-0.1)/abs(ocMASK-0.1)+1)/2
  
  #' OSPAR REGION 2
  #' Region lon:  5W to 10E
  #'        lat: 48N to 62N
  
  #' ABOUT:
  #' xmin = 18
  #' xmax = 58
  #' ymin = 23
  #' ymax = 76
  #' 
  #' BUT WE DO IT MORE IN DETAIL
  myNS = array(1.0, dim = dim(ocean.raw$MASK))
  myBS = array(1.0, dim = dim(ocean.raw$MASK))
  
  myNS[1:15,] = 0
  myNS[1:24,34:106] = 0
  myNS[1:25,1:23] = 0
  myNS[1:25,34:53] = 0
  myNS[1:25,70:106] = 0
  myNS[,80:106] = 0
  myNS[26,72:80] = 0
  myNS[27,73:80] = 0
  myNS[28,74:80] = 0
  myNS[29,75:80] = 0
  myNS[30,76:80] = 0
  myNS[31,77:80] = 0
  myNS[32,78:80] = 0
  myNS[33,79:80] = 0
  myNS[69:112,] = 0
  myNS[59:112,1:60] = 0
  myNS[57:58,47:53] = 0
  myNS[,1:23] = 0
  ## myNS[1:30, 1:40] = 0
  #     image(myNS)
  
  myBS[,1:32] = 0
  myBS[1:58,33:46] = 0
  myBS[1:58,33:106] = 0
  myBS[57:58,47:53] = 1.0
  myBS[1:68,61:106] = 0
  myBS[98:112,1:106] = 0
  myBS[98:107,70:83] = 1.0
  myBS[1:112,105:106] = 0
  myBS[69,93:104] = 0
  myBS[70,94:104] = 0
  myBS[71,95:104] = 0
  myBS[72,96:104] = 0
  myBS[73,97:104] = 0
  myBS[74,98:104] = 0
  myBS[75,99:104] = 0
  myBS[76,100:104] = 0
  myBS[77,101:104] = 0
  myBS[78,102:104] = 0
  myBS[79,103:104] = 0
  myBS[80,104] = 0
  myBS[78:97,33] = 0
  myBS[79:97,34] = 0
  myBS[80:97,35] = 0
  myBS[81:97,36] = 0
  myBS[82:97,37] = 0
  myBS[83:97,38] = 0
  myBS[84:97,39] = 0
  myBS[85:97,40] = 0
  myBS[86:97,41] = 0
  myBS[87:97,42] = 0
  myBS[88:97,43] = 0
  myBS[89:97,44] = 0
  myBS[90:97,45] = 0
  myBS[91:97,46] = 0
  myBS[92:97,47] = 0
  myBS[93:97,48] = 0
  myBS[94:97,49] = 0
  myBS[95:97,50] = 0
  myBS[96:97,51] = 0
  myBS[97,52] = 0
  #     image(myBS)
  
  ocean.raw$NS = myNS * (ocean.raw$OPEN + ocean.raw$SURF)
  ocean.raw$BS = myBS * (ocean.raw$OPEN + ocean.raw$SURF)
  
  openNS = myNS - myNS * ceiling(1 - ocean.raw$OPEN)
  openBS = myBS - myBS * ceiling(1 - ocean.raw$OPEN) 
}


# simple test plot ----
if(test.plot) {
  myLimitsTotl = c(0.0025, 0.002,0.0015,0.001,0.0005, 0.00025, 0.0001, 0.00005) / 2
  myLimitsDiff = ((-4):3)/10^5
  for(iMon in MONs) {
    for (iScen in SCENs) {
      plot.griddata.lambert(data.raw[[iMon]][[iScen]], hires=FALSE, limits = myLimitsTotl, title = paste(iScen, iMon, sep = ', '))
      if (iScen != 'base') {
        plot.griddata.lambert(data.raw[[iMon]][[iScen]] - data.raw[[iMon]][['base']], hires=FALSE, limits = myLimitsDiff, title = paste(iScen, iMon, sep = ', '))
      }
    }
  }
}




# calculate N dep. into North and Baltic Sea ----
if(data.write) {
  nMon = length(MONs)
  nScen = length(SCENs)
  
  data.ns.mid = matrix(0, nrow=nMon, ncol=nScen, dimnames = list('rows' = MONs, 'cols' = SCENs))
  data.bs.mid = matrix(0, nrow=nMon, ncol=nScen, dimnames = list('rows' = MONs, 'cols' = SCENs))
  
  data.ns.top = data.ns.mid
  data.ns.bot = data.ns.mid
  data.bs.top = data.bs.mid
  data.bs.bot = data.bs.mid
  
  
  for (iM in 1:nMon) {
    iMon = MONs[iM]
    for (iS in 1:nScen) {
      iScen = SCENs[iS]
      
      data.ns.bot[iM,iS] = sum(openNS * data.raw[[iMon]][[iScen]]$val)
      data.bs.bot[iM,iS] = sum(openBS * data.raw[[iMon]][[iScen]]$val)
      
      data.ns.top[iM,iS] = sum(myNS * data.raw[[iMon]][[iScen]]$val)
      data.bs.top[iM,iS] = sum(myBS * data.raw[[iMon]][[iScen]]$val)
      
      data.ns.mid[iM,iS] = sum(ocean.raw$NS * data.raw[[iMon]][[iScen]]$val)
      data.bs.mid[iM,iS] = sum(ocean.raw$BS * data.raw[[iMon]][[iScen]]$val)
    }
  }
  
  write.table(matrix(c('', SCENs), nrow = 1), file = 'NDep.NorthSea.top.csv', col.names = FALSE, row.names = FALSE, quote = FALSE, sep = ',')
  write.table(data.ns.top, file = 'NDep.NorthSea.top.csv', append = TRUE, col.names = FALSE, quote = FALSE, sep = ',')
  
  write.table(matrix(c('', SCENs), nrow = 1), file = 'NDep.NorthSea.mid.csv', col.names = FALSE, row.names = FALSE, quote = FALSE, sep = ',')
  write.table(data.ns.mid, file = 'NDep.NorthSea.mid.csv', append = TRUE, col.names = FALSE, quote = FALSE, sep = ',')
  
  write.table(matrix(c('', SCENs), nrow = 1), file = 'NDep.NorthSea.bod.csv', col.names = FALSE, row.names = FALSE, quote = FALSE, sep = ',')
  write.table(data.ns.bot, file = 'NDep.NorthSea.bod.csv', append = TRUE, col.names = FALSE, quote = FALSE, sep = ',')
  
  
  write.table(matrix(c('', SCENs), nrow = 1), file = 'NDep.BalticSea.top.csv', col.names = FALSE, row.names = FALSE, quote = FALSE, sep = ',')
  write.table(data.bs.top, file = 'NDep.BalticSea.top.csv', append = TRUE, col.names = FALSE, quote = FALSE, sep = ',')
  
  write.table(matrix(c('', SCENs), nrow = 1), file = 'NDep.BalticSea.mid.csv', col.names = FALSE, row.names = FALSE, quote = FALSE, sep = ',')
  write.table(data.bs.mid, file = 'NDep.BalticSea.mid.csv', append = TRUE, col.names = FALSE, quote = FALSE, sep = ',')
  
  write.table(matrix(c('', SCENs), nrow = 1), file = 'NDep.BalticSea.bot.csv', col.names = FALSE, row.names = FALSE, quote = FALSE, sep = ',')
  write.table(data.bs.bot, file = 'NDep.BalticSea.bot.csv', append = TRUE, col.names = FALSE, quote = FALSE, sep = ',')
}


# ocean.map: plot a map of the considered ocean regions ----
if(ocean.map) {
  print('')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('CREATING PLOT FOR PUBLICATION: North and Baltic Sea')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  # ocean.map: set output device ----
  # postscript(file = paste('figS05_ocean_map', 'eps', sep = '.'), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 3.84)
  pdf(file = paste('figS05_ocean_map', 'pdf', sep = '.'), onefile=TRUE,
             paper = 'special', width = 10, height = 3.84)
  
  
  # ocean.map: set page layout ----
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  bL = 0.01 # left boundary
  bR = 0.01 # right boundary
  bT = 0.0391 # top boundary
  bB = 0.0391 # bottom boundary
  dHor = 0.016 # horizontal distance between maps
  dLeg = 0.15 # width of the legend
  
  plWidth = (1 - bL - bR - 2*dHor - dLeg) / 2 # width per map
  plHeight = 1 - bT - bB # height per map
  
  split.screen(rbind(c(bL, bL + plWidth, bB, 1 - bT),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, bB, 1 - bT),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR, bB, 1 - bT)))
  
  #   set some plotting parameters
  myUnit = expression('fraction [%]')
  myVar = 'sea surface'
  myLim.rain.bow = c(0,1.0625)
  rain.bow = rev(rainbow(24)[1:17])
  myHires = FALSE
  
  # ocean.map: plot map a) ----
  screen(1)
  plot.griddata.lambert.mod(griddata.lambert(ocean.raw$NS,gridDesc),
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'a)')
  
  # ocean.map: plot map b) ----
  screen(2)
  plot.griddata.lambert.mod(griddata.lambert(ocean.raw$BS,gridDesc),
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = myHires)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'b)')
  
  # ocean.map: plot legend ----
  screen(3)
  myTicks = formatC(100*(0:4)*(myLim.rain.bow[2]-myLim.rain.bow[1])/17*16/4, format = 'd')
  myCol = append(rain.bow, rain.bow[1])
  color.my.pub(myCol, min = 100*myLim.rain.bow[1], max = 100*myLim.rain.bow[2], ticks = myTicks,
               title1 = myVar, title2 = myUnit, numbPos = 7)
  
  # ocean.map: close screens and graphic device ----
  close.screen(all.screens = TRUE)
  dev.off()
}


if (uncert.bar) {
  data.ns.mid
  data.ns.top
  data.ns.bot
  data.bs.mid
  data.bs.top
  data.bs.bot
  
  myCOLs = list('base' = 'blue', 'noSurf' = 'red', 'zero' = 'green', 'full' = 'darkorange')
  myPCHs = list('base' = 16, 'noSurf' = 1, 'zero' = 4, 'full' = 8)
  
  for(iReg in c('ns', 'bs')) {
    myTop = get(paste('data', iReg, 'top', sep = '.'))
    myMid = get(paste('data', iReg, 'mid', sep = '.'))
    myBot = get(paste('data', iReg, 'bot', sep = '.'))
    
    myLims = getLims(max = max(myTop), min = min(myBot), type = 3)
    myLims = c(0,900)
    
    postscript(file = paste('ndep.totals.uncertainty', iReg, 'eps', sep = '.'),
               paper = 'special', onefile = FALSE, width = 4, height = 5,
               horizontal = FALSE)
    
    par(mar = c(3,3.5,0.5,0.5), mgp = c(1.9,0.8,0))
    
    plot(c(-1), c(-1), xlim = c(0,10), ylim = myLims,
         xlab = 'year 2008', ylab = expression('nitrogen deposition [kt N'~ 'yr'^-1 ~ ']'),
         xaxt = 'n', frame = FALSE)
    axis(side = 1, at = c(-2.5, 2.5, 7.5, 12.5), labels = c('','winter', 'summer',''))
    axis(side = 2, at = (0:5)*200)
    
    legend('topleft', legend = SCENs, title = 'emission cases', 
           col = array(unlist(myCOLs)), pch = array(unlist(myPCHs)),
           inset = c(0.04,0), pt.cex = 1.4)
    
    for(iM in 1:2) {
      iMon = MONs[[iM]]
      for(iS in 1:4) {
        iScen = SCENs[[iS]]
        iX = (iM - 1) * 5 + iS
        iYt = myTop[iM,iS]
        iYm = myMid[iM,iS]
        iYb = myBot[iM,iS]
        
        lines(c(iX-0.1,iX+0.1,NA,iX,iX,NA,iX-0.1,iX+0.1), c(iYt,iYt,NA,iYt,iYb,NA,iYb,iYb), col = myCOLs[[iScen]],
              lwd = 2)
        points(c(iX), c(iYm), col = myCOLs[[iScen]], pch = myPCHs[[iScen]], cex = 1.4)
      }
    }
    
    dev.off()
  }
}