#' This script will read in CMAQ simulations results (CONC, DRYDEP, and
#' WETDEP1) and create monthly averaged maps of concentrations and
#' depositions
#' 
#' @author Daniel Neumann, daniel.neumann@hzg.de
#' @date 2015-09-21
#' @version 1.2.0
#' 
#' original version: area_plots_v1.0.0.R
#' converted to: sail_emis_plots_v1.1.0.R


# load libraries ----
library('ncdf4')
library('cmaqtools')
source('plot.griddata.mod.R')
source('plot.griddata.lambert.mod.R')


## save(list = ls(all=TRUE), file = "inData_SSEMIS_map_mean_pub.RData")
## load("inData_SSEMIS_map_mean_pub.RData")


# path and control parameters ----
dIn = '/storage/neumannd/data/cctm/CD24/analysis'
# dIn = '/home/neumannd/storage/neumannd/data/cctm/CD24/analysis'
dOt = ''

gridName = 'CD24'
gridDesc = griddesc(gridName)
mech = 'cb05tucl_ae5_aq_ssa'
setup='effectSeaSalt.v5'

data.read = FALSE
data.work = FALSE
data.plot = FALSE
pub.plot = TRUE


# functions and constants ----
myMolMass = list('NO' = 30,'NO2' = 46, 'HNO3' = 63,
                 'ANO3I' = 62, 'ANO3J' = 62, 'ANO3K' = 62,
                 'NH3' = 17, 'ANH4I'= 18, 'ANH4J' = 18, 'ANH4K' = 18,
                 'N' = 15,
                 'S' = 32, 'SO2' = 64, 'SO4' = 96, 
                 'ASO4I' = 96, 'ASO4J' = 96, 'ASO4K' = 96)


make_nice_A = function() {
  par(xpd=NA)
#   rect(-200,0,0,950, col = 'white', border = FALSE)
#   rect(870,0,1200,950, col = 'white', border = FALSE)
#   rect(-100,-150,1200,0, col = 'white', border = FALSE)
#   rect(-100,960,1200,1200, col = 'white', border = FALSE)
  rect(-1000,-200,0,2800, col = 'white', border = FALSE)
  rect(2700,0,5000,2800, col = 'white', border = FALSE)
  rect(-200,-1000,2700,0, col = 'white', border = FALSE)
  rect(-100,2600,2500,3000, col = 'white', border = FALSE)
  
  
  par(mgp=c(3,1.7,0))
  box(lwd = 2)
#   axis(1, at = (0:4)*200, cex.axis = 2, lwd.ticks = 4)
#   axis(2, at = (0:4)*200, cex.axis = 2, lwd.ticks = 4)
}

add_a_legend_A <- function(iVar,iType,iSeas,subtitle,abs=TRUE) {
  var.base=list('SO2'='SO', 'ASO4'='SO', 'NO2'='NO', 'ANO3'='NO', 'O3'='O', 'N' = 'N')
  var.subscript=list('SO2'='2', 'ASO4'='4', 'NO2'='2', 'ANO3'='3', 'O3'='3', 'N' = '')
  var.superscript=list('SO2'='', 'ASO4'='2-', 'NO2'='', 'ANO3'='-', 'O3'='', 'N' = '')
  seas.base = list('win2013' = 'winter', 'spr2013' = 'spring', 'sum2013' = 'summer', 'aut2013' = 'autumn',
                   'win2008' = 'winter', 'spr2008' = 'spring', 'sum2008' = 'summer', 'aut2008' = 'autumn')
  type.base = list('CONC' = 'conc.', 'DEP' = 'dep.', 'WETDEP1' = 'wet dep.', 'DRYDEP' = 'dry dep.', , 'SSEMIS' = 'sea salt emis.')
  
  if (!abs) {
    legend('topleft', 
           legend = c(eval(bquote(expression(.(var.base[[iVar]])[.(var.subscript[[iVar]])]^.(var.superscript[[iVar]]) ~ .(type.base[[iType]]) ~ '[%],' ~.(seas.base[[iSeas]])))),
                      subtitle),
           bg = 'white', x.intersp = 0, y.intersp = 0.9, 
           text.font = 2, cex = 1.5)
  } else if (iUnit == 'ppmV') {
    legend('topleft', 
           legend = c(eval(bquote(expression(.(var.base[[iVar]])[.(var.subscript[[iVar]])]^.(var.superscript[[iVar]]) ~ .(type.base[[iType]]) ~ '[ppm'[V]*'],' ~.(seas.base[[iSeas]])))),
                      subtitle),
           bg = 'white', x.intersp = 0, y.intersp = 0.9, 
           text.font = 2, cex = 1.5)
  } else if (iUnit == 'ppbV') {
    legend('topleft', 
           legend = c(eval(bquote(expression(.(var.base[[iVar]])[.(var.subscript[[iVar]])]^.(var.superscript[[iVar]]) ~ .(type.base[[iType]]) ~ '[ppb'[V]*'],' ~.(seas.base[[iSeas]])))),
                      subtitle),
           bg = 'white', x.intersp = 0, y.intersp = 0.9, 
           text.font = 2, cex = 1.5)
  } else if (iUnit == 'micrograms/m**3') {
    legend('topleft', 
           legend = c(eval(bquote(expression(.(var.base[[iVar]])[.(var.subscript[[iVar]])]^.(var.superscript[[iVar]]) ~ .(type.base[[iType]]) ~ '['*mu*'g' ~ 'm'^-3 * '],' ~.(seas.base[[iSeas]])))),
                      subtitle),
           bg = 'white', x.intersp = 0, y.intersp = 0.9, 
           text.font = 2, cex = 1.5)
  } else if (iUnit == 'mg/(day*m2)') {
    legend('topleft', 
           legend = c(eval(bquote(expression(.(var.base[[iVar]])[.(var.subscript[[iVar]])]^.(var.superscript[[iVar]]) ~ .(type.base[[iType]]) ~ '[mg N' ~ 'm'^-2 * 'day'^-1 * '],' ~.(seas.base[[iSeas]])))),
                      subtitle),
           bg = 'white', x.intersp = 0, y.intersp = 0.9, 
           text.font = 2, cex = 1.5)
  }
}

add_a_legend_B <- function(iVar,iScen,subtitle,abs=TRUE) {
  var.base=list('SO2'='SO', 'NOX'='NO', 'PM25'='PM',
                'MASSJ' = 'dry mass', 'MASSK' = 'dry mass', 'MASST' = 'dry mass', 
                'NUMJ' = 'number', 'NUMK' = 'number', 'NUMT' = 'number')
  var.subscript=list('SO2'='2', 'NOX'='X', 'PM25'='2.5')
  var.superscript=list('SO2'='', 'NOX'='', 'PM25'='')
  scen.base = list('CD24_ALL' = 'reference', 'SAIL1' = 'SAIL1', 'SAIL2' = 'SAIL2',
                   'base' = 'base', 'noSurf' = 'noSurf')
  
  
  legend('topleft', 
#          legend = paste('scenario', scen.base[[iScen]], sep = ' '),
#          legend = paste('scenario ', scen.base[[iScen]], subtitle, '                       ', sep = ''),
         legend = paste(scen.base[[iScen]], subtitle, '                       ', sep = ''),
         bg = 'white', x.intersp = 0, y.intersp = 0.9, 
         text.font = 2, cex = 1.5)
}

color.my <- function(lut, min, max=-min, nticks=11, ticks=seq(min, max, len=nticks), title='', title1='', title2='') {
  scale = (length(lut)-1)/(max-min)
  
  #   dev.new(width=1.75, height=5)
  par(adj = 0.6)
  plot(c(0,10), c(min,max+(max-min)*0.2), type='n', bty='n', xaxt='n', xlab='', yaxt='n', ylab='')
  # title(title, line = 0)
  text(12, max+(max-min)*0.25, labels = title1, pos = 1, cex = 2)
  text(12, max+(max-min)*0.15, labels = title2, pos = 1, cex = 2)
  # axis(4, ticks, las=1, pos = 12, lwd = 0, lwd.tick = 4, font = 2, cex.axis = 2)
  axis(4, as.numeric(ticks), labels = ticks, las=1, pos = 12, lwd = 0, lwd.tick = 4, font = 2, cex.axis = 2)
  for (i in 1:(length(lut)-1)) {
    y = (i-1)/scale + min
    rect(11,y,12,y+1/scale, col=lut[i], border=NA)
  }
}

modify_my_plot <- function(iVar, iScen, iUnit, min, max, subtitle, centre = 0) {
  var.base=list('SO2'='SO', 'NOX'='NO', 'PM25'='PM',
                'MASSJ' = 'dry mass', 'MASSK' = 'dry mass', 'MASST' = 'dry mass', 
                'NUMJ' = 'number', 'NUMK' = 'number', 'NUMT' = 'number')
#                 'MASSJ' = 'dry mass acc. mode', 'MASSK' = 'dry mass coa. mode', 'MASST' = 'total dry mass', 
#                 'NUMJ' = 'numb. acc. mode', 'NUMK' = 'numb. coa. mode', 'NUMT' = 'total number')
  var.subscript=list('SO2'='2', 'NOX'='X', 'PM25'='2.5')
  var.superscript=list('SO2'='', 'NOX'='', 'PM25'='')
  scen.base = list('CD24_ALL' = 'reference', 'SAIL1' = 'SAIL1', 'SAIL2' = 'SAIL2',
                   'base' = 'base', 'noSurf' = 'noSurf')
  
  if(iUnit == '1e+19 particles/d') { title2 = expression('    [10'^19 ~ 'd'^-1 * ']')
  } else if(iUnit == 't/d') {        title2 = expression('    [t d'^-1 * ']')
  } else {                           title2 = paste('    [', iUnit,']', sep = '') }

  title1 = eval(bquote(expression('   '*.(var.base[[iVar]])[.(var.subscript[[iVar]])]^.(var.superscript[[iVar]]))))
  
  if(centre == 1) {
    if (max == -min) {
      # myTicks = ((-3):3)/3*max/10.5*9
      myTicks = formatC(((-3):3)/3*max/10.5*9, flag = "+", width = 4)
      print(myTicks)
      myCol = append(hotcolor_20lev, hotcolor_20lev[1])
    } else{
      myTicks = seq(from = min , to = max, length.out = 6)
      myCol = append(rain.bow, rain.bow[1])
    }
  } else {
    myTicks = (0:5)*(max-min)/17*15/5
    myCol = append(rain.bow, rain.bow[1])
  }
  
  add_a_legend_B(iVar,iScen,subtitle,abs=FALSE)
  make_nice_A()
  par(new = TRUE)
  color.my(myCol,
           min = min, max = max,
#            nticks = 7,
           ticks = myTicks,
           title1 = title1,
           title2 = title2)
}

# parameters ----

hotcolor_19lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
hotcolor_20lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(1,1,1), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
# rain.bow = rev(append(rainbow(16)[1:5],rainbow(12)[c(5, 7, 8, 9)]))
# rain.bow = rev(rainbow(18)[1:13])
rain.bow = rev(rainbow(24)[1:17])

#' unit conversion
# g/s into t/y => *31.536e+6 *1e-6
uConFac = 31.536
# Unit CONversion FACtor


#' seasons to read in
SCENs = c('base', 'noSurf')
MONs = c('win2008', 'sum2008')
myMONs = c('win2008' = 'winter 2008', 'sum2008' = 'summer 2008')
myModes = c('MASSJ' = 'J mode', 'MASSK' = 'K mode', 'MASST' = 'total',
            'NUMJ' = 'J mode', 'NUMK' = 'K mode', 'NUMT' = 'total')

iType = 'emis'


# initialise data arraies ----
if (data.read) {
  data.raw = list()
  for (iMon in MONs) {
    data.raw[[iMon]] = list()
    for (iScen in SCENs) {
      data.raw[[iMon]][[iScen]] = list()
    }    
  }    
}

if (data.work) {
  data.all = list()
  for (iMon in MONs) {
    data.all[[iMon]] = list()
    for (iScen in SCENs) {
      data.all[[iMon]][[iScen]] = list()
    }    
  }  
}


# read data ----
if (data.read ) {
  # get data ----
  for(iMon in MONs) {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      pIn = paste(dIn, 
                  paste('SSEMIS.CD24_', setup, '.', iScen, '_', mech, '_', iMon, '.short.timmean', sep = ''), 
                  sep = '/')
      
      print('    Reading NUMJ')
      data.raw[[iMon]][[iScen]]$NUMJ = read.griddata.lambert('NUMACC', file = pIn, grid = gridDesc)
      print('    Reading NUMK')
      data.raw[[iMon]][[iScen]]$NUMK = read.griddata.lambert('NUMCOR', file = pIn, grid = gridDesc)
      print('    Reading MASSJ')
      data.raw[[iMon]][[iScen]]$MASSJ = read.griddata.lambert('ASO4J', file = pIn, grid = gridDesc) + read.griddata.lambert('ACLJ', file = pIn, grid = gridDesc) + read.griddata.lambert('ANAJ', file = pIn, grid = gridDesc)
      print('    Reading MASSK')
      data.raw[[iMon]][[iScen]]$MASSK = read.griddata.lambert('ASO4K', file = pIn, grid = gridDesc) + read.griddata.lambert('ACLK', file = pIn, grid = gridDesc) + read.griddata.lambert('ANAK', file = pIn, grid = gridDesc)
            
      data.raw[[iMon]][[iScen]]$NUMT = data.raw[[iMon]][[iScen]]$NUMJ + data.raw[[iMon]][[iScen]]$NUMK
      data.raw[[iMon]][[iScen]]$MASST = data.raw[[iMon]][[iScen]]$MASSJ + data.raw[[iMon]][[iScen]]$MASSK
      
      data.raw[[iMon]][[iScen]]$NUMT$var = "NUMTOTAL"
      data.raw[[iMon]][[iScen]]$MASSJ$var = "MASSJ"
      data.raw[[iMon]][[iScen]]$MASSK$var = "MASSK"
      data.raw[[iMon]][[iScen]]$MASST$var = "MASSTOTAL"
    }
  }
}


if (data.work) {
  yScale = list('NUMJ' = 8.64*10^-15, 'NUMK' = 8.64*10^-15, 'NUMT' = 8.64*10^-15, 'MASSJ' = 0.0864, 'MASSK' = 0.0864, 'MASST' = 0.0864)
  for(iMon in MONs) {
    for (iScen in SCENs) {
      for(iMode in c('J','K','T')) {
        myMass=paste('MASS', iMode, sep = '')
        myNum=paste('NUM', iMode, sep = '')
        
        data.all[[iMon]][[iScen]][[myMass]] = data.raw[[iMon]][[iScen]][[myMass]] * yScale[[myMass]]
        data.all[[iMon]][[iScen]][[myNum]] = data.raw[[iMon]][[iScen]][[myNum]] * yScale[[myNum]]
        
        data.all[[iMon]][[iScen]][[myMass]]$unit = 't/d'
        data.all[[iMon]][[iScen]][[myNum]]$unit = '1e+19 particles/d'
      }
    }
  }
}


# plot data ----
if (data.plot) {
  
  scale.abs.max = list('MASSJ'=1.19,'MASSK'=68,'MASST'=68, 'NUMJ'=3.74,'NUMK'=0.34,'NUMT'=3.74)
  scale.rel.min = list('MASSJ'=-0.21,'MASSK'=-12.6,'MASST'=-12.6, 'NUMJ'=-0.735,'NUMK'=-0.063,'NUMT'=-0.735)
  scale.rel.max = list('MASSJ'=0.21,'MASSK'=12.6,'MASST'=12.6, 'NUMJ'=0.735,'NUMK'=0.063,'NUMT'=0.735)
  # for (iMon in c('win2008')) {
  for (iMon in MONs) {
    # for (iScen in c('base')) {
    for (iScen in SCENs) {
      myNames = names(data.all[[iMon]][[iScen]])
      # for (iVar in c('MASST')) {
      # for (iVar in myNames) {
      for (iVar in c('NUMT', 'MASST')) {
        myCol = rain.bow
        myLev = 18
        myLimAbs = c(0, scale.abs.max[[iVar]])
        myLimRel = c(scale.rel.min[[iVar]], scale.rel.max[[iVar]])
        myCent = 0
        
        iUnit = data.all[[iMon]][[iScen]][[iVar]]$unit
        
        subtitle = paste('', myMONs[[iMon]], myModes[[iVar]], sep = ', ')
        # tmpDat = zoom(data.all[[iMon]][[iScen]][[iVar]], frame = c(600,1800,600,1600))
        tmpDat = data.all[[iMon]][[iScen]][[iVar]]
        plot.griddata.lambert(tmpDat,
#                               hires=TRUE,
                              limits = myLimAbs,
                              col = rain.bow,
                              levels = 18)
        modify_my_plot(iVar, iScen, tmpDat$unit, 0, scale.abs.max[[iVar]], subtitle, centre = 0)
        if (iScen == 'CD24_ALL') tmpScen = 'REF' else tmpScen = iScen
        dev.copy2eps(file = paste('ssemis', 'abs', tmpScen, iMon, iVar, "eps", sep = "."),
                     width = 6.8, height = 6)
        dev.off()
        if(iScen != 'base') {
          subtitle = paste(' - base', myMONs[[iMon]], myModes[[iVar]], sep = ', ')
          # tmpDat = zoom(data.all[[iMon]][[iScen]][[iVar]] - data.all[['base']][[iVar]], frame = c(600,1800,600,1600))
          tmpDat = data.all[[iMon]][[iScen]][[iVar]] - data.all[[iMon]][['base']][[iVar]]
          # tmpDat$val[tmpDat$val>0] = 0
          tmpDat$val[tmpDat$val<scale.rel.min[[iVar]]] = scale.rel.min[[iVar]]
          plot.griddata.lambert(tmpDat,
#                                 hires=TRUE,
                                limits = myLimRel,
                                col = hotcolor_20lev,
                                levels = 22)
          modify_my_plot(iVar, iScen, tmpDat$unit, scale.rel.min[[iVar]], scale.rel.max[[iVar]], subtitle, centre = 1)
          dev.copy2eps(file = paste('ssemis', 'diff', iScen, '-base', iMon, iVar, "eps", sep = "."),
                       width = 6.8, height = 6)
          dev.off()
        }
      }
    }
  }
}


# create map for the publication ----
if(pub.plot) {
  print('')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('CREATING PLOT FOR PUBLICATION')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  
  #   source functions ----
  source('plot.griddata.mod.R')
  source('plot.griddata.lambert.mod.R')
  
  color.my.pub <- function(lut, min, max=-min, nticks=11, ticks=seq(min, max, len=nticks), title='', title1='', title2='', numbPos = 8) {
    scale = (length(lut)-1)/(max-min)
    
    #   dev.new(width=1.75, height=5)
    par(adj = 0.6)
    plot(c(0,10), c(min,max+(max-min)*0.2), type='n', bty='n', xaxt='n', xlab='', yaxt='n', ylab='')
    # plot(c(0,10), c(min,max+(max-min)*0.2), type='n', xlab='', yaxt='n', ylab='')
    # title(title, line = 0)
    text(5, max+(max-min)*0.25, labels = title1, pos = 1, cex = 1.8)
    text(7, max+(max-min)*0.15, labels = title2, pos = 1, cex = 1.5)
    # axis(4, ticks, las=1, pos = 12, lwd = 0, lwd.tick = 4, font = 2, cex.axis = 2)
    axis(4, as.numeric(ticks), labels = rep('',length(ticks)), las=1, pos = 3, lwd = 0, lwd.tick = 2, 
         font = 1)
    axis(4, as.numeric(ticks), labels = ticks, las=1, pos = numbPos, lwd = 0, lwd.tick = 0, 
         font = 1, cex.axis = 1.8, hadj = 1.0)
    for (i in 1:(length(lut)-1)) {
      y = (i-1)/scale + min
      rect(0.5,y,3,y+1/scale, col=lut[i], border=NA)
    }
  }
  
  
  #   set output device ----
  # postscript(file = paste('fig03_ssemis_maps', 'eps', sep = '.'), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 7.5)
  pdf(file = paste('fig03_ssemis_maps', 'pdf', sep = '.'), onefile=TRUE,
             paper = 'special', width = 10, height = 7.5)
  
  
  #   set page layout ----
  par(mar = c(0,0,0,0)+0, 
      mgp = c(1.5,0.5,0.0))
  
  bL = 0.01 # left boundary
  bR = 0.01 # right boundary
  bT = 0.02 # top boundary
  bB = 0.02 # bottom boundary
  dHor = 0.016 # horizontal distance between maps
  dVert = 0.016 # vertical distance between maps
  dLeg = 0.15 # width of the legend
  
  plWidth = (1 - bL - bR - 2*dHor - dLeg) / 2 # width per map
  plHeight = (1 - bT - bB - dVert) / 2 # height per map
  
  split.screen(rbind(c(bL, bL + plWidth, 1 - bT - plHeight, 1 - bT),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, 1 - bT - plHeight, 1 - bT),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR, 1 - bT - plHeight, 1 - bT),
                     c(bL, bL + plWidth, bB, bB + plHeight),
                     c(bL + plWidth + dHor, bL + 2*plWidth + dHor, bB, bB + plHeight),
                     c(bL + 2*plWidth + 2*dHor, 1 - bR,bB, bB + plHeight)))
  
  #   set some plotting parameters
  myUnit = expression('    [t d'^-1 * ']')
  myVar = 'dry mass'
  myLim.rain.bow = c(0,68)
  myLim.hot = c(-12.6, 12.6)
  hotcolor_20lev = c(rgb(  0/255,   0/255,  50/255), rgb( 24/255,  24/255, 112/255), rgb( 16/255,  78/255, 139/255), rgb( 23/255, 116/255, 205/255), rgb( 72/255, 118/255, 255/255), rgb( 91/255, 172/255, 237/255), rgb(173/255, 215/255, 230/255), rgb(209/255, 237/255, 237/255), rgb(229/255, 239/255, 249/255), rgb(242/255, 255/255, 255/255), rgb(1,1,1), rgb(253/255, 245/255, 230/255), rgb(255/255, 228/255, 180/255), rgb(243/255, 164/255,  96/255), rgb(237/255, 118/255,   0/255), rgb(205/255, 102/255,  29/255), rgb(224/255,  49/255,  15/255), rgb(237/255,   0/255,   0/255), rgb(205/255,   0/255,   0/255), rgb(139/255,   0/255,   0/255), rgb( 50/255,   0/255,   0/255))
  rain.bow = rev(rainbow(24)[1:17])
  
  #   plot map a) ----
  screen(1)
  plot.griddata.lambert.mod(data.all$win2008$base$MASST,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = TRUE)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'a)')
  
  #   plot map b) ----
  screen(2)
  plot.griddata.lambert.mod(data.all$sum2008$base$MASST,
                            limits = myLim.rain.bow, col = rain.bow, levels = 18, hires = TRUE)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'b)')
  
  #   plot map c) ----
  screen(4)
  plot.griddata.lambert.mod(data.all$win2008$noSurf$MASST - data.all$win2008$base$MASST,
                            limits = myLim.hot, col = hotcolor_20lev, levels = 22, hires = TRUE)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'c)')
  
  #   plot map d) ----
  screen(5)
  plot.griddata.lambert.mod(data.all$sum2008$noSurf$MASST - data.all$sum2008$base$MASST,
                            limits = myLim.hot, col = hotcolor_20lev, levels = 22, hires = TRUE)
  box()
  legend('topleft', legend = '', bg = 'white', x.intersp = 0, y.intersp = 0.2, cex = 1.5, title = 'd)')
  
  #   plot legend top row ----
  screen(3)
  myTicks = (0:5)*(myLim.rain.bow[2]-myLim.rain.bow[1])/17*15/5
  myCol = append(rain.bow, rain.bow[1])
  color.my.pub(myCol, min = myLim.rain.bow[1], max = myLim.rain.bow[2], ticks = myTicks,
               title1 = myVar, title2 = myUnit, numbPos = 7)
  
  #   plot legend bottom row ----
  screen(6)
  myTicks = formatC(((-3):3)/3*myLim.hot[2]/10.5*9, flag = "+", width = 4)
  myTicks[4] = '0.0'
  myCol = append(hotcolor_20lev, hotcolor_20lev[1])
  color.my.pub(myCol, min = myLim.hot[1], max = myLim.hot[2], ticks = myTicks,
               title1 = myVar, title2 = myUnit, numbPos = 9)
  
  # close screens and graphic device ----
  close.screen(all.screens = TRUE)
  dev.off()
}