library('ncdf4')

#' original: combine_sim_and_obs_v1.6.0_newPlotOrder.R

source('./handy_functions.R')

## save(list = ls(all=TRUE), file = "inData_SSEMIS_field_allSpecs_std_pub.RData")
## load("inData_SSEMIS_field_allSpecs_std_pub.RData")

## save(list = ls(all=TRUE), file = "inData_SSEMIS_field_allSpecs_std_pub_short.RData")
## load("inData_SSEMIS_field_allSpecs_std_pub_short.RData")

# Create plots for Daniel's extended Abstract for the ITM 2015 in Montpellier.
getSimData = FALSE
plotData = TRUE
simplifyData = FALSE
writeOutData = FALSE
plotType = 2 # 1 == lines/steps; 2 == points; 

# setup='effectSeaSalt'
# setup='seasalt3d'
setup='effectSeaSalt.v5'
strYear='2008'
# strYear='2013'
mech = 'cb05tucl_ae5_aq_ssa'


if(setup == 'seasalt3d') {
  ssSO4Mass = 0.0776
  ssNaMass = 0.3086
  ssClMass = 0.5538
  ssSeaCatMass = 0.3086+0.0368+0.0114+0.0118
} else if (setup == 'effectSeaSalt') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
} else if (setup == 'effectSeaSalt.v5') {
  ssSO4Mass = 0.0755
  ssNaMass = 0.3856
  ssRealNa2Cat = 0.7800
  ssClMass = 0.5389
}

# functions and constant ----
make_daily_mean <- function(series) {
  dim_old = dim(series)
  
  if (length(dim_old) <= 1) {
    n_old = length(series)
    n_new = n_old/24
    
    means = rep(0.0, n_new)
    
    for(i1 in 1:n_new) {
      means[i1] = mean(series[(1:24)+(i1-1)*24])
    }
  } else if (length(dim_old) == 2) {
    n_old = dim_old[2]
    n_new = n_old/24
    dim_new = c(dim_old[1], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,i1] = rowMeans(series[,(1:24)+(i1-1)*24], dims = 1)
    }
  } else if (length(dim_old) == 3) {
    n_old = dim_old[3]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,i1] = rowMeans(series[,,(1:24)+(i1-1)*24], dims = 2)
    }
  } else if (length(dim_old) == 4) {
    n_old = dim_old[4]
    n_new = n_old/24
    dim_new = c(dim_old[1], dim_old[2], dim_old[3], n_new)
    
    means = array(0.0, dim = dim_new)
    
    for(i1 in 1:n_new) {
      means[,,,i1] = rowMeans(series[,,,(1:24)+(i1-1)*24], dims = 3)
    }
  }
  
  return(means)
}


getYlim <- function(yMax, type) {
  if ( yMax == 0 ) {        yLim = 1
  } else if ( type == 1 ) { yLim = ceiling(yMax/10^(floor(log10(yMax))-1))*10^(floor(log10(yMax))-1)
  } else if ( type == 2 ) { yLim = signif(yMax, digits = 1) * 2
  } else if ( type == 3 ) { yLim = signif(yMax, digits = 1)
    if(yLim < yMax) yLim = signif(2*yMax-yLim, digits = 2)
  } else {                  yLim = 1
  }
  
  return(yLim)
}

# set some parameters ----
inDir = '~/storage/neumannd/data/cctm/CD24/analysis'
inOcean = '/home/neumannd/storage/M3HOME/data/ocean/sf050m_GIS/OCEAN_CD24_sf050m_GIS_ubound.nc'

MONs = c('win2008', 'sum2008')
SPECs = paste(rep(c('NUM', 'MASS'), each = 2), rep(c('J','K'), 2), sep = '')
myStations = c("A", "B", "C")
myCells = list('A' = list('x'=46, 'y'=43),
               'B' = list('x'=53, 'y'=44),
               'C' = list('x'=47, 'y'=77))
SCENs = c('base', 'noSurf')
# SCENs = c('base', 'noSurf', 'zero', 'full')


if (getSimData) {
  valSIM = list()
  for(iMon in MONs) {
    valSIM[[iMon]] = list()
    for(iScen in SCENs) { valSIM[[iMon]][[iScen]] = list() }
  }
}


# get data ----
if (getSimData) {
  print('  READING ocean File')
  ncId = nc_open(inOcean)
  valOpen = ncvar_get(ncId, 'OPEN')
  valSurf = ncvar_get(ncId, 'SURF')
  nc_close(ncId)
  print('  finished READING ocean File')

  for(iMon in MONs) {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      ncId = nc_open(paste(inDir, paste('SSEMIS.CD24_', setup, '.', iScen,
                                        '_', mech, '_', iMon, sep = ''), 
                           sep = '/'))
      
      print('    Reading NUMJ')
      valSIM[[iMon]][[iScen]]$NUMJ = ncvar_get(ncId, 'NUMACC')
      print('    Reading NUMK')
      valSIM[[iMon]][[iScen]]$NUMK = ncvar_get(ncId, 'NUMCOR')
      print('    Reading MASSJ')
      valSIM[[iMon]][[iScen]]$MASSJ = ncvar_get(ncId, 'ASO4J') + ncvar_get(ncId, 'ACLJ') + ncvar_get(ncId, 'ANAJ')
      print('    Reading MASSK')
      valSIM[[iMon]][[iScen]]$MASSK = ncvar_get(ncId, 'ASO4K') + ncvar_get(ncId, 'ACLK') + ncvar_get(ncId, 'ANAK')
      
      nc_close(ncId)
      
      valSIM[[iMon]][[iScen]]$NUMT = valSIM[[iMon]][[iScen]]$NUMJ + valSIM[[iMon]][[iScen]]$NUMK
      valSIM[[iMon]][[iScen]]$MASST = valSIM[[iMon]][[iScen]]$MASSJ + valSIM[[iMon]][[iScen]]$MASSK
      
    }
  }
}


# plot data ----
if(plotData) {  
  # define output file type ----
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
  
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('NUMJ' = expression('acc. mode particle number flux ['*10^19 ~ 'particles/d]'),
                  'NUMK' = expression('coarse mode particle number flux ['*10^19 ~ 'particles/d]'),
                  'NUMT' = expression('particle number flux ['*10^19 ~ 'particles/d]'),
                  'MASSJ' = expression('acc. mode particle mass flux [t/d]'),
                  'MASSK' = expression('coarse mode particle mass flux [t/d]'),
                  'MASST' = expression('particle mass flux [t/d]'))
  yScale = list('NUMJ' = 8.64*10^-15, 'NUMK' = 8.64*10^-15, 'NUMT' = 8.64*10^-15, 'MASSJ' = 0.0864, 'MASSK' = 0.0864, 'MASST' = 0.0864)
  yMaxVals = list('NUMJ' = 10, 'NUMK' = 1, 'NUMT' = 10, 'MASSJ' = 2, 'MASSK' = 140, 'MASST' = 140)
  
  for(iSpec in c(SPECs, c('NUMT', 'MASST'))) {  
  # for(iSpec in SPECs[c(6, 7)]) {  
  # for(iSpec in SPECs[c(5,4,3,1,2)]) {  
  # for(iStat in myStations){
    # postscript(file = paste('SSEMIS.timeseries', setup, iSpec, 
    #                         gsub('([0-9]{2}).([0-9]{2})', 'x\\1y\\2', paste(unlist(myCells), collapse = '.')),
    #                         'eps', sep = '.'), onefile=FALSE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    pdf(file = paste('SSEMIS.timeseries', setup, iSpec, 
                            gsub('([0-9]{2}).([0-9]{2})', 'x\\1y\\2', paste(unlist(myCells), collapse = '.')),
                            'pdf', sep = '.'), onefile=FALSE,
               paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6
    
    split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                       # top left, time series
                       c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       # top right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       # center left, time series
                       c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       # center right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       # bottom left, time series
                       c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                       # bottom right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                       c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
    ))
    iScreen = 1
    
    # make legend ----
    # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
    plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
    if(iSpec == 'Na') {
      tCol = 'orange'
      tPch = 8
      tLab = 'sim, full'
    } else {
      tCol = 'green'
      tPch = 4
      tLab = 'sim, zero'
    }
    if(plotType == 1) {
      legend('left', legend = c('base sea salt emis', 'noSurf sea salt emis', '  year 2008'),
             col = c('blue', 'red', 'white'), lwd = c(3,3,NA), 
             lty = c('solid', 'dotted', NA),
             bg = 'white', horiz = TRUE, inset = 0.02,
             pt.cex = 2, seg.len = 0.5, text.width = 0.2, bty = 'n')
    } else if (plotType == 2) {
      legend('left', legend = c('base sea salt emis', 'noSurf sea salt emis', '  year 2008'),
             col = c('blue', 'red', 'white'), lwd = c(2,2,NA), 
             lty = c(NA, NA, NA), pch = c(19, 1, NA),
             bg = 'white', horiz = TRUE, inset = 0.02,
             pt.cex = 2, seg.len = 0.5, text.width = 0.2, bty = 'n')
    }
    

    for(iStat in myStations){
      myLoc = myCells[[iStat]]
      
      myMax = 0
      for (iMon in MONs) {
        for(iScen in SCENs) {
          myMax = max(myMax, max(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][myLoc$x, myLoc$y,]), na.rm = TRUE))
        }
      }
      myLim = getYlim(myMax, 3)
      myLim = yMaxVals[[iSpec]]
      
      #for(iMon in c('win2008', 'win2008')) {
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'sum2008') {
          # nT = 92
          # from = 2008151
          # to = 2008242
          # nT = 91
          # from = 2008183
          # to = 2008273
          nT = 61
          from = 2008183
          to = 2008243
        } else if(iMon == 'win2008') {
          # nT = 30
          # from = 2008336
          # to = 2008365
          # nT = 91
          # from = 2008001
          # to = 2008091
          nT = 60
          from = 2008001
          to = 2008060
        }

        # prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIMbase = make_daily_mean(valSIM[[iMon]][[SCENs[1]]][[iSpec]][myLoc$x, myLoc$y,1:(nT*24)])*yScale[[iSpec]]
        pltSIMnoSu = make_daily_mean(valSIM[[iMon]][[SCENs[2]]][[iSpec]][myLoc$x, myLoc$y,1:(nT*24)])*yScale[[iSpec]]
        # pltSIMzero = make_daily_mean(valSIM[[iMon]][[SCENs[3]]][[iSpec]][myLoc$x, myLoc$y,])*yScale[[iSpec]]
        # pltSIMfull = make_daily_mean(valSIM[[iMon]][[SCENs[4]]][[iSpec]][myLoc$x, myLoc$y,])*yScale[[iSpec]]
      
        myMax = max(c(max(pltSIMbase),
                      max(pltSIMnoSu)))
#         myLim = getYlim(myMax, 3)
      
        # start plotting ----
        iScreen = iScreen + 1 
      
        screen(iScreen)
        plot(timeAxis[-nT-1], pltSIMbase,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
      
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
      
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(paste('location ', iStat, ',  ',
                                             paste('open=',formatC(valOpen[myCells[[iStat]]$x, myCells[[iStat]]$y]*100, format = 'f', width = 5, digits = 2),
                                                   '%,  surf=',formatC(valSurf[myCells[[iStat]]$x, myCells[[iStat]]$y]*100, format = 'f', width = 5, digits = 2),
                                                   '%', sep = ''), 
                                             sep = ''), line = -1)
        
#         polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
#                 col = 'darkgrey', border = FALSE)
      
        if (plotType == 1) {
          lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMbase, each = 2),
                col = 'blue', lwd =3)
          lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMnoSu, each = 2),
                col = 'red', lwd =2, lty = 'dotted')
          lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMnoSu, each = 2),
                col = 'red', lwd =1)
#           if (iSpec == 'Na') {
#             lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMfull, each = 2),
#                   col = 'orange', lwd =1)
#           } else {
#             lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMzero, each = 2),
#                   col = 'green', lwd =2, lty = 'dashed')
#             lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMzero, each = 2),
#                   col = 'green', lwd =1, lty = 'dotted')
#           }
        } else {
          # lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMbase, each = 2),
          #       col = 'blue', lwd = 1)
          # lines(rep(timeAxis, each = 2)[c(-1, -2*nT-2)], rep(pltSIMnoSu, each = 2),
          #       col = 'red', lwd = 1)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
                col = 'blue', pch = 19, cex = 0.8)
          points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMnoSu,
                col = 'red', pch = 1, cex = 0.8)
#           if (iSpec == 'Na') {
#             points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMfull,
#                   col = 'orange', pch = 8, cex = 0.7)
#           } else {
#             points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
#                   col = 'green', pch = 4, cex = 0.8)
#           }
        }
      
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        if (iSpec == 'Na') {
          boxplot(apply(rbind(pltSIMbase, pltSIMnoSu), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('blue', 'red'), range = 0)
          points(1:2, apply(rbind(pltSIMbase, pltSIMnoSu), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('blue', 'red'))
        } else {
          boxplot(apply(rbind(pltSIMbase, pltSIMnoSu), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                  yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('blue', 'red'), range = 0)
          points(1:2, apply(rbind(pltSIMbase, pltSIMnoSu), MARGIN = 1, FUN = mean, na.rm = TRUE),
                 pch = 18, col = c('blue', 'red'))
        }
      
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
  
}


if(simplifyData) {
  myPos = names(myCells)
  nPos = length(myPos)
  valOUT = list()
  
  
  for(iMon in MONs) {
    if(iMon == 'sum2008') { nT = 61*24 } else if(iMon == 'win2008') { nT = 60*24 }
    valOUT[[iMon]] = list()
    
    for(iScen in SCENs) {
      varNames = names(valSIM[[iMon]][[iScen]])
      valOUT[[iMon]][[iScen]] = list()
      
      for(iVar in varNames) {
        valOUT[[iMon]][[iScen]][[iVar]] = array(0.0, dim = c(nPos,nT))
        
        for (iPos in 1:nPos) {
          strPos = myPos[iPos]
          valOUT[[iMon]][[iScen]][[iVar]][iPos,] = valSIM[[iMon]][[iScen]][[iVar]][myCells[[strPos]]$x, myCells[[strPos]]$y, 1:nT]
        }
      }
    }
  }
}


if(writeOutData) {
  varNames = c('NUMJ','NUMK','NUMT','MASSJ','MASSK','MASST')
  headings = append(c('doy', 'hour'), varNames)
  
  myPos = names(myCells)
  nPos = length(myPos)
  
  for(iMon in MONs) {
    if(iMon == 'sum2008') {
      nT = 61
      from = 2008183
      to = 2008243
    } else if(iMon == 'win2008') {
      nT = 60
      from = 2008001
      to = 2008060
    }
    
    for(iScen in SCENs) {
      
      for (iPos in 1:nPos) {
        strPos = myPos[iPos]
        fOut = paste('ssemis.timeseries.values', iMon, iScen, strPos, 'csv', sep = '.')
        
        nT = length(valOUT[[iMon]][[iScen]]$MASST[iPos,])
        nDays = nT/24
        
        tmpOut = array(0.0, dim = c(nT,8))
        tmpOut[,1] = rep(seq(from, length.out = nDays), each = 24)
        tmpOut[,2] = rep(0:23, nDays)
        
        for(iVar in 1:length(varNames)) {
          strVar = varNames[iVar]
          
          tmpOut[,iVar+2] = valOUT[[iMon]][[iScen]][[strVar]][iPos,]
        }
        
        write.table(tmpOut, fOut, col.names = headings, row.names = FALSE, sep = ',')
      }
    }
  }
  
}