# corrected sulf wurde falsch berechnet!
# Das verhaeltnis ist fuer sulfat : sodium
# aber sulfat ist nicht in ug/m3 fuer sulfat sondern fuer schwefel angegeben!!!


# load libraries ----
library('cmaqtools')
library('ctmeval')

# configuration ----
myGrid = griddesc('CD24')
DBaccess <- list(name="neumannd-pg-emep_v02.1",uid="neumannd",pwd="nd$1,")
setup = 'effectSeaSalt.v5'
mech = 'cb05tucl_ae5_aq_ssa'
strYear = '2008'

# load/save data ----
## save(list = ls(all=TRUE), file = "inData_SIM_OBS_DE0001R_allSpecs_pmX.newer.RData")
## load("inData_SIM_OBS_DE0001R_allSpecs_pmX.newer.RData")

# what to do? ----
read.obs = FALSE
read.sim = FALSE
plot.dat = FALSE
write.stat = FALSE
writeOutData = TRUE

# parameters ----
MONs = c('win2008', 'sum2008')
SPECs = c('NO3', 'NH4', 'Na', 'SO4', 'XSO4')
SCENs = c('base', 'sp13.corr', 'ov14.corr', 'zero')

myStation = 'DE0001R'
myLoc = list(lat = 54.92556, lon = 8.309722)
myCell = findcell(myLoc, myGrid)

specScale = list('NO3' = 14/62, 'NH4' = 14/18, 'SO4' = 1/3, 'XSO4' = 1/3, 'Na' = 0.7800) # TODO
na2sulfOBS  = 0.077/0.306/3 # todo
na2sulfSIM = 0.0755/0.3856/3
ssSO4Mass = 0.0755
ssNaMass = 0.3856
ssRealNa2Cat = 0.7800
ssClMass = 0.5389

inDir = '/ocean-storage/neumannd/data/cctm/CD24/analysis'
# inDir = '/storage/neumannd/data/cctm/CD24/analysis'


# parameters for plotting
yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                'SO4' = expression("SO4"[4]^"2-" ~ 'concentration [' ~ mu * 'g S/' * m^3 * ']'),
                'Na' = expression("Na"^"+" ~ 'concentration [' ~ mu * 'g/' * m^3 * ']'),
                'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                'NH4' = expression("NH"[4]^"+" ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'),
                'NO3' = expression("NO"[3]^"-" ~ 'concentration [' ~ mu * 'g N/' * m^3 * ']'))
xAxisLab = list('win2008' = c('Jan', 'Feb', 'Mar'), 'sum2008' = c('Jul', 'Aug', 'Sept'))


# functions ----
getYlim <- function(yMax, type) {
  if ( yMax == 0 ) {
    yLim = 1
  } else if ( type == 1 ) {
    yLim = ceiling(yMax/10^(floor(log10(yMax))-1))*10^(floor(log10(yMax))-1)
  } else if ( type == 2 ) {
    yLim = signif(yMax, digits = 1) * 2
  } else if ( type == 3 ) {
    yLim = signif(yMax, digits = 1)
    if(yLim < yMax) {
      yLim = signif(2*yMax-yLim, digits = 2)
    }
  } else {
    yLim = 1
  }
  
  return(yLim)
}

plot_ts = function(jMon, jSpec, jLim, jTitle, jScreen, obsT = NULL, obs1 = NULL, obs2=NULL, simT = NULL, sim1=NULL, sim2=NULL, sim3=NULL, sim4=NULL) {
  
  if(!is.null(obs1)) {
    plot(obsT[-nT-1], obs1, type = 'n', ann = FALSE, ylim = c(0,jLim), yaxt = 'n', xaxt = 'n')
  } else {
    plot(obsT[-nT-1], obs2, type = 'n', ann = FALSE, ylim = c(0,jLim), yaxt = 'n', xaxt = 'n')
  }
  if(!is.null(obs2)) polygon(rep(obsT, each = 2), append(append(rep(obs2, each = 2), 0, after = 0), 0), 
                             col = 'black', border = FALSE)
  if(!is.null(obs1)) polygon(rep(obsT, each = 2), append(append(rep(obs1, each = 2), 0, after = 0), 0), 
                             col = 'darkgrey', border = FALSE)
  if(!is.null(sim1)) points(simT, sim1, col = 'cyan', pch = 19, cex = 0.8)
  if(!is.null(sim2)) points(simT, sim2, col = 'orange', pch = 1, cex = 0.8)
  if(!is.null(sim3)) points(simT, sim3, col = 'darkviolet', pch = 8, cex = 0.8)
  if(!is.null(sim4) && iSpec != 'Na') points(simT, sim4, col = 'red', pch = 4, cex = 0.8)
  
  axis(1,at = yTicks[[iMon]], labels = FALSE, tck = -0.03)
  if(jScreen %in% c(10,12)) axis(1,at = (yTicks[[iMon]][-1]+yTicks[[iMon]][-4])/2, tick = FALSE, labels = xAxisLab[[iMon]])
  
  axis(2)
  if(jScreen == 6 ) mtext(yAxisLab[[iSpec]],2, line = 1.6)
  
  if(jScreen%%4 == 0) title(jTitle, line = -1, cex.main = 1.5, font.main = 2)
}


# read obs ----
if(read.obs) {
  obsRaw = list()
  for (iMon in MONs){
    obsRaw[[iMon]] = list()
    for(iSpec in SPECs) {
      obsRaw[[iMon]][[iSpec]] = list()
      for(iSize in c('pm25', 'pm10')) {
        obsRaw[[iMon]][[iSpec]][[iSize]] = list() } } }
  
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('READING OBSERVATIONAL DATA FROM DATABASE')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  for (iMon in MONs) {
    if(iMon == 'sum2008' || iMon == 'sum') {
      from = 2008183
      to = 2008243
      nT = 61
    } else if(iMon == 'win2008' || iMon == 'win') {
      from = 2008001
      to = 2008060
      nT = 60
    }
    nTh = nT * 24
    
    for (iSpec in SPECs) {
      iSize = 'aerosol'
      if (iSpec != 'XSO4') {
        obsRaw[[iMon]][[iSpec]][['pm10']] = getobservationts(from, to, iSpec, myStation, iSize,
                                                            vlevel = gsub('or', 'and', gsub(', 781,', ',', vlevel(1)))) # TODO
      } else {
        obsRaw[[iMon]][[iSpec]][['pm10']] = obsRaw[[iMon]][['SO4']][['pm10']] - obsRaw[[iMon]][['Na']][['pm10']] * na2sulfOBS
        obsRaw[[iMon]][[iSpec]][['pm10']]$substance = 'XSO4'
      }
      
      obsRaw[[iMon]][[iSpec]][['pm25']] = obsRaw[[iMon]][[iSpec]][['pm10']]
      obsRaw[[iMon]][[iSpec]][['pm25']]$timeser$values[] = 0
    }
  }
}



# read sim ----
if(read.sim) {
  simRaw = list()
  for (iMon in MONs){
    simRaw[[iMon]] = list()
    for(iScen in SCENs) {
      simRaw[[iMon]][[iScen]] = list()
      for(iSpec in SPECs) {
        simRaw[[iMon]][[iScen]][[iSpec]] = list()
        for(iSize in c('pm25', 'pm10')) {
          simRaw[[iMon]][[iScen]][[iSpec]][[iSize]] } } } } 
  
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  print('READING SIMULATION DATA FROM NETCDF FILES')
  print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
  for (iMon in MONs) {
    if(iMon == 'sum2008' || iMon == 'sum') {
      from = 2008183
      to = 2008243
      nT = 61
    } else if(iMon == 'win2008' || iMon == 'win') {
      from = 2008001
      to = 2008060
      nT = 60
    }
    nTh = nT * 24
    
    myStart = c(myCell$x, myCell$y, 1, 1)
    myCount = c(1, 1, 1, nTh)
    
    for (iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, ' and time periode ', iMon, sep = ''))
      
      fAERO = paste(inDir, 
                    paste('BL_AERODIAM.CD24_effectSeaSalt.v5.', iScen, 
                          '_cb05tucl_ae5_aq_ssa_', iMon, '.short', sep = ''), 
                    sep = '/')
      fCONC = paste(inDir, 
                    paste('BL_CONC.CD24_effectSeaSalt.v5.', iScen, 
                          '_cb05tucl_ae5_aq_ssa_', iMon, '.short', sep = ''), 
                    sep = '/')
      
      # AERO fuer PM2.5
      print('    Reading Aerosol Size Parameters')
      ncId = nc_open(fAERO)
      fracI = ncvar_get(ncId, 'PM25AT', start = myStart, count = myCount)
      fracJ = ncvar_get(ncId, 'PM25AC', start = myStart, count = myCount)
      fracK = ncvar_get(ncId, 'PM25CO', start = myStart, count = myCount)
      nc_close(ncId)
      
      ncId = nc_open(fCONC)
      for (iSpec in SPECs) {
        print(paste('    Reading', iSpec, sep = ' '))
        if (iSpec != 'XSO4') {
          tmpI = ncvar_get(ncId, paste('A', toupper(iSpec), 'I', sep = ''), start = myStart, count = myCount)
          tmpJ = ncvar_get(ncId, paste('A', toupper(iSpec), 'J', sep = ''), start = myStart, count = myCount)
          tmpK = ncvar_get(ncId, paste('A', toupper(iSpec), 'K', sep = ''), start = myStart, count = myCount)
          simRaw[[iMon]][[iScen]][[iSpec]][['pm25']] = (tmpI*fracI + tmpJ*fracJ + tmpK*fracK) * specScale[[iSpec]]
          simRaw[[iMon]][[iScen]][[iSpec]][['pm10']] = (tmpI + tmpJ + tmpK) * specScale[[iSpec]]
        } else {
          for (iSize in c('pm25', 'pm10'))
          simRaw[[iMon]][[iScen]][[iSpec]][[iSize]] = simRaw[[iMon]][[iScen]][['SO4']][[iSize]] - simRaw[[iMon]][[iScen]][['Na']][[iSize]]  / ssRealNa2Cat / ssNaMass * ssSO4Mass / 3
        }
      }
      nc_close(ncId)
    }
  }
}



# plotting ----
if (plot.dat) {
  for(iSpec in SPECs) {
    # postscript(file = paste('fig12_CONC.timeseries', setup, iSpec, 'DE0001R', 'PM', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # postscript(file = paste('fig11_CONC.timeseries', setup, iSpec, 'DE0001R', 'PM', 'vert', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = TRUE, paper = 'special', width = 10, height = 6.5)
    pdf(file = paste(paste('fig11_CONC_timeseries', setup, iSpec, 'DE0001R', 'PM', sep = '_'), 'pdf', sep = '.'),
               paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    # plot: define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6 # center
    ShwB = ShrB-ShlB # width
    
    split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                       # top left, time series
                       c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       # top right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                       # center left, time series
                       c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       # center right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                       # bottom left, time series
                       c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                       c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                       # bottom right, time series
                       c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                       c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
    ))
    iScreen = 1
    
    # plot: legend ----
    screen(iScreen)
    plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
    if (iSpec == 'Na') {
    legend('left', legend = c(expression('OBS, PM'[10]), 'GO03', 'SP13', 'OV14', 'Westerland', 'year, 2008'),
           col = c('darkgrey', 'cyan', 'orange', 'darkviolet', 'white', 'white'), lwd = c(10,2,2,2,2, NA, NA), 
           lty = NA, pch = c(15, 19, 1, 8, NA, NA),
           bg = 'white', horiz = TRUE, inset = 0.02,
           pt.cex = 2, seg.len = 0.1, text.width = 0.16, bty = 'n')
    } else {
      legend('left', legend = c(expression('OBS, PM'[10]), 'GO03', 'SP13', 'OV14', 'zero', 'Westerland', '2008'),
             col = c('darkgrey', 'cyan', 'orange', 'darkviolet', 'red', 'white', 'white'), lwd = c(10,2,2,2,2, NA, NA), 
             lty = NA, pch = c(15, 19, 1, 8, 4, NA, NA),
             bg = 'white', horiz = TRUE, inset = 0.015,
             pt.cex = 2, seg.len = 0.05, text.width = 0.14, bty = 'n')
    }
    iScreen = iScreen + 1
    
    # plot: iterate sizes and month ----
    for (iMon in MONs) {
      refDate=2008001
      strYear='2008'
      if(iMon == 'sum2008' || iMon == 'sum') {
        # from = 2008151
        # to = 2008242
        nT = 61
        from = 2008183
        to = 2008243
      } else if(iMon == 'win2008' || iMon == 'win') {
        # from = 2008336
        # to = 2008365
        nT = 60
        from = 2008001
        to = 2008060
      }
      
      # plot: prepare plot data ----
      timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
      meanAxis = colMeans(rbind(timeAxis[-1],timeAxis[-nT-1]))
      yTicks = list('win2008' = c(1199145600, 1201824000, 1204329600, 1207008000),
                    'sum2008' = c(1215043200, 1217721600, 1220400000, 1222992000))
      
      pltOBS = list()
      pltOBSnoNA = list()
      pltSIM = list()
      myMax = list('pm25'=0,'pm10'=0)
      
      for(iSize in c('pm25', 'pm10')) {
        pltOBS[[iSize]] = obsRaw[[iMon]][[iSpec]][[iSize]]$timeser$value
        if ( is.null(pltOBS[[iSize]]) || length(pltOBS[[iSize]]) == 0) { pltOBS[[iSize]] = rep(0.0, nT) }
        pltOBSnoNA[[iSize]] = pltOBS[[iSize]]
        
        pltSIM[[iSize]] = list()
        for(iScen in c('base', 'sp13.corr', 'ov14.corr', 'zero')) {
          pltSIM[[iSize]][[iScen]] = colMeans(matrix(simRaw[[iMon]][[iScen]][[iSpec]][[iSize]][1:(nT*24)], nrow = 24), na.rm = TRUE)
          if (iScen != 'sp13.corr') myMax[[iSize]] = max(c(myMax[[iSize]], max(pltSIM[[iSize]][[iScen]], na.rm = TRUE)))
        }
      }
      
      for(iSize in c('pm25', 'pm10')) {
        pltOBSnoNA[[iSize]][!as.logical((!is.na(pltOBS[['pm10']]))*(!is.na(pltOBS[['pm25']])))] = 0
        myMax[[iSize]] = max(c(myMax[[iSize]], max(pltOBS[[iSize]], na.rm = TRUE))) 
      }
      
      myLim = list('pm10'=getYlim(myMax[['pm10']], 3), 
                   'pm25'=getYlim(myMax[['pm25']], 3), 
                   'pm10-pm25'=getYlim(max(max(pltOBSnoNA[['pm10']]-pltOBSnoNA[['pm25']], na.rm=TRUE),
                                           max(pltSIM[['pm10']][['base']]-pltSIM[['pm25']][['base']], na.rm=TRUE),
                                           max(pltSIM[['pm10']][['ov14.corr']]-pltSIM[['pm25']][['ov14.corr']], na.rm=TRUE),
                                           max(pltSIM[['pm10']][['zero']]-pltSIM[['pm25']][['zero']], na.rm=TRUE)), 
                                       3))
        
      # plot: time series ----
      screen(iScreen)
      iSize = 'pm10'
      plot_ts(iMon, iSpec, myLim[[iSize]], expression('PM'[10]), iScreen, 
              obsT = timeAxis, obs1 = pltOBSnoNA[['pm10']], obs2=pltOBSnoNA[['pm25']], 
              simT = meanAxis, sim1=pltSIM[[iSize]][['base']], sim2=pltSIM[[iSize]][['sp13.corr']], 
              sim3=pltSIM[[iSize]][['ov14.corr']], sim4=pltSIM[[iSize]][['zero']])
      
      screen(iScreen + 4)
      iSize = 'pm25'
      plot_ts(iMon, iSpec, myLim[[iSize]], expression('PM'[2.5]), iScreen+4,
              obsT = timeAxis, obs1 = pltOBSnoNA[['pm25']], 
              simT = meanAxis, sim1=pltSIM[[iSize]][['base']], sim2=pltSIM[[iSize]][['sp13.corr']], 
              sim3=pltSIM[[iSize]][['ov14.corr']], sim4=pltSIM[[iSize]][['zero']])
      
      screen(iScreen + 8)
      plot_ts(iMon, iSpec, myLim[['pm10-pm25']], expression('PM'['C']), iScreen+8,
              # obsT = timeAxis, obs2 = pltOBSnoNA[['pm10']]-pltOBSnoNA[['pm25']], 
              obsT = timeAxis, obs2 = pltOBSnoNA[['pm10']]-pltOBSnoNA[['pm10']], 
              simT = meanAxis, sim1=pltSIM[['pm10']][['base']]-pltSIM[['pm25']][['base']], 
              sim2=pltSIM[['pm10']][['sp13.corr']]-pltSIM[['pm25']][['sp13.corr']], 
              sim3=pltSIM[['pm10']][['ov14.corr']]-pltSIM[['pm25']][['ov14.corr']], 
              sim4=pltSIM[['pm10']][['zero']]-pltSIM[['pm25']][['zero']])
      
      iScreen = iScreen + 1
        
      # plot: box plots ----
      if (iSpec == 'Na') zeroCol = 'white' else zeroCol = 'red' # we need this for the Na+ data
      screen(iScreen)
      iSize = 'pm10'
      boxplot(apply(rbind(pltOBS[[iSize]], pltSIM[[iSize]][['base']], pltSIM[[iSize]][['sp13.corr']], pltSIM[[iSize]][['ov14.corr']], pltSIM[[iSize]][['zero']])[,!is.na(pltOBS[[iSize]])], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim[[iSize]]), border = c('black', 'cyan', 'orange', 'darkviolet', zeroCol), range = 0)
      points(1:5, apply(rbind(pltOBS[[iSize]], pltSIM[[iSize]][['base']], pltSIM[[iSize]][['sp13.corr']], pltSIM[[iSize]][['ov14.corr']], pltSIM[[iSize]][['zero']]), MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', zeroCol))
      
      screen(iScreen + 4)
      iSize = 'pm25'
      boxplot(apply(rbind(pltOBS[[iSize]], pltSIM[[iSize]][['base']], pltSIM[[iSize]][['sp13.corr']], pltSIM[[iSize]][['ov14.corr']], pltSIM[[iSize]][['zero']])[,!is.na(pltOBS[[iSize]])], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim[[iSize]]), border = c('black', 'cyan', 'orange', 'darkviolet', zeroCol), range = 0)
      points(1:5, apply(rbind(pltOBS[[iSize]], pltSIM[[iSize]][['base']], pltSIM[[iSize]][['sp13.corr']], pltSIM[[iSize]][['ov14.corr']], pltSIM[[iSize]][['zero']]), MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', zeroCol))
      
      screen(iScreen + 8)
      boxplot(apply(rbind(pltOBS[['pm10']]-pltOBS[['pm10']], 
                          pltSIM[['pm10']][['base']]-pltSIM[['pm25']][['base']], 
                          pltSIM[['pm10']][['sp13.corr']]-pltSIM[['pm25']][['sp13.corr']], 
                          pltSIM[['pm10']][['ov14.corr']]-pltSIM[['pm25']][['ov14.corr']], 
                          pltSIM[['pm10']][['zero']]-pltSIM[['pm25']][['zero']])[,as.logical(!is.na(pltOBS[['pm10']])*!is.na(pltOBS[['pm25']]))], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
              yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim[['pm10-pm25']]), border = c('black', 'cyan', 'orange', 'darkviolet', zeroCol), range = 0)
      points(1:5, apply(rbind(pltOBS[['pm10']]-pltOBS[['pm10']], 
                              pltSIM[['pm10']][['base']]-pltSIM[['pm25']][['base']], 
                              pltSIM[['pm10']][['sp13.corr']]-pltSIM[['pm25']][['sp13.corr']], 
                              pltSIM[['pm10']][['ov14.corr']]-pltSIM[['pm25']][['ov14.corr']], 
                              pltSIM[['pm10']][['zero']]-pltSIM[['pm25']][['zero']])[,as.logical(!is.na(pltOBS[['pm10']])*!is.na(pltOBS[['pm25']]))], MARGIN = 1, FUN = mean, na.rm = TRUE),
             pch = 18, col = c('black', 'cyan', 'orange', 'darkviolet', zeroCol))
      
      iScreen = iScreen + 1
       
    }
    
    # plot: finalize ----
    close.screen(all.screens = TRUE)
    dev.off()
  }
}



if(write.stat) {
  units = list()
  fStat = paste('stat', 'new', setup, mech, strYear, 'DE0001R', 'csv', sep = '.')
  
  write('SPECIES,SEASON,STATION,CASE,n,rae,mnb,cor,mean.sim,mean.obs,median.sim,median.obs', 
        file = fStat, append = FALSE)
  
  # for(iMon in c('win2008')) {
  for(iMon in MONs) {
    for(iScen in SCENs) {
      for(iSpec in SPECs[c(3,5,1,2)]) {
        
        for (iSize in c('pm25', 'pm10', 'pmC')) {
          
          if(iMon == 'sum2008') {
            nT = 61
            from = 2008183
            to = 2008243
          } else if(iMon == 'win2008') {
            nT = 60
            from = 2008001
            to = 2008060
          }
          
          if (iSize == 'pmC') {
            obs = obsRaw[[iMon]][[iSpec]][['pm10']]$timeser$value - obsRaw[[iMon]][[iSpec]][['pm25']]$timeser$value
            obs[obs<0] = NA
            sim = colMeans(matrix(simRaw[[iMon]][[iScen]][[iSpec]][['pm10']][1:(nT*24)], nrow = 24), na.rm = TRUE) - colMeans(matrix(simRaw[[iMon]][[iScen]][[iSpec]][['pm25']][1:(nT*24)], nrow = 24), na.rm = TRUE)
          } else {
            obs = obsRaw[[iMon]][[iSpec]][[iSize]]$timeser$value
            sim = colMeans(matrix(simRaw[[iMon]][[iScen]][[iSpec]][[iSize]][1:(nT*24)], nrow = 24), na.rm = TRUE)
          }
          
          validVals = !is.na(obs + sim)
          
          n = sum(validVals)
          rae = sum(abs(obs-sim), na.rm = TRUE)/sum(validVals)
          mean.sim = mean(sim[validVals])
          mean.obs = mean(obs[validVals])
          median.sim = median(sim[validVals])
          median.obs = median(obs[validVals])
          mnb = MNB(obs, sim)
          myCor = cor(sim[validVals], obs[validVals], method = 'spearman')
          
          write(paste(iSpec, iMon, iSize, iScen, n, rae, mnb, myCor, mean.sim, mean.obs, median.sim, median.obs, sep = ','), 
                file = fStat, append = TRUE)
        }
        
      }
    }
  }
}


# write out data for supplement ----
if(writeOutData) {
  myPos = c('pm2.5', 'pm10')
  nPos = length(myPos)
  headings = append(c('doy', 'hour'), myPos)
  
  
  for(iMon in MONs) {
    if(iMon == 'sum2008') {
      nT = 61*24
      from = 2008183
      to = 2008243
    } else if(iMon == 'win2008') {
      nT = 60*24
      from = 2008001
      to = 2008060
    }
    nDays = nT/24
    
    for(iScen in SCENs) {
      for(iSpec in SPECs[c(3)]) {
        print(paste(iMon, iScen, iSpec))
        fOut = paste('conc.timeseries.values', iMon, iScen, iSpec, myStation,'csv', sep = '.')
        
        tmpOut = array(0.0, dim = c(nT,nPos+2))
        tmpOut[,1] = rep(seq(from, length.out = nDays), each = 24)
        tmpOut[,2] = rep(0:23, nDays)
        
        # browser()
        
        for (iPos in 1:nPos) {
          strPos = sub('.', '', myPos[iPos], fixed = TRUE)
          tmpOut[,iPos+2] = simRaw[[iMon]][[iScen]][[iSpec]][[strPos]]
        }
        write.table(tmpOut, fOut, col.names = headings, row.names = FALSE, sep = ',')
      }
    }
  }
  
}