library('ncdf4')
library('cmaqtools')
library('ctmeval')

source('./handy_functions.R')
source('./list_stations.R')
source('../../65_R/78_tools/getYlim.R')
source('../../65_R/78_tools/make_daily_mean.R')

## save(list = ls(all=TRUE), file = "inData_combine_sim_ods_size_distribution.RData")
## load("inData_combine_sim_ods_size_distribution.RData")

# Create plots for Daniel's extended Abstract for the ITM 2015 in Montpellier.
getSimData = FALSE
plotDataA = FALSE # all
plotDataB = FALSE # Westerland, Waldhof and Zingst; summer
plotDataC = FALSE # Zingst; summer
plotDataD = FALSE # Westerland; winter
plotDataE = FALSE # Westerland, Waldhof Zingst
plotDataF = FALSE # Westerland, Waldhof Zingst
plotType = 2 # 1 == lines/steps; 2 == points; 
doStatistics = FALSE
doCorr = FALSE
writeOutData = TRUE

GRID_NAME='CD24'
setup='effectSeaSalt.v5'
mech = 'cb05tucl_ae5_aq_ssa'
strYear='2008'

## AERO6
# ssSO4Mass = 0.0776
# ssNaMass = 0.3086
# ssClMass = 0.5538
# ssSeaCatMass = 0.3086+0.0368+0.0114+0.0118
## AERO5
ssSO4Mass = 0.0755
ssNaMass = 0.3856
ssRealNa2Cat = 0.7800
ssClMass = 0.5389


# set some parameters ----
myGrid = griddesc(GRID_NAME)
DBaccess <- list(name="neumannd-pg-emep_v02.1",uid="neumannd",pwd="nd$1,")

inDir = '/ocean-storage/neumannd/data/cctm/CD24/analysis'

# MONs = c('win2008')
MONs = c('win2008', 'sum2008')

SPECs = c('DGATKN_DRY', 'DGACC_DRY', 'DGCOR_DRY', 'STDEVATKN', 'STDEVACC', 'STDEVCOR')
UNITS = list('DGATKN_DRY' = 'um', 'DGACC_DRY' = 'um', 'DGCOR_DRY' = 'um', 'STDEVATKN' = '', 'STDEVACC' = '', 'STDEVCOR' = '')

SCENs = c('base', 'sp13.corr', 'ov14.corr', 'zero')

nSTATION=-1

if (getSimData) {
  nCOL=-1
  nROW=-1
  valSIM = list()
  for(iMon in MONs) {
    valSIM[[iMon]] = list()
    for(iScen in SCENs) {
      valSIM[[iMon]][[iScen]] = list() } } }


# get data ----
for(iMon in MONs) {
  #' for case effectSeaSalt.v5
  if(iMon == 'sum2008' || iMon == 'sum') {
    from = 2008183
    to = 2008243
    nT = 61
  } else if(iMon == 'win2008' || iMon == 'win') {
    from = 2008001
    to = 2008060
    nT = 60
  }
  nTh = nT*24
  
  myStations = c("DE0001R", "DE0002R", "DE0003R", "DE0007R", "DE0009R", "DE0044R", "DK0003R", "DK0005R", "DK0008R", "DK0031R", "FI0009R", "FI0017R", "NO0001R", "NO0056R", "PL0002R", "PL0003R", "PL0004R", "SE0014R")
  nSTATIONS=length(myStations)
  
  myPositions = list()
  myCells = list()
  
  myPositions$DE0001R=list(lat=54.92556,lon=8.309722)
  myPositions$DE0002R=list(lat=52.80222,lon=10.75944)
  myPositions$DE0003R=list(lat=47.91472,lon=7.908611)
  myPositions$DE0007R=list(lat=53.16667,lon=13.03333)
  myPositions$DE0009R=list(lat=54.43333,lon=12.73333)
  myPositions$DE0044R=list(lat=51.53,lon=12.93)
  myPositions$DK0003R=list(lat=56.35,lon=9.6)
  myPositions$DK0005R=list(lat=54.73333,lon=10.73333)
  myPositions$DK0008R=list(lat=56.71667,lon=11.51667)
  myPositions$DK0031R=list(lat=56.28333,lon=8.433333)
  myPositions$FI0009R=list(lat=59.77917,lon=21.37722)
  myPositions$FI0017R=list(lat=60.52667,lon=27.68611)
  myPositions$NO0001R=list(lat=58.38333,lon=8.25)
  myPositions$NO0056R=list(lat=60.37222,lon=11.07806)
  myPositions$PL0002R=list(lat=51.81667,lon=21.98333)
  myPositions$PL0003R=list(lat=50.73333,lon=15.73333)
  myPositions$PL0004R=list(lat=54.75,lon=17.53333)
  myPositions$SE0014R=list(lat=57.39389,lon=11.91389)
  
  myCells$DE0001R=list(x=54,y=50)
  myCells$DE0002R=list(x=61,y=40)
  myCells$DE0003R=list(x=52,y=18)
  myCells$DE0007R=list(x=67,y=42)
  myCells$DE0009R=list(x=66,y=48)
  myCells$DE0044R=list(x=67,y=35)
  myCells$DK0003R=list(x=58,y=56)
  myCells$DK0005R=list(x=61,y=49)
  myCells$DK0008R=list(x=63,y=58)
  myCells$DK0031R=list(x=55,y=56)
  myCells$FI0009R=list(x=85,y=74)
  myCells$FI0017R=list(x=99,y=80)
  myCells$NO0001R=list(x=55,y=66)
  myCells$NO0056R=list(x=61,y=75)
  myCells$PL0002R=list(x=92,y=38)
  myCells$PL0003R=list(x=75,y=31)
  myCells$PL0004R=list(x=78,y=50)
  myCells$SE0014R=list(x=63,y=61)
  
  if(getSimData) {
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    print('READING SIMULATION DATA FROM NETCDF FILES')
    print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    
    # for(iScen in c('zero')) {
    for(iScen in SCENs) {
      print(paste('  READING netCDF files for scenario ', iScen, sep = ''))
      ncId = nc_open(paste(inDir, paste('BL_AERODIAM.CD24_', setup, '.', iScen,
                                        '_', mech, '_', iMon, '.short', sep = ''), 
                           sep = '/'))
            
      for (iSpec in SPECs) {
        print(paste('    Reading ', iSpec, sep = ''))
        valSIM[[iMon]][[iScen]][[iSpec]] = matrix(ncvar_get(ncId, iSpec, start = c(1,1,1,1), count = c(-1,-1, 1,nTh))[array(c(rep(t(array(unlist(myCells), dim = c(2,nSTATIONS))),each=nTh),rep(1:nTh, nSTATIONS)), dim = c(nTh*nSTATIONS,3))], ncol=nSTATIONS)
      }
      
      nc_close(ncId)
    }
  }
}

gc()

# plot dataA ----
if(plotDataA) {  
  # plot dataA: define output file type ----
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'A4')
  # postscript(file = paste('CONC.timeseries.', setup, '.ps', sep = ''), onefile=TRUE,
  #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
  
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('DGATKN_DRY' = expression('GMD'['Aitken'] ~ '[' ~ mu * 'm]'),
                  'DGACC_DRY' = expression('GMD'['accum.'] ~ '[' ~ mu * 'm]'),
                  'DGCOR_DRY' = expression('GMD'['coarse'] ~ '[' ~ mu * 'm]'),
                  'STDEVATKN' = expression(sigma['Aitken']),
                  'STDEVACC' = expression(sigma['accum.']),
                  'STDEVCOR' = expression(sigma['coarse']))
  
  # for(iSpec in SPECs[c(5,4,3,1,2,6, 7)]) {  
  for(iSpec in SPECs) {  
  # for(iSpec in SPECs[c(6, 7)]) {  
  # for(iSpec in SPECs[c(5,4,3,1,2)]) {  
    postscript(file = paste('AERO.timeseries', setup, iSpec, 'allStations', 'eps', sep = '.'), onefile=TRUE,
               horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # plot dataA: define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6 # center
    ShwB = ShrB-ShlB # width
    
    iScreen = 0
    
    # for(iLoc in 13:15){
    # for(iLoc in c(1, 2, 5)){
    for(iLoc in 1:nSTATIONS){
      # print(iScreen)
      if(iScreen%%13 == 0) {
        if(iScreen != 0) plot.new()
        iScreen = 1
        
        split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                           # top left, time series
                           c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # top right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # center left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # center right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # bottom left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           # bottom right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
        ))
        
        # plot dataA: make legend ----
        screen(iScreen)
        
        plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
        legend('left', legend = c('GO03', 'SP13', 'OV14', 'zero', '', '  year 2008'),
               col = c('cyan', 'orange', 'darkviolet', 'red', 'white', 'white'), lwd = c(2,2,2,2,2, NA), 
               lty = c(NA, NA, NA, NA, NA, NA), pch = c(19, 1, 8, 4, NA, NA),
               bg = 'white', horiz = TRUE, inset = 0.02,
               pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
      }
      iStat = myStations[iLoc]
      myLoc = myCells[[iStat]]
      
      
      myMax = 0
      for (iMon in MONs) {
        for(iScen in SCENs) {
          myMax = max(myMax, max(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][,iLoc]), na.rm = TRUE))
        }
      }
      myLim = getYlim(myMax, 3)
      
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'sum2008') {
          # nT = 92 ; from = 2008151 ; to = 2008242
          # nT = 91 ; from = 2008183 ; to = 2008273
          nT = 61
          from = 2008183
          to = 2008243
        } else if(iMon == 'win2008') {
          # nT = 30 ; from = 2008336 ; to = 2008365
          # nT = 91 ; from = 2008001 ; to = 2008091
          nT = 60
          from = 2008001
          to = 2008060
        }
        nTh = nT * 24

        # plot dataA: prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIMbase = make_daily_mean(valSIM[[iMon]][['base']][[iSpec]][1:nTh,iLoc])
        pltSIMsp13b = make_daily_mean(valSIM[[iMon]][['sp13.corr']][[iSpec]][1:nTh,iLoc])
        pltSIMov14m = make_daily_mean(valSIM[[iMon]][['ov14.corr']][[iSpec]][1:nTh,iLoc])
        pltSIMzero = make_daily_mean(valSIM[[iMon]][['zero']][[iSpec]][1:nTh,iLoc])
      
        myMax = max(c(max(pltSIMbase),
        #               max(pltSIMsp13b),
                      max(pltSIMov14m),
                      max(pltSIMzero)), na.rm = TRUE)
        myLim = getYlim(myMax, 3)
      
        # plot dataA: start plotting ----
        iScreen = iScreen + 1 
        # x11()
        screen(iScreen)
        plot(timeAxis[-nT-1], pltSIMbase,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
      
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
      
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(paste(list_stations[[iStat]], iStat, sep = ' '), line = -1)
          
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
              col = 'cyan', pch = 19, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMsp13b,
              col = 'orange', pch = 1, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMov14m,
              col = 'darkviolet', pch = 8, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
               col = 'red', pch = 4, cex = 0.7)
    
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
#         x11()
        boxplot(apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('cyan', 'orange', 'darkviolet', 'red'), range = 0)
        points(1:4, apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = mean, na.rm = TRUE),
               pch = 18, col = c('cyan', 'orange', 'darkviolet', 'red'))
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
  
}


# plot data B ----
if(plotDataB) {  
  iSpec = 'Na'
  postscript(file = paste('CONC.timeseries', 'eac', 'B', setup, iSpec, 'threeStat', 'eps', sep = '.'), onefile=TRUE,
             horizontal = FALSE, paper = 'special', width = 8, height = 4.5)
  par(mar = c(0,0,0,0)+0, 
      mgp = c(3,0.7,0.0))
  
  yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SO4' = expression("SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'Na' = expression("Na"^"+" ~ 'conc [' ~ mu * 'g/' * m^3 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
    
  # plot data B: define screens ----
  ShlB = 0.1 # left
  ShrB = 0.992 # right
  ShdB = 0.035 # Abstand
  SvtB = 0.91 # top
  SvbB = 0.08 # bottom
  SvdB = 0.02 # Abstand
  ShBox = 0.12
  
  ShcB = ShlB+(ShrB-ShlB)*3/6 # center
  ShwB = ShrB-ShlB # width
  
  split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                     # top right, time series
                     c(ShlB, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                     c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                     # center right, time series
                     c(ShlB, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                     c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                     # bottom right, time series
                     c(ShlB, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                     c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
  ))
  
  # plot data B: make legend ----
  iScreen = 1
  screen(iScreen)
  
  plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
  box(lwd = 2)
  
  legend('left', legend = c('OBS', 'GO03', 'SP13','OV14', '  year 2008'),
         col = c('darkgrey', 'cyan', 'red', 'darkviolet', 'white'), lwd = c(10,2,2,2,2, NA), 
         lty = c('solid', NA, NA, NA, NA), pch = c(NA, 19, 1, 8, NA),
         bg = 'white', horiz = TRUE, inset = 0.02,
         pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
  
  for(iLoc in c(1,2,5)){
    iStat = myStations[iLoc]
    myLoc = myCells[[iStat]]
    
    iMon = 'sum2008'
    refDate=2008001
    strYear='2008'
    nT = 61
    from = 2008183
    to = 2008243
    
    # plot data B: prepare data ----
    timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
    
    pltOBS = rep(0.0, nT)
    pltOBS = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$value[1:nT]
    if ( is.null(pltOBS) ||
           length(pltOBS) == 0) {
      pltOBS = rep(0.0, nT)
    }
    
    pltOBSnoNA = pltOBS
    pltOBSnoNA[is.na(pltOBS)] = 0
    
    # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
    pltSIMbase = make_daily_mean(valSIM[[iMon]][['base']][[iSpec]][1:(nT*24),iLoc])
    pltSIMsp13b = make_daily_mean(valSIM[[iMon]][['sp13.corr']][[iSpec]][1:(nT*24),iLoc])
    pltSIMov14m = make_daily_mean(valSIM[[iMon]][['ov14.corr']][[iSpec]][1:(nT*24),iLoc])
    
    myMax = max(c(max(pltOBS, na.rm = TRUE), 
                  max(pltSIMbase),
                  # max(pltSIMsp13b),
                  max(pltSIMov14m)), na.rm = TRUE)
    myLim = getYlim(myMax, 3)
    
    # plot data B: start plotting ----
    iScreen = iScreen + 1 
    screen(iScreen)
    plot(timeAxis[-nT-1], pltOBSnoNA,
         type = 'n', ann = FALSE, ylim = c(0,myLim*1.1),
         yaxt = 'n', xaxt = 'n', bty = 'n')
    box(lwd = 2)
    if ((iScreen-1)%%2 == 1) axis(2, labels = FALSE, lwd = 2, tck = -0.04)
    if (iScreen==2) axis(2, at = (0:2)*4, cex.axis = 1.5, lwd = 2)
    if (iScreen==4) axis(2, at = 0:2, cex.axis = 1.5, lwd = 2)
    if (iScreen==6) axis(2, at = c(0,3), cex.axis = 1.5, lwd = 2)
    if (iScreen==6) axis(2, at = 1.5, cex.axis = 1.5, lwd = 2)
    # if(iScreen > 12) axis(1)
    
    yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
    yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
    axis(1,at = yTicksSum, labels = FALSE, tck = -0.05, lwd = 2) # 1212278400, 1214870400, 1217548800, 1220227200
    if(iScreen == 6) axis(1,at = yTicksSum, labels = FALSE, tck = -0.1, lwd = 2)
    if(iScreen == 6) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'), cex.axis = 1.5, font = 2)
    # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
    if(iScreen == 4) mtext(yAxisLab[[iSpec]],2, line = 2.1, cex = 1.5)
    if (iScreen%%2 == 0) title(valOBS[[1]][[1]][[iStat]]$station$station_name, line = -1.2, cex.main = 1.5)
    
    polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
            col = 'darkgrey', border = FALSE)
    
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
           col = 'cyan', pch = 19, cex = 0.8)
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMsp13b,
           col = 'red', pch = 1, cex = 0.8)
    points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMov14m,
           col = 'darkviolet', pch = 8, cex = 0.8)
    
    iScreen = iScreen + 1 
    screen(iScreen)
    # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
    #       are available as observations and measurements.
    boxplot(apply(rbind(pltOBS, pltSIMbase, pltSIMsp13b, pltSIMov14m)[,!is.na(pltOBS)], MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
            yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim*1.1), border = c('black', 'cyan', 'red', 'darkviolet'), range = 0)
    points(1:4, apply(rbind(pltOBS, pltSIMbase, pltSIMsp13b, pltSIMov14m), MARGIN = 1, FUN = mean, na.rm = TRUE),
           pch = 18, col = c('black', 'cyan', 'red', 'darkviolet'))
    box(lwd = 2)
  }
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot data C ----
if(plotDataC) {  
  iSpec = 'NO3'
  iLoc = 5
  iStat = myStations[iLoc]
  myLoc = myCells[[iStat]]
  
  postscript(file = paste('CONC.timeseries', 'eac', 'C', setup, iSpec, 'oneStat', 'eps', sep = '.'), onefile=TRUE,
             horizontal = FALSE, paper = 'special', width = 8, height = 2.4)
#   postscript(file = paste('CONC.timeseries', 'eac', setup, iSpec, 'oneStat', 'eps', sep = '.'), onefile=TRUE,
#              horizontal = FALSE, paper = 'special', width = 8, height = 1.95)
  par(mar = c(0,0,0,0)+0, 
      mgp = c(3,0.7,0.0))
  
  yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SO4' = expression("SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'Na' = expression("Na"^"+" ~ 'conc [' ~ mu * 'g/' * m^3 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  
  # plot data C: define screens ----
  ShlB = 0.1 # left
  ShrB = 0.992 # right
  ShdB = 0.035 # Abstand
  SvtB = 0.831 # top
  SvbB = 0.15 # bottom
  SvdB = 0.0375 # Abstand
  ShBox = 0.12
  
  ShcB = ShlB+(ShrB-ShlB)*3/6 # center
  ShwB = ShrB-ShlB # width
  
  split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                     c(ShlB, ShrB-ShBox, SvbB, SvtB),
                     c(ShrB-ShBox, ShrB, SvbB, SvtB)
  ))
  
  # plot data C: make legend ----
  iScreen = 1
  screen(iScreen)
  # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
  #     x11()
  plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
  box(lwd = 2)
  
  legend('left', legend = c('OBS', 'GO03', 'SP13','OV14', 'no sea salt', '  year 2008'),
         col = c('darkgrey', 'cyan', 'red', 'darkviolet', 'orange', 'white'), lwd = c(10,2,2,2,2,2, NA), 
         lty = c('solid', NA, NA, NA, NA, NA), pch = c(NA, 19, 1, 8, 4, NA),
         bg = 'white', horiz = TRUE, inset = 0.02,
         pt.cex = 2, seg.len = 0.5, text.width = 0.13, bty = 'n')
  
  iMon = 'sum2008'
  refDate=2008001
  strYear='2008'
  nT = 61
  from = 2008183
  to = 2008243
  
  # plot data C: prepare data ----
  timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
  # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
  
  pltOBS = rep(0.0, nT)
  pltOBS = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$value[1:nT]
  if ( is.null(pltOBS) ||
         length(pltOBS) == 0) {
    pltOBS = rep(0.0, nT)
  }
  
  pltOBSnoNA = pltOBS
  pltOBSnoNA[is.na(pltOBS)] = 0
  
  # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
  pltSIMbase = make_daily_mean(valSIM[[iMon]][[SCENs[1]]][[iSpec]][1:(nT*24),iLoc])
  pltSIMsp13b = make_daily_mean(valSIM[[iMon]][[SCENs[2]]][[iSpec]][1:(nT*24),iLoc])
  pltSIMov14m = make_daily_mean(valSIM[[iMon]][[SCENs[3]]][[iSpec]][1:(nT*24),iLoc])
  pltSIMzero = make_daily_mean(valSIM[[iMon]][['zero']][[iSpec]][1:(nT*24),iLoc])
  
  myMax = max(c(max(pltOBS, na.rm = TRUE), 
                max(pltSIMbase),
                #                       max(pltSIMsp13b),
                max(pltSIMov14m),
                max(pltSIMzero)), na.rm = TRUE)
  myLim = getYlim(myMax, 3)
  
  # plot data C: start plotting ----
  iScreen = iScreen + 1 
  screen(iScreen)
  plot(timeAxis[-nT-1], pltOBSnoNA,
       type = 'n', ann = FALSE, ylim = c(0,myLim),
       yaxt = 'n', xaxt = 'n', bty = 'n')
  box(lwd = 2)
  axis(2, at = (0:6)/4, lwd = 2, cex.axis = 1.4, tck = -0.04, label = FALSE)
  axis(2, at = c(0, 1), lwd = 2, cex.axis = 1.4)
  axis(2, at = c(0.5, 1.5), lwd = 2, cex.axis = 1.4)
#   axis(2, labels = FALSE, lwd = 2, tck = -0.04)
#   axis(2, at = (0:2)*4, cex.axis = 1.5, lwd = 2)
  # if(iScreen > 12) axis(1)
  
  yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
  yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
  axis(1,at = yTicksSum, labels = FALSE, tck = -0.1, lwd = 2)
  axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'), cex.axis = 1.5, font = 2)
  # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
  mtext(yAxisLab[[iSpec]],2, line = 2.1, cex = 1.5)
  title(valOBS[[1]][[1]][[iStat]]$station$station_name, line = -1.2, cex.main = 1.5)
  
  polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
          col = 'darkgrey', border = FALSE)
  
  points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
         col = 'cyan', pch = 19, cex = 0.8)
  points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMsp13b,
         col = 'red', pch = 1, cex = 0.8)
  points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMov14m,
         col = 'darkviolet', pch = 8, cex = 0.8)
  points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
         col = 'orange', pch = 4, cex = 0.8)
  
  iScreen = iScreen + 1 
  screen(iScreen)
  # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
  #       are available as observations and measurements.
  boxplot(apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
          yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('cyan', 'orange', 'darkviolet', 'red'), range = 0)
  points(1:4, apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = mean, na.rm = TRUE),
         pch = 18, col = c('cyan', 'orange', 'darkviolet', 'red'))
  box(lwd = 2)
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot data D ----
if(plotDataD) {  
  iSpec = 'Na'
  iLoc = 1
  iStat = myStations[iLoc]
  myLoc = myCells[[iStat]]
  
  postscript(file = paste('CONC.timeseries', 'eac', 'D', setup, iSpec, 'oneStat', 'eps', sep = '.'), onefile=TRUE,
             horizontal = FALSE, paper = 'special', width = 5, height = 2.4)
  #   postscript(file = paste('CONC.timeseries', 'eac', setup, iSpec, 'oneStat', 'eps', sep = '.'), onefile=TRUE,
  #              horizontal = FALSE, paper = 'special', width = 8, height = 1.95)
  par(mar = c(0,0,0,0)+0, 
      mgp = c(3,0.7,0.0))
  
  
  
  yAxisLab = list('SNH4' = expression("NH"[4]^"+" ~ "+" ~ "NH"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SNO3' = expression("NO"[3]^"-" ~ "+" ~ "HNO"[3] ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'SO4' = expression("SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'Na' = expression("Na"^"+" ~ 'conc [' ~ mu * 'g/' * m^3 * ']'),
                  'XSO4' = expression("corr. SO4"[4]^"2-" ~ 'conc [' ~ mu * 'g S/' * m^3 * ']'),
                  'NH4' = expression("NH"[4]^"+" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'),
                  'NO3' = expression("NO"[3]^"-" ~ 'conc [' ~ mu * 'g N/' * m^3 * ']'))
  
  # plot data D: define screens ----
  ShlB = 0.16 # left
  ShrB = 0.992 # right
  ShdB = 0.035 # Abstand
  SvtB = 0.831 # top
  SvbB = 0.15 # bottom
  SvdB = 0.0375 # Abstand
  ShBox = 0.12
  
  ShcB = ShlB+(ShrB-ShlB)*3/6 # center
  ShwB = ShrB-ShlB # width
  
  split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                     c(ShlB, ShrB, SvbB, SvtB)
  ))
  
  # plot data D: make legend ----
  iScreen = 1
  screen(iScreen)
  # plot(c(0,1), c(0,1), axes = FALSE, ann = FALSE, type = 'n')
  #     x11()
  plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
  box(lwd = 2)
  
  legend('left', legend = c('EMEP obs.', 'model sea salt', 'year 2008'),
         col = c('darkgrey', 'cyan', 'white'), lwd = c(10,2,NA), 
         lty = c(NA, NA, NA), pch = c(15, 19, NA),
         bg = 'white', horiz = TRUE, inset = 0.02,
         pt.cex = 2, seg.len = 0.5, text.width = 0.3, bty = 'n')
  
  iMon = 'win2008'
  refDate=2008001
  strYear='2008'
  nT = 60
  from = 2008001
  to = 2008060
  
  # plot data D: prepare data ----
  timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
  # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
  
  pltOBS = rep(0.0, nT)
  pltOBS = valOBS[[iMon]][[iSpec]][[iStat]]$timeser$value[1:nT]
  if ( is.null(pltOBS) ||
         length(pltOBS) == 0) {
    pltOBS = rep(0.0, nT)
  }
  
  pltOBSnoNA = pltOBS
  pltOBSnoNA[is.na(pltOBS)] = 0
  
  # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
  pltSIMbase = make_daily_mean(valSIM[[iMon]][[SCENs[1]]][[iSpec]][1:(nT*24),iLoc])
  
  myMax = max(c(max(pltOBS, na.rm = TRUE), 
                max(pltSIMbase),
                #                       max(pltSIMsp13b),
                max(pltSIMov14m),
                max(pltSIMzero)), na.rm = TRUE)
  myLim = getYlim(myMax, 3)
  
  # plot data D: start plotting ----
  iScreen = iScreen + 1 
  screen(iScreen)
  plot(timeAxis[-nT-1], pltOBSnoNA,
       type = 'n', ann = FALSE, ylim = c(0,myLim),
       yaxt = 'n', xaxt = 'n', bty = 'n')
  box(lwd = 2)
  
  # axis(2, lwd = 2)
  # axis(2, at = (0:6)/4, lwd = 2, cex.axis = 1.4, tck = -0.04, label = FALSE)
  axis(2, at = (0:3)*5, lwd = 2, cex.axis = 1.4)
  # axis(2, at = c(0.5, 1.5), lwd = 2, cex.axis = 1.4)
  #   axis(2, labels = FALSE, lwd = 2, tck = -0.04)
  #   axis(2, at = (0:2)*4, cex.axis = 1.5, lwd = 2)
  # if(iScreen > 12) axis(1)
  
  yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
  yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
  axis(1,at = yTicksWin, labels = FALSE, tck = -0.1, lwd = 2)
  axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'), cex.axis = 1.5, font = 2)
  # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
  mtext(yAxisLab[[iSpec]],2, line = 2.1, cex = 1.5)
  title(valOBS[[1]][[1]][[iStat]]$station$station_name, line = -1.2, cex.main = 1.5)
  
  polygon(rep(timeAxis, each = 2), append(append(rep(pltOBSnoNA, each = 2), 0, after = 0), 0),
          col = 'darkgrey', border = FALSE)
  
  points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
         col = 'cyan', pch = 19, cex = 0.8)

  close.screen(all.screens = TRUE)
  dev.off()
}



# plot dataE ----
if(plotDataE) {  
  # plot dataE: define output file type ----
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('DGATKN_DRY' = expression('GMD'['Aitken'] ~ '[' ~ mu * 'm]'),
                  'DGACC_DRY' = expression('GMD'['accum.'] ~ '[' ~ mu * 'm]'),
                  'DGCOR_DRY' = expression('GMD'['coarse'] ~ '[' ~ mu * 'm]'),
                  'STDEVATKN' = expression(sigma['Aitken']),
                  'STDEVACC' = expression(sigma['accum.']),
                  'STDEVCOR' = expression(sigma['coarse']))
  
  for(iSpec in SPECs) {  
    postscript(file = paste('AERO.timeseries', setup, iSpec, 'threeStations', 'eps', sep = '.'), onefile=TRUE,
               horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # plot dataE: define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6 # center
    ShwB = ShrB-ShlB # width
    
    iScreen = 0
    
    # for(iLoc in 13:15){
    for(iLoc in c(1, 2, 5)){
    # for(iLoc in 1:nSTATIONS){
      # print(iScreen)
      if(iScreen%%13 == 0) {
        if(iScreen != 0) plot.new()
        iScreen = 1
        
        split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                           # top left, time series
                           c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # top right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # center left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # center right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # bottom left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           # bottom right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
        ))
        
        # plot dataE: make legend ----
        screen(iScreen)
        
        plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
        legend('left', legend = c('GO03', 'SP13', 'OV14', 'zero', '', '  year 2008'),
               col = c('cyan', 'orange', 'darkviolet', 'red', 'white', 'white'), lwd = c(2,2,2,2,2, NA), 
               lty = c(NA, NA, NA, NA, NA, NA), pch = c(19, 1, 8, 4, NA, NA),
               bg = 'white', horiz = TRUE, inset = 0.02,
               pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
      }
      iStat = myStations[iLoc]
      myLoc = myCells[[iStat]]
      
      
      myMax = 0
      for (iMon in MONs) {
        for(iScen in SCENs) {
          myMax = max(myMax, max(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][,iLoc]), na.rm = TRUE))
        }
      }
      myLim = getYlim(myMax, 3)
      
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'sum2008') {
          # nT = 92 ; from = 2008151 ; to = 2008242
          # nT = 91 ; from = 2008183 ; to = 2008273
          nT = 61
          from = 2008183
          to = 2008243
        } else if(iMon == 'win2008') {
          # nT = 30 ; from = 2008336 ; to = 2008365
          # nT = 91 ; from = 2008001 ; to = 2008091
          nT = 60
          from = 2008001
          to = 2008060
        }
        nTh = nT * 24
        
        # plot dataE: prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIMbase = make_daily_mean(valSIM[[iMon]][['base']][[iSpec]][1:nTh,iLoc])
        pltSIMsp13b = make_daily_mean(valSIM[[iMon]][['sp13.corr']][[iSpec]][1:nTh,iLoc])
        pltSIMov14m = make_daily_mean(valSIM[[iMon]][['ov14.corr']][[iSpec]][1:nTh,iLoc])
        pltSIMzero = make_daily_mean(valSIM[[iMon]][['zero']][[iSpec]][1:nTh,iLoc])
        
        myMax = max(c(max(pltSIMbase),
                      max(pltSIMov14m),
                      max(pltSIMzero)), na.rm = TRUE)
        myLim = getYlim(myMax, 3)
        
        # plot dataE: start plotting ----
        iScreen = iScreen + 1 
        # x11()
        screen(iScreen)
        plot(timeAxis[-nT-1], pltSIMbase,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
        
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
        
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(paste(list_stations[[iStat]], iStat, sep = ' '), line = -1)
        
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
               col = 'cyan', pch = 19, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMsp13b,
               col = 'orange', pch = 1, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMov14m,
               col = 'darkviolet', pch = 8, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
               col = 'red', pch = 4, cex = 0.7)
        
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        #         x11()
        boxplot(apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('cyan', 'orange', 'darkviolet', 'red'), range = 0)
        points(1:4, apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = mean, na.rm = TRUE),
               pch = 18, col = c('cyan', 'orange', 'darkviolet', 'red'))
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
  
}




# plot dataF ----
if(plotDataF) {  
  # plot dataF: define output file type ----
  # par(mar = c(0,0,0,0)+0, 
  #     mgp = c(1.5,0.5,0.0))
  
  yAxisLab = list('DGATKN_DRY' = expression('GMD'['Aitken'] ~ '[' ~ mu * 'm]'),
                  'DGACC_DRY' = expression('GMD'['accum.'] ~ '[' ~ mu * 'm]'),
                  'DGCOR_DRY' = expression('GMD'['coarse'] ~ '[' ~ mu * 'm]'),
                  'STDEVATKN' = expression(sigma['Aitken']),
                  'STDEVACC' = expression(sigma['accum.']),
                  'STDEVCOR' = expression(sigma['coarse']))
  
  for (iSpec in c('DGACC_DRY','DGCOR_DRY')) {
    # postscript(file = paste('fig13_AERO.timeseries', setup, iSpec, 'threeStationsF', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = FALSE, paper = 'special', width = 10, height = 6.5)
    # postscript(file = paste('fig13_AERO.timeseries', setup, iSpec, 'threeStationsF', 'vert', 'eps', sep = '.'), onefile=TRUE,
    #            horizontal = TRUE, paper = 'special', width = 10, height = 6.5)
    pdf(file = paste(paste('fig13_AERO_timeseries', setup, iSpec, 'threeStationsF', sep = '_'), 'pdf', sep = '.'), 
               paper = 'special', width = 10, height = 6.5)
    par(mar = c(0,0,0,0)+0, 
        mgp = c(1.5,0.5,0.0))
    
    
    # plot dataF: define screens ----
    ShlB = 0.07 # left
    ShrB = 0.992 # right
    ShdB = 0.035 # Abstand
    SvtB = 0.93 # top
    SvbB = 0.05 # bottom
    SvdB = 0.01 # Abstand
    ShBox = 0.06
    
    ShcB = ShlB+(ShrB-ShlB)*3/6 # center
    ShwB = ShrB-ShlB # width
    
    iScreen = 0
    
    # for(iLoc in 13:15){
    for(iLoc in c(1, 2, 6)){
    # for(iLoc in 1:nSTATIONS){
      # print(iScreen)
      if(iScreen%%13 == 0) {
        if(iScreen != 0) plot.new()
        iScreen = 1
        
        split.screen(rbind(c(ShlB,ShrB, SvtB+SvdB, 1.0-SvdB), # legend row
                           # top left, time series
                           c(ShlB, ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # top right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*2/3+SvdB/2, SvtB),
                           # center left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # center right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB+(SvtB-SvbB)*1/3+SvdB/2, SvbB+(SvtB-SvbB)*2/3-SvdB/2),
                           # bottom left, time series
                           c(ShlB,ShcB-ShdB/2-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShcB-ShdB/2-ShBox, ShcB-ShdB/2, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           # bottom right, time series
                           c(ShcB+ShdB/2, ShrB-ShBox, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2),
                           c(ShrB-ShBox, ShrB, SvbB, SvbB+(SvtB-SvbB)*1/3-SvdB/2)
        ))
        
        # plot dataF: make legend ----
        screen(iScreen)
        
        plot(c(0,1), c(0,1), xaxt = 'n', yaxt = 'n', ann = FALSE, type = 'n')
        legend('left', legend = c('GO03', 'SP13', 'OV14', 'zero', '', '  year 2008'),
               col = c('cyan', 'orange', 'darkviolet', 'red', 'white', 'white'), lwd = c(2,2,2,2,2, NA), 
               lty = c(NA, NA, NA, NA, NA, NA), pch = c(19, 1, 8, 4, NA, NA),
               bg = 'white', horiz = TRUE, inset = 0.02,
               pt.cex = 2, seg.len = 0.5, text.width = 0.15, bty = 'n')
      }
      iStat = myStations[iLoc]
      myLoc = myCells[[iStat]]
      
      
      myMax = 0
      for (iMon in MONs) {
        for(iScen in SCENs) {
          myMax = max(myMax, max(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][,iLoc]), na.rm = TRUE))
        }
      }
      myLim = getYlim(myMax, 3)
      
      for(iMon in MONs) {
        refDate=2008001
        strYear='2008'
        if(iMon == 'sum2008') {
          # nT = 92 ; from = 2008151 ; to = 2008242
          # nT = 91 ; from = 2008183 ; to = 2008273
          nT = 61
          from = 2008183
          to = 2008243
        } else if(iMon == 'win2008') {
          # nT = 30 ; from = 2008336 ; to = 2008365
          # nT = 91 ; from = 2008001 ; to = 2008091
          nT = 60
          from = 2008001
          to = 2008060
        }
        nTh = nT * 24
        
        # plot dataF: prepare data ----
        timeAxis = as.POSIXct((0:(nT) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        # timeAxis = as.POSIXct((0:(nT-1) + (from-refDate))*3600*24, tz = 'UTC', origin = "2008-01-01 00:00:00")
        
        # alternative: colMeans(array(ARRAY, dim = c(24,91)), na.rm = TRUE)
        pltSIMbase = make_daily_mean(valSIM[[iMon]][['base']][[iSpec]][1:nTh,iLoc])
        pltSIMsp13b = make_daily_mean(valSIM[[iMon]][['sp13.corr']][[iSpec]][1:nTh,iLoc])
        pltSIMov14m = make_daily_mean(valSIM[[iMon]][['ov14.corr']][[iSpec]][1:nTh,iLoc])
        pltSIMzero = make_daily_mean(valSIM[[iMon]][['zero']][[iSpec]][1:nTh,iLoc])
        
        myMax = max(c(max(pltSIMbase),
                      max(pltSIMov14m),
                      max(pltSIMzero)), na.rm = TRUE)
        myLim = getYlim(myMax, 3)
        if(iSpec=='DGACC_DRY') myLim = 0.17 else if(iSpec=='DGCOR_DRY') myLim = 2.4
        
        # plot dataF: start plotting ----
        iScreen = iScreen + 1 
        # x11()
        screen(iScreen)
        plot(timeAxis[-nT-1], pltSIMbase,
             type = 'n', ann = FALSE, ylim = c(0,myLim),
             yaxt = 'n', xaxt = 'n')
        
        if ((iScreen-1)%%2 == 1) axis(2)
        # if(iScreen > 12) axis(1)
        
        yTicksWin = c(1199145600, 1201824000, 1204329600, 1207008000)
        yTicksSum = c(1215043200, 1217721600, 1220400000, 1222992000)
        if(iScreen %in% c(2, 6, 10)) axis(1,at = yTicksWin, labels = FALSE, tck = -0.03)
        if(iScreen == 10) axis(1,at = (yTicksWin[-1]+yTicksWin[-4])/2, tick = FALSE, labels = c('Jan', 'Feb', 'Mar'))
        if(iScreen %in% c(4, 8, 12)) axis(1,at = yTicksSum, labels = FALSE, tck = -0.03) # 1212278400, 1214870400, 1217548800, 1220227200
        if(iScreen == 12) axis(1,at = (yTicksSum[-1]+yTicksSum[-4])/2, tick = FALSE, labels = c('Jul', 'Aug', 'Sept'))
        # if((iScreen-1)%%2 == 0) mtext(yAxisLab[[iSpec]],2, line = 1)
        if(iScreen == 6) mtext(yAxisLab[[iSpec]],2, line = 1.6)
        if ((iScreen-1)%%4 == 3) title(list_stations[[iStat]], line = -1)
        
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMbase,
               col = 'cyan', pch = 19, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMsp13b,
               col = 'orange', pch = 1, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMov14m,
               col = 'darkviolet', pch = 8, cex = 0.8)
        points(colMeans(rbind(timeAxis[-1],timeAxis[-nT-1])), pltSIMzero,
               col = 'red', pch = 4, cex = 0.7)
        
        iScreen = iScreen + 1 
        screen(iScreen)
        # NOTE: [,!is.na(pltOBS)] makes that only values are considered which
        #       are available as observations and measurements.
        #         x11()
        boxplot(apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = quantile, probs = c(0, 0.25, 0.5, 0.75, 1.0), na.rm = TRUE),
                yaxt = 'n', xaxt = 'n', xlab = '', ylab = '', ylim = c(0,myLim), border = c('cyan', 'orange', 'darkviolet', 'red'), range = 0)
        points(1:4, apply(rbind(pltSIMbase, pltSIMsp13b, pltSIMov14m, pltSIMzero), MARGIN = 1, FUN = mean, na.rm = TRUE),
               pch = 18, col = c('cyan', 'orange', 'darkviolet', 'red'))
      }
    }
    close.screen(all.screens = TRUE)
    dev.off()
  }
}



if(doStatistics) {
  units = list()
  fStat = paste('statistic', setup, mech, strYear, 'csv', sep = '.')
  fRAE = paste('stat', 'new', setup, mech, strYear, 'csv', sep = '.')
  # fIdx = paste('statistic', setup, mech, strYear, 'idx', sep = '.')
  
  file.remove(fStat)
  # file.remove(fRAE)
  # file.remove(fIdx)
  
  write('SPECIES,SEASON,STATION,CASE,n,rae,mnb,cor,mean.sim,mean.obs,median.sim,median.obs', 
        file = fRAE, append = FALSE)
  
  # for(iMon in c('win2008')) {
  for(iMon in MONs) {
    for(iScen in SCENs) {
      for(iSpec in SPECs[5]) {
#         print(paste(iMon, iScen, iSpec))
        obsDat = valOBS[[iMon]][[iSpec]]
        # simDat = griddata.lambert(make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]]), 
        #                           grid = myGrid, var = iSpec, unit = UNITS[[iSpec]])
        
        # statDat = summary.observationts(obsDat, simDat)
        # write(paste(iMon, iSpec, iScen, sep = "_"), file = fStat, append = TRUE) # add index
        # write.table(statDat, file = fStat, append=TRUE) # add statistics
        
        for (iStat in names(obsDat)) {
          # print(paste(iMon, iScen, iSpec, iStat))
          
          if(iMon == 'sum2008') {
            nT = 61
            from = 2008183
            to = 2008243
          } else if(iMon == 'win2008') {
            nT = 60
            from = 2008001
            to = 2008060
          }
          nTh = nT * 24
          
          iLoc = which(iStat == myStations)
          obs = obsDat[[iStat]]$timeser$values[1:nT]
          sim = make_daily_mean(valSIM[[iMon]][[iScen]][[iSpec]][1:nTh,iLoc])
          validVals = !is.na(obs + sim)
          
          n = sum(validVals)
          rae = sum(abs(obs-sim), na.rm = TRUE)/sum(validVals)
          mean.sim = mean(sim[validVals])
          mean.obs = mean(obs[validVals])
          median.sim = median(sim[validVals])
          median.obs = median(obs[validVals])
          mnb = MNB(obs, sim)
          myCor = cor(sim[validVals], obs[validVals], method = 'spearman')
          
          # write(paste(iSpec, iMon, iStat, iScen, formatC(rae, format = 'f', width = 4), sep = ','), 
          #       file = fRAE, append = TRUE)
          write(paste(iSpec, iMon, iStat, iScen, n, rae, mnb, myCor, mean.sim, mean.obs, median.sim, median.obs, sep = ','), 
                file = fRAE, append = TRUE)
        }
        
        # remove(obsDat,simDat,statDat)
      }
    }
  }
  #' make the files nice with
  #' sed -r ':a;N;$!ba;s/([a-zA-Z]+_[a-zA-Z0-9]+_[a-zA-Z]+)\n"station"/\n"\1" "station"/g' statistic.effectSeaSalt.cb05cl_ae5_aq.2008.csv | sed ':a;N;$!ba;s/^\n//g' > statistic.effectSeaSalt.cb05cl_ae5_aq.2008.csv
  #' sed -r ':a;N;$!ba;s/([a-zA-Z0-9]+_[a-zA-Z0-9]+_[a-zA-Z]+)\n"station"/\n"\1" "station"/g' statistic.effectSeaSalt.v5.cb05tucl_ae5_aq_ssa.2008.csv | sed ':a;N;$!ba;s/^\n//g' > statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.csv
  #' first sed: Remove newline between 'index' and 'statistics' (see above) and add a new
  #'            line above 'index'. The column headings of stations are no move on column
  #'            to the right. The first column of the heading row contains index.
  #' second sed: Remove the newline before the first data set.
  #' 
  #' make it even more nicer :-)
  #' cat statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.csv | tr '\n' ';' | sed -r 's/("(win|sum)2008_(SNH4|SNO3|SO4|XSO4|Na)_(noSurf|base|zero|full)") ([^;]*);"[123]" ([^;]*);"[123]" ([^;]*);"[123]" ([^;]*);/\1 \5;\1 \6;\1 \7;\1 \8/g' | sed -r 's/;"([^;"]*)" "station" [^;]*;/;/g' | sed 's/^"[^"]*"/"setup"/g' | tr ';' '\n' > statistic.effectSeaSalt.v5.cb05tucl_ae5_aq.2008.A.csv
  #' 
}



if(doCorr) {
  units = list()
  fCorr = paste('n_corr', setup, mech, strYear, 'csv', sep = '.')
  
  file.remove(fCorr)
  write('season,station,case,n,Robs,Rsim,species1,species2', file = fCorr, append = TRUE)
  
  NO3s = c('SNO3', 'NO3', 'HNO3')
  NH4s = c('SNH4', 'NH4', 'NH3')
  
  # for(iMon in c('win2008')) {
  for(iSpec in 1:2) {
    for(iMon in MONs) {
      for(iScen in SCENs) {
        for (iStat in names(valOBS[[iMon]]$SNH4)) {
          print(paste(iMon, iScen, iStat))
          iLoc = which(iStat == myStations)
          myLoc = myCells[[iStat]]
          
          tmpObsSNH4 = valOBS[[iMon]][[NH4s[iSpec]]][[iStat]]$timeser$values
          tmpObsSNO3 = valOBS[[iMon]][[NO3s[iSpec]]][[iStat]]$timeser$values
          tmpSimSNH4 = make_daily_mean(valSIM[[iMon]][[iScen]][[NH4s[iSpec]]][,iLoc])
          tmpSimSNO3 = make_daily_mean(valSIM[[iMon]][[iScen]][[NO3s[iSpec]]][,iLoc])
          validVals = !is.na(tmpObsSNH4+tmpObsSNO3+tmpSimSNH4+tmpSimSNO3)
          nVals = sum(validVals)
          
          corObs = cor(tmpObsSNH4[validVals], tmpObsSNO3[validVals], method = 'spearman')
          corSim = cor(tmpSimSNH4[validVals], tmpSimSNO3[validVals], method = 'spearman')
          
          write(paste(iMon, iStat, iScen, formatC(nVals, format = 'd'), 
                      formatC(corObs, format = 'f', width = 4), formatC(corSim, format = 'f', width = 4), 
                      NH4s[iSpec], NO3s[iSpec], sep = ','), 
                file = fCorr, append = TRUE)
        }
      }
    }
  }
}


# write out data for supplement ----
if(writeOutData) {
  myPos = names(myCells)
  nPos = length(myPos)
  headings = append(c('doy', 'hour'), myPos)
  
  
  for(iMon in MONs) {
    if(iMon == 'sum2008') {
      nT = 61*24
      from = 2008183
      to = 2008243
    } else if(iMon == 'win2008') {
      nT = 60*24
      from = 2008001
      to = 2008060
    }
    nDays = nT/24
    
    for(iScen in SCENs) {
      for(iSpec in SPECs) {
      # for(iSpec in SPECs[c(1,2,4,7)]) {
        print(paste(iMon, iScen, iSpec))
        fOut = paste('params.timeseries.values', iMon, iScen, iSpec, 'moreStations','csv', sep = '.')
        
        tmpOut = array(0.0, dim = c(nT,nPos+2))
        tmpOut[,1] = rep(seq(from, length.out = nDays), each = 24)
        tmpOut[,2] = rep(0:23, nDays)
        
        # browser()
        
        for (iPos in 1:nPos) {
          strPos = myPos[iPos]
          tmpOut[,iPos+2] = valSIM[[iMon]][[iScen]][[iSpec]][1:nT,iPos]
        }
        write.table(tmpOut, fOut, col.names = headings, row.names = FALSE, sep = ',')
      }
    }
  }
  
}
