plot.griddata.lambert.eps <-
function(x,title=NULL,hires=FALSE,observations=NULL,...) {
  ## uses plot.griddata and adds a map
  ## for griddata.lambert

  ## Often, it is recommendable to expand the map that is transformed to lambert
  ## so that all regions are displayed completely. The range of expansion is set with mapex

  mapex <- list(lon=c(-20,10),lat=c(-2,5))

  ## checks for data
  if (is.null(x$grid))
    stop("grid is missing")

  grid <- x$grid
   
  if (is.null(title))
    title <- x$var
  
  unit <- x$unit
 
  ## check for zooming
  if(!is.null(x$zoom)) {
    zooming <- TRUE
    zoom <- x$zoom }
  else
    zooming <- FALSE
  
  ## set up axes
  xcell <- grid$xcell
  ycell <- grid$ycell
  ncol <- grid$ncol
  nrow <- grid$nrow
  
  xaxis <- seq(xcell*0.5,xcell*(ncol-0.5),length.out=ncol)
  yaxis <- seq(ycell*0.5,ycell*(nrow-0.5),length.out=nrow)
  
  ## define the frame of world map
  ll <- lambert(lam=list(x=0,y=0),grid=grid,rev=TRUE) #lower left in lat lon
  ur <- lambert(lam=list(x=max(xaxis),y=max(yaxis)),grid=grid,rev=TRUE) # upper right ...
  XL <- c(ll$lon,ur$lon) + mapex$lon
  YL <- c(ll$lat,ur$lat) + mapex$lat

  ## apply zoom to the axes after setting the coordinates for the map
  if(zooming) {
    xaxis <- xaxis[zoom$coli]
    yaxis <- yaxis[zoom$rowi]

    if(length(xaxis)+length(yaxis)<2)
      stop("problems with the zoom attribute.")
  }

  ## imageplot
  gri <- plot.griddata.eps(x$val,xaxis,yaxis,unit=unit,title=title,...)

  ## create the map

  ## create the map without plotting it
  if (hires)
    mp0 <- map("worldHires",xlim=XL,ylim=YL,plot=FALSE)
  else
    mp0 <- map("world",xlim=XL,ylim=YL,plot=FALSE)

  ## project the map on cmaqs lambert conformal coordinates, defined by grid (see lambert)
  ## cut back to the required area
  mpl <- lambert.map(mp0,grid)
  usr <- par("usr")
  ##cutx <- mpl$x>=usr[1]
  ##cutx[1:(which(cutx)[1]-1)] <- FALSE
  ##mpl$x <- mpl$x[cutx]
  ##mpl$y <- mpl$y[cutx]
  mpl$range <- c(range(mpl$x,na.rm=TRUE),range(mpl$y,na.rm=TRUE))
  
  #plot the projected map
  map(mpl,add=TRUE)
  
  ## stay with the main plotregion
  par(mfg=c(1,1))

  ## show observations if requested
  if (!is.null(observations))
    show.observations(observations,gri$breaks,gri$colors,grid=grid)

}

