plot.griddata.mod <-
function(x,xaxis=1:dim(x)[1],yaxis=1:dim(x)[2],layer=1,unit="",limits=NULL,
         levels=8,col=conc.colors(n=levels),title="",smart=5,pmin=1e-8,
         legbottom=FALSE,...) {
  
  ## plots an image with the coordinates specified by xaxis and yaxis
  ## and a legend in a seperate plot window.
  
  x[abs(x)<abs(pmin)] <- NA
  
  matsize <- dim(x)
  
  if (xor(length(xaxis)<=2, length(yaxis)<=2))
    stop("Probably incorrect x- or y-axis.")
  
  if (length(yaxis)==2)
    xaxis <- seq(xaxis[1],xaxis[2],length.out=matsize[1])
  
  if (length(yaxis)==2)
    yaxis <- seq(yaxis[1],yaxis[2],length.out=matsize[2])
  
  if (length(matsize) > 2) {
    print(paste("The data matrix has more than two dimensions. Will plot layer.",layer))
    if (length(matsize) == 3)
      x <- x[,,layer]
    else if (length(matsize) == 4)
      x <- x[,,1,layer]
  }
  
  if (all(is.na(x))) {
    warning("Only NAs in Data. Maybe all values are below |pmin|.")
    x[is.na(x)] <- 0
    levels <- 1
    col <- NA
  }
  
  ## default title and unit
  if (is.null(title))
    title <- " "
  
  if (is.null(unit))
    unit <- " "
  
  if (length(dim(x))>3)
    stop(paste("Data matrix has more than 3 dimensions:",dim(x)))
  
  ## set up the color range and plot the image, default is to use quantiles along the levels
  if (is.null(limits))
    limits <- quantile(x,seq(0.05,0.95,length=levels),na.rm=TRUE)
  
  else if (length(limits)==1) 
    limits <- seq(min(x,na.rm=TRUE),limits,length=levels)
  
  else if (length(limits)==2) 
    limits <- seq(limits[1],limits[2],length=levels)
  
  else if (length(limits)!=levels)
    stop("Length of the limits vector must equal the number of levels")
  
  br <- c(limits,max(x,na.rm=TRUE)) #the breaks for the image
  
  col <- c(col[1:levels-1],col[length(col)]) #color levels for the image
  
  #open a new device and set layout
  image(xaxis,yaxis,x,col=col,breaks=br,ann=FALSE,yaxt = 'n', xaxt = 'n')
#   title(main=title)
  
  return(list(breaks=as.numeric(br),colors=col))
  
}
