


# overview
plotA=FALSE # overview plot with Gong, Spada and Ovadnevaite
plotU=FALSE # overview plot with Gong, Spada and Ovadnevaite, different scaling of axes
plotV=FALSE # overview plot with Gong, Spada and Ovadnevaite, high wind speed
plotW=FALSE # overview plot with Gong, Spada and Ovadnevaite, low wind speed
plotX=FALSE # overview plot with Gong, Spada and Ovadnevaite, one row modal split
plotXpub=FALSE # overview plot with Gong, Spada and Ovadnevaite, one row modal split
plotXpubB=TRUE # overview plot with Gong, Spada and Ovadnevaite, one row modal split
plotY=FALSE # overview plot with Gong, Spada and Ovadnevaite, one row
plotZpub=TRUE # overview plot with Gong, Spada and Ovadnevaite for different wind speeds
plotQpub=FALSE # overview plot with Gong and Spada for different salinities

# gong
plotB=FALSE # Gong parameterisation for different salinities
plotC=FALSE # Gong parameterisation for different wind speeds
plotM=FALSE # Gong: split for emis (two log-normal distributions)

# spada
plotD=FALSE # Spada parameterisation for different salinities
plotE=FALSE # Spada parameterisation for different wind speeds
plotF=FALSE # Spada parameterisation for different SSTs
plotN=FALSE # Spada: split for emis (two fix boundaries)

# ovadnevaite
plotG=FALSE # Ovadnevaite parameterisation for different salinities
plotH=FALSE # Ovadnevaite parameterisation for different wind speeds
plotI=FALSE # Ovadnevaite parameterisation for different salinities
plotO=FALSE # Ovadnevaite: split for emis (two fix boundaries)
plotP=FALSE # Ovadnevaite: split for emis (three log-normal distributions)



outDir="10_params_overview"
source('SW_tools.R')


# layout ----
myWidth=4.5
myHeight=3

colHZGlightblue = '#4CCCFF'
colHZGblue = '#0098D4'

leg.cex.l1 = 1
leg.cex.l2 = 1

ax.cex.lab = 1.2
ax.cex.ax = 1.3

cex.axis.pub = 0.8
cex.lab.pub = 1.0
cex.main.pub = 1.0
lwd.main.pub = 2

lwdMain = 4
lwdDD = 5

# ovadnevaite ----
Cd = 2.15 * 10^(-3)
Hs = 1.23
# vw = 1.34 * 10^(-6)
vw = SWkviscosity(283,'K', 35, 'g/kg') # = 1.35897e-06
u10 = 8 # m/s

ReHw = sqrt(Cd) * u10 * Hs / vw
Re = 3.1 * 10^6
Re = 340494.1

# standard deviation
stddev = c(1.37, 1.5, 1.42, 1.53, 1.85)
# count median diameter
cmd = c(0.018, 0.041, 0.09, 0.23, 0.83)
# cmd = c(0.018, 0.041, 0.09, 0.233, 0.83)

tnf_par1 = c(104.51,0.044,149.64,2.96,0.52)
tnf_par2 = c(0.556,1.08,0.545,0.79,0.87)
tnf_par3 = c(1e+5,1e+5,1e+5,1e+5,2e+5)
tnf <- function(Re, i1) {
  return(tnf_par1[i1] * (max(Re,tnf_par3[i1]) - tnf_par3[i1])^tnf_par2[i1])
}

dFdlogD_OV14 = function(D, Re, iModes = 1:5) {
  # The sqrt(2*pi)^(-1) comes from the functions which is called in the apply.
  # The "D^(-1)" is in the end of the calculation in order to make the order
  #  of the calculations more efficient.
  # return(rowSums(apply(array(iModes, dim = c(length(iModes),1)), MARGIN = 1, FUN = myModes, D = D, Re = Re)) / D)
  tmpVal = rep(0.0, length(D))
  for (iM in iModes) {
    tmpVal = tmpVal + tnf(Re, iM)/log10(stddev[iM])/sqrt(2*pi) * exp(-0.5 * (log10(D/cmd[iM])/log10(stddev[iM]))^2)
  }
  return(tmpVal)
}

dFdlogD_OV14_switchedArgs = function(Re,D) return(dFdlogD_OV14(D,Re))

dFdD_OV14 = function(D, Re, iModes = 1:5, tnff = tnf(Re, 1:5)) {
  # The sqrt(2*pi)^(-1) comes from the functions which is called in the apply.
  # The "D^(-1)" is in the end of the calculation in order to make the order
  #  of the calculations more efficient.
  # return(rowSums(apply(array(iModes, dim = c(length(iModes),1)), MARGIN = 1, FUN = myModes, D = D, Re = Re)) / D)
  tmpVal = rep(0.0, length(D))
  for (iM in iModes) {
    tmpVal = tmpVal + tnff[iM]/log10(stddev[iM])/sqrt(2*pi) * exp(-0.5 * (log10(D/cmd[iM])/log10(stddev[iM]))^2)
  }
  return(tmpVal / D / log(10))
}


# gong ----
dFdR_GO03 = function(R) {
  A = 4.7 * (1 + 30 * R)^(-0.017 * R^(-1.44))
  B = (0.433 - log10(R))/0.433
  outF = log(10)*R*u10^3.41 * 1.373 * R^(-A) * (1 + 0.057 * R^3.45) * 10^(1.607 * exp(-B^2))
  # outF = scaleW_GO03 * R * 3.5755 * 10^5 * R^(-A) * (1 + 0.057 * R^3.45) * 10^(1.607 * exp(-B^2))
  return(outF)
}

cmaqDGNJ = c(0.2651, 0.2677, 0.2696, 0.2713, 0.2736, 0.2752, 0.2768, 0.2784, 0.2806, 0.2823, 0.2840, 0.2858, 0.2883, 0.2903, 0.2924, 0.2951, 0.2974, 0.2998, 0.3028, 0.3054, 0.3080, 0.3113, 0.3140, 0.3174, 0.3203, 0.3232, 0.3267, 0.3297, 0.3332, 0.3363, 0.3394, 0.3430, 0.3462, 0.3499, 0.3533, 0.3573, 0.3611, 0.3652, 0.3700, 0.3752, 0.3806, 0.3871, 0.3945, 0.4030, 0.4129, 0.4246, 0.4259, 0.4271, 0.4284, 0.4298, 0.4311, 0.4328, 0.4342, 0.4356, 0.4371, 0.4385, 0.4401, 0.4416, 0.4434, 0.4451, 0.4467, 0.4484, 0.4501, 0.4518, 0.4538, 0.4556, 0.4575, 0.4594, 0.4613, 0.4633, 0.4655, 0.4676, 0.4697, 0.4718, 0.4740, 0.4764, 0.4787, 0.4811, 0.4835, 0.4859, 0.4886, 0.4912, 0.4938, 0.4965, 0.4994, 0.5022, 0.5051, 0.5081, 0.5112, 0.5143, 0.5175, 0.5208, 0.5242, 0.5276, 0.5312, 0.5348, 0.5386, 0.5424, 0.5463, 0.5503, 0.5544, 0.5587, 0.5631, 0.5675, 0.5722, 0.5769, 0.5818, 0.5867, 0.5919, 0.5972, 0.6026, 0.6083, 0.6140, 0.6201, 0.6263, 0.6325, 0.6392, 0.6458, 0.6529, 0.6600, 0.6676, 0.6751, 0.6833, 0.6914, 0.7001, 0.7088, 0.7177, 0.7276, 0.7372, 0.7478, 0.7582, 0.7690, 0.7810, 0.7928, 0.8050, 0.8187)
cmaqDGNK = c(1.7618, 1.8130, 1.8257, 1.8375, 1.8861, 1.8973, 1.9084, 1.9194, 1.9678, 1.9796, 1.9919, 2.0046, 2.0548, 2.0690, 2.0840, 2.1359, 2.1525, 2.1698, 2.2236, 2.2423, 2.2617, 2.3171, 2.3378, 2.3936, 2.4154, 2.4376, 2.4940, 2.5169, 2.5732, 2.5969, 2.6209, 2.6776, 2.7027, 2.7599, 2.7868, 2.8453, 2.8754, 2.9076, 2.9723, 3.0398, 3.0835, 3.1604, 3.2439, 3.3357, 3.4386, 3.5555, 3.5660, 3.5767, 3.5876, 3.5986, 3.6099, 3.6421, 3.6539, 3.6659, 3.6782, 3.6906, 3.7034, 3.7163, 3.7487, 3.7623, 3.7761, 3.7903, 3.8047, 3.8194, 3.8519, 3.8673, 3.8830, 3.8990, 3.9154, 3.9321, 3.9651, 3.9826, 4.0005, 4.0188, 4.0374, 4.0710, 4.0906, 4.1106, 4.1311, 4.1520, 4.1860, 4.2080, 4.2305, 4.2535, 4.2878, 4.3120, 4.3367, 4.3621, 4.3969, 4.4236, 4.4510, 4.4790, 4.5146, 4.5442, 4.5745, 4.6104, 4.6424, 4.6752, 4.7089, 4.7463, 4.7816, 4.8182, 4.8565, 4.8952, 4.9350, 4.9746, 5.0169, 5.0563, 5.1010, 5.1470, 5.1884, 5.2369, 5.2789, 5.3308, 5.3844, 5.4289, 5.4856, 5.5313, 5.5922, 5.6394, 5.7042, 5.7532, 5.8228, 5.8741, 5.9486, 6.0022, 6.0564, 6.1392, 6.1968, 6.2860, 6.3476, 6.4099, 6.5098, 6.5772, 6.6466, 6.7590)
cmaqSIGJ = c(1.7572, 1.7612, 1.7612, 1.7612, 1.7651, 1.7651, 1.7651, 1.7651, 1.7689, 1.7689, 1.7689, 1.7689, 1.7727, 1.7727, 1.7727, 1.7764, 1.7764, 1.7764, 1.7801, 1.7801, 1.7801, 1.7837, 1.7837, 1.7873, 1.7873, 1.7873, 1.7907, 1.7907, 1.7941, 1.7941, 1.7941, 1.7974, 1.7974, 1.8006, 1.8006, 1.8037, 1.8037, 1.8037, 1.8066, 1.8095, 1.8095, 1.8122, 1.8147, 1.8172, 1.8195, 1.8217, 1.8217, 1.8217, 1.8217, 1.8217, 1.8217, 1.8237, 1.8237, 1.8237, 1.8237, 1.8237, 1.8237, 1.8237, 1.8255, 1.8255, 1.8255, 1.8255, 1.8255, 1.8255, 1.8272, 1.8272, 1.8272, 1.8272, 1.8272, 1.8272, 1.8287, 1.8287, 1.8287, 1.8287, 1.8287, 1.8300, 1.8300, 1.8300, 1.8300, 1.8300, 1.8312, 1.8312, 1.8312, 1.8312, 1.8322, 1.8322, 1.8322, 1.8322, 1.8330, 1.8330, 1.8330, 1.8330, 1.8336, 1.8336, 1.8336, 1.8340, 1.8340, 1.8340, 1.8340, 1.8342, 1.8342, 1.8342, 1.8343, 1.8343, 1.8343, 1.8342, 1.8342, 1.8339, 1.8339, 1.8339, 1.8334, 1.8334, 1.8327, 1.8327, 1.8327, 1.8318, 1.8318, 1.8307, 1.8307, 1.8295, 1.8295, 1.8281, 1.8281, 1.8266, 1.8266, 1.8248, 1.8229, 1.8230, 1.8209, 1.8209, 1.8188, 1.8164, 1.8164, 1.8140, 1.8115, 1.8115)
cmaqSIGK = c(2.1039, 2.0834, 2.0834, 2.0834, 2.0639, 2.0639, 2.0639, 2.0639, 2.0452, 2.0452, 2.0452, 2.0452, 2.0273, 2.0273, 2.0273, 2.0101, 2.0101, 2.0101, 1.9937, 1.9937, 1.9937, 1.9780, 1.9780, 1.9631, 1.9631, 1.9631, 1.9488, 1.9488, 1.9351, 1.9351, 1.9351, 1.9222, 1.9222, 1.9098, 1.9098, 1.8981, 1.8981, 1.8981, 1.8870, 1.8765, 1.8765, 1.8666, 1.8573, 1.8486, 1.8405, 1.8329, 1.8329, 1.8329, 1.8329, 1.8329, 1.8329, 1.8259, 1.8259, 1.8259, 1.8259, 1.8259, 1.8259, 1.8259, 1.8195, 1.8195, 1.8195, 1.8195, 1.8195, 1.8195, 1.8137, 1.8137, 1.8137, 1.8137, 1.8137, 1.8137, 1.8085, 1.8085, 1.8085, 1.8085, 1.8085, 1.8038, 1.8038, 1.8038, 1.8038, 1.8038, 1.7997, 1.7997, 1.7997, 1.7997, 1.7963, 1.7963, 1.7963, 1.7963, 1.7934, 1.7934, 1.7934, 1.7934, 1.7913, 1.7913, 1.7913, 1.7897, 1.7897, 1.7897, 1.7897, 1.7888, 1.7889, 1.7889, 1.7886, 1.7886, 1.7886, 1.7891, 1.7891, 1.7904, 1.7903, 1.7903, 1.7923, 1.7924, 1.7952, 1.7952, 1.7952, 1.7988, 1.7989, 1.8034, 1.8034, 1.8089, 1.8090, 1.8155, 1.8154, 1.8230, 1.8230, 1.8318, 1.8417, 1.8417, 1.8529, 1.8529, 1.8656, 1.8799, 1.8799, 1.8960, 1.9138, 1.9138)
cmaqFNJ = c(89.326, 89.524, 89.524, 89.524, 89.709, 89.709, 89.709, 89.709,89.881, 89.881, 89.881, 89.881, 90.040, 90.040, 90.040, 90.188,90.188, 90.188, 90.325, 90.324, 90.324, 90.451, 90.451, 90.569,90.569, 90.569, 90.678, 90.678, 90.779, 90.779, 90.779, 90.873,90.873, 90.959, 90.959, 91.039, 91.039, 91.039, 91.113, 91.181,91.181, 91.243, 91.301, 91.353, 91.401, 91.445, 91.445, 91.445,91.445, 91.445, 91.445, 91.484, 91.484, 91.484, 91.484, 91.484,91.484, 91.484, 91.520, 91.520, 91.520, 91.520, 91.520, 91.520,91.551, 91.551, 91.551, 91.551, 91.551, 91.551, 91.579, 91.579,91.579, 91.579, 91.579, 91.604, 91.604, 91.604, 91.604, 91.604,91.625, 91.625, 91.625, 91.625, 91.642, 91.642, 91.642, 91.642,91.656, 91.656, 91.656, 91.656, 91.667, 91.667, 91.667, 91.675,91.675, 91.675, 91.675, 91.679, 91.679, 91.679, 91.680, 91.680,91.680, 91.678, 91.678, 91.672, 91.672, 91.672, 91.663, 91.663,91.650, 91.650, 91.650, 91.633, 91.633, 91.612, 91.612, 91.587,91.587, 91.558, 91.558, 91.524, 91.524, 91.485, 91.441, 91.441,91.392, 91.392, 91.337, 91.274, 91.274, 91.205, 91.129, 91.129)
cmaqFNK = c(11.315, 11.110, 11.110, 11.109, 10.919, 10.919, 10.919, 10.919, 10.740, 10.740, 10.740, 10.740, 10.573, 10.573, 10.573, 10.417, 10.417, 10.417, 10.270, 10.271, 10.271, 10.134, 10.134, 10.006, 10.006, 10.006, 9.886, 9.886, 9.774, 9.774, 9.774, 9.669, 9.669, 9.571, 9.571, 9.480, 9.480, 9.480, 9.395, 9.315, 9.315, 9.243, 9.174, 9.111, 9.053, 8.999, 8.999, 8.999, 9.000, 9.000, 9.000, 8.951, 8.951, 8.951, 8.951, 8.951, 8.951, 8.951, 8.907, 8.907, 8.907, 8.907, 8.907, 8.907, 8.867, 8.867, 8.867, 8.867, 8.867, 8.867, 8.832, 8.832, 8.832, 8.832, 8.832, 8.800, 8.800, 8.800, 8.800, 8.800, 8.773, 8.773, 8.773, 8.773, 8.751, 8.751, 8.751, 8.751, 8.732, 8.732, 8.732, 8.732, 8.718, 8.718, 8.718, 8.708, 8.708, 8.708, 8.708, 8.702, 8.703, 8.703, 8.701, 8.701, 8.701, 8.704, 8.704, 8.712, 8.712, 8.711, 8.724, 8.725, 8.742, 8.742, 8.742, 8.765, 8.765, 8.794, 8.794, 8.828, 8.828, 8.869, 8.869, 8.915, 8.915, 8.970, 9.031, 9.031, 9.101, 9.101, 9.179, 9.268, 9.268, 9.366, 9.476, 9.476)
cmaqVFLUX = c(3.38E-016,3.40E-016,3.47E-016,3.54E-016,3.55E-016,3.61E-016,3.68E-016,3.74E-016,3.75E-016,3.82E-016,3.89E-016,3.96E-016,3.98E-016,4.06E-016,4.15E-016,4.18E-016,4.28E-016,4.38E-016,4.43E-016,4.54E-016,4.66E-016,4.72E-016,4.84E-016,4.91E-016,5.04E-016,5.18E-016,5.25E-016,5.40E-016,5.47E-016,5.63E-016,5.78E-016,5.86E-016,6.03E-016,6.12E-016,6.30E-016,6.41E-016,6.61E-016,6.84E-016,6.99E-016,7.18E-016,7.49E-016,7.76E-016,8.08E-016,8.48E-016,8.98E-016,9.62E-016,9.70E-016,9.79E-016,9.88E-016,9.97E-016,1.01E-015,1.00E-015,1.01E-015,1.02E-015,1.03E-015,1.04E-015,1.05E-015,1.07E-015,1.06E-015,1.07E-015,1.09E-015,1.10E-015,1.11E-015,1.12E-015,1.12E-015,1.14E-015,1.15E-015,1.16E-015,1.18E-015,1.19E-015,1.19E-015,1.21E-015,1.22E-015,1.24E-015,1.26E-015,1.26E-015,1.28E-015,1.30E-015,1.32E-015,1.34E-015,1.34E-015,1.36E-015,1.38E-015,1.40E-015,1.41E-015,1.43E-015,1.46E-015,1.48E-015,1.49E-015,1.51E-015,1.54E-015,1.57E-015,1.58E-015,1.61E-015,1.64E-015,1.65E-015,1.69E-015,1.72E-015,1.76E-015,1.77E-015,1.81E-015,1.85E-015,1.87E-015,1.91E-015,1.96E-015,1.98E-015,2.03E-015,2.04E-015,2.10E-015,2.16E-015,2.18E-015,2.24E-015,2.27E-015,2.33E-015,2.40E-015,2.43E-015,2.51E-015,2.55E-015,2.63E-015,2.67E-015,2.76E-015,2.80E-015,2.91E-015,2.95E-015,3.07E-015,3.12E-015,3.17E-015,3.31E-015,3.37E-015,3.51E-015,3.58E-015,3.66E-015,3.83E-015,3.91E-015,4.00E-015,4.21E-015)
cmaqRH = c(0.45, 0.46, 0.47, 0.48, 0.49, 0.5, 0.51, 0.52, 0.53, 0.54, 0.55, 0.56, 0.57, 0.58, 0.59, 0.6, 0.61, 0.62, 0.63, 0.64, 0.65, 0.66, 0.67, 0.68, 0.69, 0.7, 0.71, 0.72, 0.73, 0.74, 0.75, 0.76, 0.77, 0.78, 0.79, 0.8, 0.81, 0.82, 0.83, 0.84, 0.85, 0.86, 0.87, 0.88, 0.89, 0.9, 0.901, 0.902, 0.903, 0.904, 0.905, 0.906, 0.907, 0.908, 0.909, 0.91, 0.911, 0.912, 0.913, 0.914, 0.915, 0.916, 0.917, 0.918, 0.919, 0.92, 0.921, 0.922, 0.923, 0.924, 0.925, 0.926, 0.927, 0.928, 0.929, 0.93, 0.931, 0.932, 0.933, 0.934, 0.935, 0.936, 0.937, 0.938, 0.939, 0.94, 0.941, 0.942, 0.943, 0.944, 0.945, 0.946, 0.947, 0.948, 0.949, 0.95, 0.951, 0.952, 0.953, 0.954, 0.955, 0.956, 0.957, 0.958, 0.959, 0.96, 0.961, 0.962, 0.963, 0.964, 0.965, 0.966, 0.967, 0.968, 0.969, 0.97, 0.971, 0.972, 0.973, 0.974, 0.975, 0.976, 0.977, 0.978, 0.979, 0.98, 0.981, 0.982, 0.983, 0.984, 0.985, 0.986, 0.987, 0.988, 0.989, 0.99)
cmaqDJKcut_RH = c(0.9733300,0.9931762,1.0002055,1.0065636,1.0253434,1.0313600,1.0373646,1.0433571,1.0619879,1.0684070,1.0748874,1.0817093,1.1016666,1.1093022,1.1173310,1.1382075,1.1470727,1.1563205,1.1785785,1.1886234,1.1987831,1.2222700,1.2329512,1.2569815,1.2684568,1.2799862,1.3044443,1.3164224,1.3410494,1.3534926,1.3659777,1.3910988,1.4040940,1.4296401,1.4435438,1.4702086,1.4858212,1.5026260,1.5325787,1.5642715,1.5867775,1.6236187,1.6640832,1.7091908,1.7600568,1.8185113,1.8240176,1.8292607,1.8347960,1.8406768,1.8463104,1.8616118,1.8676366,1.8736936,1.8800937,1.8862150,1.8929904,1.8994869,1.9148132,1.9220294,1.9289832,1.9362967,1.9436425,1.9510370,1.9668032,1.9746244,1.9827894,1.9910033,1.9992826,2.0079056,2.0239770,2.0330440,2.0421768,2.0513753,2.0609179,2.0773533,2.0873736,2.0977547,2.1082185,2.1187484,2.1358494,2.1471692,2.1585721,2.1703529,2.1875916,2.1998835,2.2125535,2.2256350,2.2431228,2.2567315,2.2707523,2.2851681,2.3030964,2.3180880,2.3337862,2.3518094,2.3683922,2.3851098,2.4022735,2.4211275,2.4390957,2.4579315,2.4776718,2.4971590,2.5177151,2.5378258,2.5593893,2.5792868,2.6021420,2.6255469,2.6464577,2.6713285,2.6924409,2.7190987,2.7463356,2.7683877,2.7975645,2.8200233,2.8510416,2.8744743,2.9075382,2.9313487,2.9669210,2.9920640,3.0298081,3.0555582,3.0811926,3.1238162,3.1506915,3.1960097,3.2249975,3.2536223,3.3043753,3.3357636,3.3674472,3.4246533)

dFdR_GO03_J = function(R) {
  iRH = 36
  return(log(10)*R*2*u10^3.41 *cmaqFNJ[iRH] * dlnorm(R*2, meanlog = log(cmaqDGNJ[iRH]), sdlog = log(cmaqSIGJ[iRH])))
}

dFdR_GO03_K = function(R) {
  iRH = 36
  return(log(10)*R*2*u10^3.41 *cmaqFNK[iRH] * dlnorm(R*2, meanlog = log(cmaqDGNK[iRH]), sdlog = log(cmaqSIGK[iRH])))
}


# spada ----
constMA03_a = (array(c(-2.5761655*10^35, -2.4522893*10^33,  1.0851561*10^29, 
                       5.9324436*10^28,  2.4035441*10^27, -9.8414340*10^23,
                       -2.8661743*10^21, -8.1478341*10^20,  3.1323593*10^18, 
                       -3.0029837*10^13,  1.1828503*10^14, -4.1645326*10^12,
                       -2.8808135*10^6 , -6.7429939*10^6 ,  2.1806374*10^6), dim = c(3,5))
               * array(rep(10^(6*(-4:0)), each = 3), dim = c(3,5)))

constMA03_b = (array(c( 7.1884656*10^37,  7.3683150*10^35, -2.8594762*10^31, 
                        -1.6156647*10^31, -7.3102149*10^29,  2.6012137*10^26,
                        6.7913299*10^23,  2.5283404*10^23, -8.2974644*10^20, 
                        1.8289469*10^16, -3.7872729*10^16,  1.1046678*10^15,
                        7.6092681*10^8 ,  2.2794005*10^9 , -5.8003880*10^8), dim = c(3,5))
               * array(rep(10^(6*(-4:0)), each = 3), dim = c(3,5)))


dFdR_MO86 = function(R) {
  B = (0.38 - log10(R))/0.65
  outF = log(10)*u10^3.41 * 1.373 * R * R^(-3) * (1 + 0.057 * R^1.05) * 10^(1.19 * exp(-B^2))
  #   outF = u10^3.41 * 1.373 * R^dFdLogR * R^(-3)  * 10^(1.19 * exp(-B^2))
  return(outF)
}


dFdR_MA03_1 = function(R) {
  outF = u10^3.41 * 3.84 * 10^(-6) * ((constMA03_a[1,5] + constMA03_a[1,4] * R + constMA03_a[1,3] * R^2 
                                         + constMA03_a[1,2] * R^3 + constMA03_a[1,1] * R^4) * tmpSST
                                        + (constMA03_b[1,5] + constMA03_b[1,4] * R + constMA03_b[1,3] * R^2 
                                           + constMA03_b[1,2] * R^3 + constMA03_b[1,1] * R^4))
  return(outF)
}

dFdR_MA03_2 = function(R) {
  outF = u10^3.41 * 3.84 * 10^(-6)  * ((constMA03_a[2,5] + constMA03_a[2,4] * R + constMA03_a[2,3] * R^2 
                                         + constMA03_a[2,2] * R^3 + constMA03_a[2,1] * R^4) * tmpSST
                                        + (constMA03_b[2,5] + constMA03_b[2,4] * R + constMA03_b[2,3] * R^2 
                                           + constMA03_b[2,2] * R^3 + constMA03_b[2,1] * R^4))
  return(outF)
}

dFdR_MA03_3 = function(R) {
  outF = u10^3.41 * 3.84 * 10^(-6) * ((constMA03_a[3,5] + constMA03_a[3,4] * R + constMA03_a[3,3] * R^2 
                                         + constMA03_a[3,2] * R^3 + constMA03_a[3,1] * R^4) * tmpSST
                                        + (constMA03_b[3,5] + constMA03_b[3,4] * R + constMA03_b[3,3] * R^2 
                                           + constMA03_b[3,2] * R^3 + constMA03_b[3,1] * R^4))
  return(outF)
}

dFdR_SM93 = function(R) {
  A1 = 10^{0.0676 * u10 + 2.43}
  A2 = 10^{0.959 * sqrt(u10) - 1.476}
  outF = log(10)* R * (A1 * exp(-3.1 * log(R/2.1)^2) + A2 * exp(-3.3 * log(R/9.2)^2))
  return(outF)
}




# parameters for plots ----
cutDIJ_dry = 0.1 # just chosen?!
cutDJK_dry = cmaqDJKcut_RH[36]/2

xVals = ((-200):100)/100
rVals = 10^xVals
# rVals = append(rVals, cutDIJ_dry, sum(rVals<cutDIJ_dry))
rVals = append(rVals, cutDJK_dry, sum(rVals<cutDJK_dry))

rMin_wet = 0.02
rI12_wet = 0.145
rI23_wet = 0.419
rMax_wet = 2.8
c1 = as.logical((rVals > rMin_wet) * (rVals <= rI12_wet))
c2 = as.logical((rVals > rI12_wet) * (rVals <= rI23_wet))
c3 = as.logical((rVals > rI23_wet) * (rVals <= rMax_wet))
c4 = (rVals > rMax_wet)

tmpSST = 283

iPosIJ = which(rVals == cutDIJ_dry)
iPosJK = which(rVals == cutDJK_dry)
iPosMax = length(rVals)

iPosIx = c(1,1:(iPosIJ-1),iPosIJ-1)
iPosJx = c(iPosIJ,iPosIJ:(iPosJK-1),iPosJK-1)
iPosKx = c(iPosJK,iPosJK:iPosMax,iPosMax)
iPosIy = 1:(iPosIJ-1)
iPosJy = iPosIJ:(iPosJK-1)
iPosKy = iPosJK:iPosMax


# plot A: overview all three funs ----
if(plotA) {
  postscript(paste(outDir,'ssemis_params_plotA_overview.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  vw = 1.34 * 10^(-6)
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  tmpSST = 283
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwdMain,
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'cyan',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals), log10(yVals_SP13), lwd = lwdMain, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwdMain, col = 'darkviolet')
  legend('bottomleft', legend = c('GO03', 'SP13','OV14'),
         col = c('cyan', 'orange', 'darkviolet'),
         lwd = c(3,3,3), cex = leg.cex.l1, inset = 0.02, bg = 'white')
  
  dev.off()
}


# plot B: Gong at three different SALs ----
if(plotB) {
  postscript(paste(outDir,'ssemis_params_plotB_gong_sal.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  u10 = 8 # m/s
  
  yVals_GO03 = dFdR_GO03(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = 4, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[rVals>0.06]), log10(37/35*yVals_GO03[rVals>0.06]), 
        lwd = lwdDD, col = '#4CCCFF', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10(37/35*yVals_GO03[rVals>0.06]), lwd = 1, col = '#4CCCFF')
  lines(log10(rVals[rVals>0.06]), log10(10/35*yVals_GO03[rVals>0.06]), 
        lwd = lwdDD, col = '#0098D4', lty = 'dotted')
  lines(log10(rVals[rVals>0.06]), log10(10/35*yVals_GO03[rVals>0.06]), lwd = 1, col = '#0098D4')
  legend('bottomleft', legend = c('37 g/kg', '35 g/kg','10 g/kg'),
         col = c('#4CCCFF', 'black', '#0098D4'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = 'salinity')
  legend('topright', legend = c(''),
         title = 'Gong, 2003', bty = 'n', cex = leg.cex.l2, inset = 0.02)
  
  dev.off()
}


# plot C: Gong at three different wind speeds ----
if(plotC) {
  postscript(paste(outDir,'ssemis_params_plotC_gong_wind.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  u10 = 8 # m/s
  
  yVals_GO03 = dFdR_GO03(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(1, 7), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  axis(2, at = 1:7, 
       labels = c(expression('10'^1),expression('10'^2),'','','','', expression('10'^7)),
       lwd = 0.5)
  lines(log10(rVals[rVals>0.06]), log10((15/8)^3.41*yVals_GO03[rVals>0.06]), 
        lwd = lwdDD, col = 'darkred', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10((15/8)^3.41*yVals_GO03[rVals>0.06]), 
        lwd = 1, col = 'darkred')
  lines(log10(rVals[rVals>0.06]), log10((1/8)^3.41*yVals_GO03[rVals>0.06]), 
        lwd = lwdDD, col = 'violet', lty = 'dotted')
  lines(log10(rVals[rVals>0.06]), log10((1/8)^3.41*yVals_GO03[rVals>0.06]), 
        lwd = 1, col = 'violet')
  legend('bottomleft', legend = c('15 m/s', '8 m/s','1 m/s'),
         col = c('darkred', 'black', 'violet'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'),
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = expression('u'[10]))
  legend('topright', legend = c(''), inset = 0.02,
         title = 'Gong, 2003', bty = 'n', cex = leg.cex.l2)
  
  dev.off()
}


# plot D: Spada at three different SALs ----
if(plotD) {
  postscript(paste(outDir,'ssemis_params_plotD_spada_sal.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  u10 = 8 # m/s
  tmpSST = 283
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10((37/35)^(1/3)*rVals), log10(yVals_SP13), 
        lwd = lwdDD, col = '#4CCCFF', lty = 'dashed')
  lines(log10((37/35)^(1/3)*rVals), log10(yVals_SP13), lwd = 1, col = '#4CCCFF')
  lines(log10((10/35)^(1/3)*rVals), log10(yVals_SP13), 
        lwd = lwdDD, col = '#0098D4', lty = 'dotted')
  lines(log10((10/35)^(1/3)*rVals), log10(yVals_SP13), lwd = 1, col = '#0098D4')
  legend('bottomleft', legend = c('37 g/kg', '35 g/kg','10 g/kg'),
         col = c('#4CCCFF', 'black', '#0098D4'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = 'salinity')
  legend('topright', legend = c(''), inset = 0.02, 
         title = 'Spada et al., 2013', bty = 'n', cex = leg.cex.l2)
  
  dev.off()
}



# plot E: Spada at three different wind speeds ----
if(plotE) {
  postscript(paste(outDir,'ssemis_params_plotE_spada_wind.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  u10 = 8 # m/s
  tmpSST = 283
  
  yVals_SP13 = rep(0.0, length(rVals))
  rValsLong = append(rVals, 11:30)
  yVals_SM93 = rep(0.0, length(rValsLong))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  u10 = 15 # m/s
  yVals_SM93[rValsLong > rMax_wet] = dFdR_SM93(rValsLong[rValsLong > rMax_wet])
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(1, at = (-2):2, labels = c('','','','',expression('10'^2)),
       lwd = 0.5)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  axis(2, at = 1:7, 
       labels = c(expression('10'^1),expression('10'^2),'','','','',expression('10'^7)),
       lwd = 0.5)
  lines(log10(rValsLong), log10(pmax((15/8)^3.41*append(yVals_SP13, rep(0.0, length(rValsLong) - length(rVals))),yVals_SM93)), 
        lwd = lwdDD, col = 'darkred', lty = 'dashed')
  lines(log10(rValsLong), log10(pmax((15/8)^3.41*append(yVals_SP13, rep(0.0, length(rValsLong) - length(rVals))),yVals_SM93)), 
        lwd = 1, col = 'darkred')
  lines(log10(rVals), log10((1/8)^3.41*yVals_SP13), 
        lwd = lwdDD, col = 'violet', lty = 'dotted')
  lines(log10(rVals), log10((1/8)^3.41*yVals_SP13), lwd = 1, col = 'violet')
  legend('topright', legend = c('15 m/s', '8 m/s','1 m/s'),
         col = c('darkred', 'black', 'violet'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'),
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = expression('u'[10]))
  legend('bottomleft', legend = c(''), title = 'Spada et al., 2013', 
         bty = 'n', cex = leg.cex.l2, inset = c(0.02,-0.12))
  
  dev.off()
}


# plot F: Spada at three different SSTs ----
if(plotF) {
  postscript(paste(outDir,'ssemis_params_plotF_spada_sst.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  u10 = 8 # m/s
  tmpSST = 283
  SSTs = c(278, 283, 288)
  
  yVals_SP13 = array(0.0, dim = c(3,length(rVals)))
  for (iSST in 1:3) {
    tmpSST = SSTs[iSST]
    yVals_SP13[iSST,c1] = dFdR_MA03_1(rVals[c1])
    yVals_SP13[iSST,c2] = dFdR_MA03_2(rVals[c2])
    yVals_SP13[iSST,c3] = dFdR_MA03_3(rVals[c3])
    yVals_SP13[iSST,c4] = dFdR_MO86(rVals[c4])
  }
  
  plot(log10(rVals), log10(yVals_SP13[2,]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals), log10(yVals_SP13[3,]), 
        lwd = lwdDD, col = 'orange', lty = 'dashed')
  lines(log10(rVals), log10(yVals_SP13[3,]), lwd = 1, col = 'orange')
  lines(log10(rVals), log10(yVals_SP13[1,]), 
        lwd = lwdDD, col = 'blue', lty = 'dotted')
  lines(log10(rVals), log10(yVals_SP13[1,]), lwd = 1, col = 'blue')
  legend('bottomleft', legend = c('288 K', '283 K','278 K'),
         col = c('orange', 'black', 'blue'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'),
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = 'SST')
  legend('topright', legend = c(''), inset = 0.02, 
         title = 'Spada et al., 2013', bty = 'n', cex = leg.cex.l2)
  
  dev.off()
}


# plot G: Ovadnevaite with different salinities ----
if(plotG) {
  postscript(paste(outDir,'ssemis_params_plotG_ovadnevaite_sal.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = c(37,35,10)
  vw = SWkviscosity(rep(tmpSST,3),'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = t(apply(matrix(ReHw,ncol=1),1,dFdlogD_OV14_switchedArgs, D = rVals))
  
  
  plot(log10(rVals), log10(yVals_OV14[2,]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals), log10(yVals_OV14[1,]), lwd = lwdDD, col = '#4CCCFF', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV14[1,]), lwd = 1, col = '#4CCCFF')
  lines(log10(rVals), log10(yVals_OV14[3,]), lwd = lwdDD, col = '#0098D4', lty = 'dotted')
  lines(log10(rVals), log10(yVals_OV14[3,]), lwd = 1, col = '#0098D4')
  legend('bottomleft', legend = c('37 g/kg', '35 g/kg','10 g/kg'),
         col = c('#4CCCFF', 'black', '#0098D4'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = 'salinity')
  legend('topright', legend = c(''), inset = 0.02, 
         title = 'Ovadnevaite et al., 2013', bty = 'n', cex = leg.cex.l2)
  
  dev.off()
}


# plot H: Ovadnevaite with different wind speeds ----
if(plotH) {
  postscript(paste(outDir,'ssemis_params_plotH_ovadnevaite_wind.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = c(15,8,2.4) # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = t(apply(matrix(ReHw,ncol=1),1,dFdlogD_OV14_switchedArgs, D = rVals))
  
  
  plot(log10(rVals), log10(yVals_OV14[2,]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(2, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  axis(2, at = 2:6, 
       labels = c(expression('10'^2),'','','',''),
       lwd = 0.5)
  lines(log10(rVals), log10(yVals_OV14[1,]), lwd = lwdDD, col = 'darkred', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV14[1,]), lwd = 1, col = 'darkred')
  lines(log10(rVals), log10(yVals_OV14[3,]), lwd = lwdDD, col = 'violet', lty = 'dotted')
  lines(log10(rVals), log10(yVals_OV14[3,]), lwd = 1, col = 'violet')
  legend('topright', legend = c('15 m/s', '8 m/s','2.4 m/s'),
         col = c('darkred', 'black', 'violet'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
         cex = 1, inset = 0, bg = 'white', ncol = 1)
  legend('topleft', legend = c(''), inset = c(0.02,-0.03), 
         title = 'Ovadnevaite et al., 2013', bty = 'n', cex = 1)
  
  dev.off()
}



# plot I: Ovadnevaite with different SSTs ----
if(plotI) {
  postscript(paste(outDir,'ssemis_params_plotI_ovadnevaite_sst.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = c(288,283,278)
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', rep(tmpSAL,3), 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = t(apply(matrix(ReHw,ncol=1),1,dFdlogD_OV14_switchedArgs, D = rVals))
  
  
  plot(log10(rVals), log10(yVals_OV14[2,]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals), log10(yVals_OV14[1,]), lwd = lwdDD, col = 'orange', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV14[1,]), lwd = 1, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14[3,]), lwd = lwdDD, col = 'blue', lty = 'dotted')
  lines(log10(rVals), log10(yVals_OV14[3,]), lwd = 1, col = 'blue')
  legend('bottomleft', legend = c('288 K', '283 K','278'),
         col = c('orange', 'black', 'blue'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = 'salinity')
  legend('topright', legend = c(''), inset = 0.02, 
         title = 'Ovadnevaite et al., 2013', bty = 'n', cex = leg.cex.l2)
  
  dev.off()
}


# plot M: Gong split ----
if(plotM) {
  postscript(paste(outDir,'ssemis_params_plotM_gong_split.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  u10 = 8 # m/s
  
  yVals_GO03 = array(0.0, dim = c(3, length(rVals)))
  yVals_GO03[1,] = dFdR_GO03(rVals)
  yVals_GO03[2, ] = dFdR_GO03_J(rVals)
  yVals_GO03[3, ] = dFdR_GO03_K(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[1,rVals>0.06]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
        lwd = 1, col = 'red', lty = 'solid')
  legend('bottomleft', legend = c('Full', 'K mode, Gong','J mode, Gong'),
         col = c('black', 'red', 'blue'),
         lwd = c(3,3,3), lty = c('solid', 'dashed', 'dashed'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white')
  legend('topleft', legend = c(''),
         title = 'Gong, 2003', bty = 'n', inset = 0.05, cex = leg.cex.l2)
  
  dev.off()
}



# plot N: Spada split ----
if(plotN) {
  postscript(paste(outDir,'ssemis_params_plotN_spada_split.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  tmpSST = 283
  u10 = 8 # m/s
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
        lwd = lwdDD, col = 'green', lty = 'dashed')
  lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
        lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
        lwd = 1, col = 'red', lty = 'solid')
  legend('bottomleft', legend = c('Full', 'K mode','J mode', 'I mode'),
         col = c('black', 'red', 'blue', 'green'),
         lwd = c(3,3,3,3), lty = c('solid', 'dashed', 'dashed', 'dashed'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white')
  legend('topright', legend = c(''),
         title = 'Spada et al., 2013', bty = 'n', inset = 0.08, cex = leg.cex.l2)
  
  dev.off()
}



# plot O: Ovadnevaite split, boundaries ----
if(plotO) {
  postscript(paste(outDir,'ssemis_params_plotO_ovadnevaite_split_bndy.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  
  yVals_OV13 = rep(0.0, length(rVals))
  yVals_OV13 = dFdlogD_OV14(rVals, ReHw, 1:5)
  
  
  plot(log10(rVals), log10(yVals_OV13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[iPosIx]), append(c(-10,-10), log10(yVals_OV13[iPosIy]), after = 1), 
        lwd = lwdDD, col = 'green', lty = 'dashed')
  lines(log10(rVals[iPosIx]), append(c(-10,-10), log10(yVals_OV13[iPosIy]), after = 1), 
        lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_OV13[iPosJy]), after = 1), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_OV13[iPosJy]), after = 1), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_OV13[iPosKy]), after = 1), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_OV13[iPosKy]), after = 1), 
        lwd = 1, col = 'red', lty = 'solid')
  legend('topright', legend = c('Full', 'K mode','J mode', 'I mode'),
         col = c('black', 'red', 'blue', 'green'),
         lwd = c(3,3,3,3), lty = c('solid', 'dashed', 'dashed', 'dashed'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white')
  legend('topleft', legend = c(''),
         title = 'Ovadnevaite et al., 2013', bty = 'n', inset = 0.01, cex = leg.cex.l2)
  
  dev.off()
}



# plot P: Ovadnevaite split, modes ----
if(plotP) {
  postscript(paste(outDir,'ssemis_params_plotP_ovadnevaite_split_mode.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  
  yVals_OV13 = array(0.0, dim = c(4, length(rVals)))
  yVals_OV13[1,] = dFdlogD_OV14(rVals, ReHw, 1:5)
  yVals_OV13[2, ] = dFdlogD_OV14(rVals, ReHw, 1:2)
  yVals_OV13[3, ] = dFdlogD_OV14(rVals, ReHw, 3:4)
  yVals_OV13[4, ] = dFdlogD_OV14(rVals, ReHw, 5:5)
  
  plot(log10(rVals), log10(yVals_OV13[1,]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals), log10(yVals_OV13[2,]), 
        lwd = lwdDD, col = 'green', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV13[2,]), 
        lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[3,]), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV13[3,]), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[4,]), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV13[4,]), 
        lwd = 1, col = 'red', lty = 'solid')
  legend('topright', legend = c('Full', 'K mode','J mode', 'I mode'),
         col = c('black', 'red', 'blue', 'green'),
         lwd = c(3,3,3,3), lty = c('solid', 'dashed', 'dashed', 'dashed'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white')
  legend('topleft', legend = c(''),
         title = 'Ovadnevaite et al., 2013', bty = 'n', inset = 0.01, cex = leg.cex.l2)
  
  dev.off()
}



# plot U: overview all three funs ----
if(plotU) {
  postscript(paste(outDir,'ssemis_params_plotU_overview.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  vw = 1.34 * 10^(-6)
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  tmpSST = 283
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwdMain,
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'cyan',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(1, at = (-2):2, labels = c('','','','',expression('10'^2)),
       lwd = 0.5)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  axis(2, at = 1:7, 
       labels = c(expression('10'^1),expression('10'^2),'','','','', expression('10'^7)),
       lwd = 0.5)
  lines(log10(rVals), log10(yVals_SP13), lwd = lwdMain, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwdMain, col = 'darkviolet')
  legend('bottomleft', legend = c('GO03', 'SP13','OV14'),
         col = c('cyan', 'orange', 'darkviolet'),
         lwd = c(3,3,3), cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = expression('u'[10]~'= 8 m/s'))
  
  dev.off()
}


# plot V: overview all three funs, high wind speed ----
if(plotV) {
  postscript(paste(outDir,'ssemis_params_plotV_overview_highWind.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  vw = 1.34 * 10^(-6)
  u10 = 15 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  tmpSST = 283
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  
  yVals_SP13 = rep(0.0, length(rVals))
  rValsLong = append(rVals, 11:30)
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  yVals_SP13 = append(yVals_SP13, rep(0.0, length(rValsLong) - length(rVals)))
  yVals_SP13[rValsLong > rMax_wet] = pmax(dFdR_SM93(rValsLong[rValsLong > rMax_wet]), yVals_SP13[rValsLong > rMax_wet])
  
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwdMain,
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'cyan',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(1, at = (-2):2, labels = c('','','','',expression('10'^2)),
       lwd = 0.5)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  axis(2, at = 1:7, 
       labels = c(expression('10'^1),expression('10'^2),'','','','', expression('10'^7)),
       lwd = 0.5)
  lines(log10(rValsLong), log10(yVals_SP13), lwd = lwdMain, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwdMain, col = 'darkviolet')
  legend('bottomleft', legend = c('GO03', 'SP13','OV14'),
         col = c('cyan', 'orange', 'darkviolet'),
         lwd = c(3,3,3), cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = expression('u'[10]~'= 15 m/s'))
  
  dev.off()
}


# plot W: overview all three funs, low wind speed ----
if(plotW) {
  postscript(paste(outDir,'ssemis_params_plotW_overview_lowWind.eps', sep = '/'), paper='special', width=myWidth, height=myHeight,horizontal=FALSE)
  par(mar=c(3.5,3.8,0.5,0.1)+0.1, mgp = c(2.2,1,0))
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  vw = 1.34 * 10^(-6)
  u10 = 2.4 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  Re = 3.1 * 10^6
  Re = 340494.1
  
  tmpSST = 283
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwdMain,
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'cyan',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(1, at = (-2):2, labels = c('','','','',expression('10'^2)),
       lwd = 0.5)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  axis(2, at = 1:7, 
       labels = c(expression('10'^1),expression('10'^2),'','','','', expression('10'^7)),
       lwd = 0.5)
  lines(log10(rVals), log10(yVals_SP13), lwd = lwdMain, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwdMain, col = 'darkviolet')
  legend('topright', legend = c('GO03', 'SP13','OV14'),
         col = c('cyan', 'orange', 'darkviolet'),
         lwd = c(3,3,3), cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = expression('u'[10]~'= 2.4 m/s'))
  
  dev.off()
}


# plot X: all split ----
if(plotX) {
  postscript(paste(outDir,'ssemis_params_plotX_all_split.eps', sep = '/'), 
             paper='special', width=12, height=3.5,horizontal=FALSE)
  par(mar=c(2.0,4.2,0.1,2.0)+0.1, mgp = c(2.5,1,0))
  
  vTop=0.01
  vBot=0.01
  hInt=0.07
  hLeft=0.005
  hRight=0.005
  hWidth=(1-hLeft-hRight)/3
  split.screen(rbind(c(hLeft,hLeft+hWidth+hInt*2/3,vBot, 1-vTop),
                     c(hLeft+hWidth-hInt*1/3,hLeft+2*hWidth+hInt*1/3,vBot, 1-vTop),
                     c(hLeft+2*hWidth-hInt*2/3,1-hRight,vBot, 1-vTop)))
  
  lwdMain = 5
  lwdDD = 5
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  
  screen(1)
  
  yVals_GO03 = array(0.0, dim = c(3, length(rVals)))
  yVals_GO03[1,] = dFdR_GO03(rVals)
  yVals_GO03[2, ] = dFdR_GO03_J(rVals)
  yVals_GO03[3, ] = dFdR_GO03_K(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[1,rVals>0.06]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = '',
       # xlab = expression('r'[80]~'['*mu*'m]'), 
       ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       cex.lab = 1.6, font.lab = 1)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
        lwd = 1, col = 'red', lty = 'solid')
  
  mtext('GO03', 3, line = -1.5, font = 2, cex = 1.5)
  
  screen(2)
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = '', ylab = '',
       # xlab = expression('r'[80]~'['*mu*'m]'), 
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  # axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
        lwd = lwdDD, col = 'green', lty = 'dashed')
  lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
        lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
        lwd = 1, col = 'red', lty = 'solid')
  
  mtext('SP13', 3, line = -1.5, font = 2, cex = 1.5)
  
  screen(3)
  yVals_OV13 = array(0.0, dim = c(4, length(rVals)))
  yVals_OV13[1,] = dFdlogD_OV14(rVals, ReHw, 1:5)
  yVals_OV13[2, ] = dFdlogD_OV14(rVals, ReHw, 1:2)
  yVals_OV13[3, ] = dFdlogD_OV14(rVals, ReHw, 3:4)
  yVals_OV13[4, ] = dFdlogD_OV14(rVals, ReHw, 5:5)
  
  plot(log10(rVals), log10(yVals_OV13[1,]), 
       type = 'l', lwd = lwdMain, 
       axes = F, 
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = '', ylab = '',
       # xlab = expression('r'[80]~'['*mu*'m]'), 
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       cex.lab = 1.6, font.lab = 1)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  axis(4, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  lines(log10(rVals), log10(yVals_OV13[2,]), 
        lwd = lwdDD, col = 'green', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV13[2,]), 
        lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[3,]), 
        lwd = lwdDD, col = 'blue', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV13[3,]), 
        lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[4,]), 
        lwd = lwdDD, col = 'red', lty = 'dashed')
  lines(log10(rVals), log10(yVals_OV13[4,]), 
        lwd = 1, col = 'red', lty = 'solid')
  
  mtext('OV14', 3, line = -1.5, font = 2, cex = 1.5)
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot Xpub: all split ----
if(plotXpub) {
  # postscript(paste(outDir,'fig03_ssemis_params_plotX_all_split.eps', sep = '/'), 
  #            paper='special', width=8, height=2.5,horizontal=FALSE)
  pdf(paste(outDir,'fig03_ssemis_params_plotX_all_split.pdf', sep = '/'), 
            paper='special', width=8, height=2.5)
  par(mar=c(2.3,2.8,0.2,1.2)+0.1, mgp = c(1.6,0.5,0))
  
  vTop=0.01
  vBot=0.01
  hInt=0.07
  hLeft=0.005
  hRight=0.005
  hWidth=(1-hLeft-hRight)/3
  split.screen(rbind(c(hLeft,hLeft+hWidth+hInt*2/3,vBot, 1-vTop),
                     c(hLeft+hWidth-hInt*1/3,hLeft+2*hWidth+hInt*1/3,vBot, 1-vTop),
                     c(hLeft+2*hWidth-hInt*2/3,1-hRight,vBot, 1-vTop)))
  
  lwdMain = 5
  lwdDD = 5
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  
  screen(1)
  
  yVals_GO03 = array(0.0, dim = c(3, length(rVals)))
  yVals_GO03[1,] = dFdR_GO03(rVals)
  yVals_GO03[2, ] = dFdR_GO03_J(rVals)
  yVals_GO03[3, ] = dFdR_GO03_K(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[1,rVals>0.06]), 
       type = 'l', lwd = lwd.main.pub, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('D'['dry']~'['*mu*'m]'), 
       ylab = expression('dF/dlog(D'['dry']*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       font.lab = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = cex.lab.pub, cex.axis = cex.axis.pub, lwd = 1)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)),
       cex.lab = cex.lab.pub, cex.axis = cex.axis.pub, lwd = 1)
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
        lwd = lwd.main.pub+0.2, col = 'blue', lty = 'dashed')
#   lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
#         lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
        lwd = lwd.main.pub+0.2, col = 'red', lty = 'dashed')
#   lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
#         lwd = 1, col = 'red', lty = 'solid')
  
  title('GO03', line = -1, font = 2, cex.main = cex.main.pub)
  
  
  screen(2)
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwd.main.pub, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('D'['dry']~'['*mu*'m]'), 
       ylab = '',
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       font.lab = 2, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  # axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
        lwd = lwd.main.pub+0.2, col = 'green', lty = 'dashed')
#   lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
#         lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
        lwd = lwd.main.pub+0.2, col = 'blue', lty = 'dashed')
#   lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
#         lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
        lwd = lwd.main.pub+0.2, col = 'red', lty = 'dashed')
#   lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
#         lwd = 1, col = 'red', lty = 'solid')
  
  title('SP13', line = -1, font = 2, cex.main = cex.main.pub)
  
  screen(3)
  yVals_OV13 = array(0.0, dim = c(4, length(rVals)))
  yVals_OV13[1,] = dFdlogD_OV14(rVals, ReHw, 1:5)
  yVals_OV13[2, ] = dFdlogD_OV14(rVals, ReHw, 1:2)
  yVals_OV13[3, ] = dFdlogD_OV14(rVals, ReHw, 3:4)
  yVals_OV13[4, ] = dFdlogD_OV14(rVals, ReHw, 5:5)
  
  plot(log10(rVals), log10(yVals_OV13[1,]), 
       type = 'l', lwd = lwd.main.pub, 
       axes = F, 
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('D'['dry']~'['*mu*'m]'), 
       ylab = '',
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       font.lab = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(4, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  lines(log10(rVals), log10(yVals_OV13[2,]), 
        lwd = lwd.main.pub, col = 'green', lty = 'dashed')
#   lines(log10(rVals), log10(yVals_OV13[2,]), 
#         lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[3,]), 
        lwd = lwd.main.pub+0.2, col = 'blue', lty = 'dashed')
#   lines(log10(rVals), log10(yVals_OV13[3,]), 
#         lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[4,]), 
        lwd = lwd.main.pub+0.2, col = 'red', lty = 'dashed')
#   lines(log10(rVals), log10(yVals_OV13[4,]), 
#         lwd = 1, col = 'red', lty = 'solid')
  
  title('OV14', line = -1, font = 2, cex.main = cex.main.pub)
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot XpubB: all split ----
if(plotXpubB) {
  # postscript(paste(outDir,'fig03_ssemis_params_plotX_all_split.eps', sep = '/'), 
  #            paper='special', width=8, height=2.2,horizontal=FALSE)
  pdf(paste(outDir,'fig03_ssemis_params_plotX_all_split.pdf', sep = '/'), 
      paper='special', width=8, height=2.2)
  par(mar=c(2.3,2.8,0.2,1.2)+0.1, mgp = c(1.6,0.5,0))
  
  vTop=0.01
  vBot=0.01
  hInt=0.07
  hLeft=0.005
  hRight=0.005
  hWidth=(1-hLeft-hRight)/3
  split.screen(rbind(c(hLeft,hLeft+hWidth+hInt*2/3,vBot, 1-vTop),
                     c(hLeft+hWidth-hInt*1/3,hLeft+2*hWidth+hInt*1/3,vBot, 1-vTop),
                     c(hLeft+2*hWidth-hInt*2/3,1-hRight,vBot, 1-vTop)))
  
  lwdMain = 5
  lwdDD = 5
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  
  screen(1)
  
  yVals_GO03 = array(0.0, dim = c(3, length(rVals)))
  yVals_GO03[1,] = dFdR_GO03(rVals)
  yVals_GO03[2, ] = dFdR_GO03_J(rVals)
  yVals_GO03[3, ] = dFdR_GO03_K(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[1,rVals>0.06]), 
       type = 'l', lwd = lwd.main.pub, 
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('D'['dry']~'['*mu*'m]'), 
       ylab = expression('dF/dlog(D'['dry']*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       font.lab = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(1, at = (-2):2, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1),expression('10'^2)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(2, at = 1+(0:3)*2, labels = c(expression('10'^1),expression('10'^3),expression('10'^5),expression('10'^7)), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(2, at = 1:7, labels = rep('', 7), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  lines(log10(c(rVals[rVals>0.06][1],rVals[rVals>0.06])), 
        log10(c(0.1,yVals_GO03[2,rVals>0.06])), 
        lwd = lwd.main.pub+0.2, col = 'blue', lty = 'dashed')
  #   lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[2,rVals>0.06]), 
  #         lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(c(rVals[rVals>0.06],rVals[rVals>0.06][length(rVals[rVals>0.06])])),
        log10(c(yVals_GO03[3,rVals>0.06],0.1)), 
        lwd = lwd.main.pub+0.2, col = 'red', lty = 'dashed')
  #   lines(log10(rVals[rVals>0.06]), log10(yVals_GO03[3,rVals>0.06]), 
  #         lwd = 1, col = 'red', lty = 'solid')
  
  title('GO03', line = -1, font = 2, cex.main = cex.main.pub)
  
  
  screen(2)
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwd.main.pub, 
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('D'['dry']~'['*mu*'m]'), 
       ylab = '',
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       font.lab = 2, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(1, at = (-2):2, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1),expression('10'^2)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  # axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
        lwd = lwd.main.pub+0.2, col = 'green', lty = 'dashed')
  #   lines(log10(rVals[c(32,iPosIx[iPosIx>31])]), append(c(-10,-10), log10(yVals_SP13[iPosIy[iPosIy>31]]), after = 1), 
  #         lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
        lwd = lwd.main.pub+0.2, col = 'blue', lty = 'dashed')
  #   lines(log10(rVals[iPosJx]), append(c(-10,-10), log10(yVals_SP13[iPosJy]), after = 1), 
  #         lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
        lwd = lwd.main.pub+0.2, col = 'red', lty = 'dashed')
  #   lines(log10(rVals[iPosKx]), append(c(-10,-10), log10(yVals_SP13[iPosKy]), after = 1), 
  #         lwd = 1, col = 'red', lty = 'solid')
  
  title('SP13', line = -1, font = 2, cex.main = cex.main.pub)
  
  screen(3)
  yVals_OV13 = array(0.0, dim = c(4, length(rVals)))
  yVals_OV13[1,] = dFdlogD_OV14(rVals, ReHw, 1:5)
  yVals_OV13[2, ] = dFdlogD_OV14(rVals, ReHw, 1:2)
  yVals_OV13[3, ] = dFdlogD_OV14(rVals, ReHw, 3:4)
  yVals_OV13[4, ] = dFdlogD_OV14(rVals, ReHw, 5:5)
  
  plot(log10(rVals), log10(yVals_OV13[1,]), 
       type = 'l', lwd = lwd.main.pub, 
       axes = F, 
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('D'['dry']~'['*mu*'m]'), 
       ylab = '',
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       font.lab = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(1, at = (-2):2, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1),expression('10'^2)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(4, at = 1+(0:3)*2, labels = c(expression('10'^1),expression('10'^3),expression('10'^5),expression('10'^7)), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(4, at = 1:7, labels = rep('', 7), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  lines(log10(c(rVals[1],rVals)), 
        log10(c(0.1,yVals_OV13[2,])), 
        lwd = lwd.main.pub, col = 'green', lty = 'dashed')
  #   lines(log10(rVals), log10(yVals_OV13[2,]), 
  #         lwd = 1, col = 'green', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[3,]), 
        lwd = lwd.main.pub+0.2, col = 'blue', lty = 'dashed')
  #   lines(log10(rVals), log10(yVals_OV13[3,]), 
  #         lwd = 1, col = 'blue', lty = 'solid')
  lines(log10(rVals), log10(yVals_OV13[4,]), 
        lwd = lwd.main.pub+0.2, col = 'red', lty = 'dashed')
  #   lines(log10(rVals), log10(yVals_OV13[4,]), 
  #         lwd = 1, col = 'red', lty = 'solid')
  
  title('OV14', line = -1, font = 2, cex.main = cex.main.pub)
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot Y: like all split ----
if(plotY) {
  postscript(paste(outDir,'fig03_ssemis_params_plotY_like_all_split.eps', sep = '/'), 
             paper='special', width=12, height=3.5,horizontal=FALSE)
  par(mar=c(2.0,4.2,0.1,2.0)+0.1, mgp = c(2.5,1,0))
  
  vTop=0.01
  vBot=0.01
  hInt=0.07
  hLeft=0.005
  hRight=0.005
  hWidth=(1-hLeft-hRight)/3
  split.screen(rbind(c(hLeft,hLeft+hWidth+hInt*2/3,vBot, 1-vTop),
                     c(hLeft+hWidth-hInt*1/3,hLeft+2*hWidth+hInt*1/3,vBot, 1-vTop),
                     c(hLeft+2*hWidth-hInt*2/3,1-hRight,vBot, 1-vTop)))
  
  lwdMain = 5
  lwdDD = 5
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  
  screen(1)
  
  yVals_GO03= dFdR_GO03(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       # xlab = expression('r'[80]~'['*mu*'m]'), 
       ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       cex.lab = 1.6, font.lab = 1)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  
  
  screen(2)
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = '', ylab = '',
       # xlab = expression('r'[80]~'['*mu*'m]'), 
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  # axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  
  
  screen(3)
  yVals_OV13 = dFdlogD_OV14(rVals, ReHw, 1:5)
  
  plot(log10(rVals), log10(yVals_OV13), 
       type = 'l', lwd = lwdMain, 
       axes = F, 
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = '', ylab = '',
       # xlab = expression('r'[80]~'['*mu*'m]'), 
       # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       col = 'black',
       cex.lab = 1.6, font.lab = 1)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  axis(4, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)),
       cex.lab = 1.4, cex.axis = 1.5, lwd = 2)
  
  
  close.screen(all.screens = TRUE)
  dev.off()
}


# plot Zpub: overview plot with Gong, Spada and Ovadnevaite for different wind speeds ----
if(plotZpub) {
  # postscript(paste(outDir,'fig02_ssemis_params_plotZ_wind_speed.eps', sep = '/'), 
  #            paper='special', width=8, height=2.2,horizontal=FALSE)
  pdf(paste(outDir,'fig02_ssemis_params_plotZ_wind_speed.pdf', sep = '/'), 
            paper='special', width=8, height=2.2)
  par(mar=c(2.3,2.8,0.2,1.2)+0.1, mgp = c(1.6,0.5,0))
  
  vTop=0.01
  vBot=0.01
  hInt=0.07
  hLeft=0.005
  hRight=0.005
  hWidth=(1-hLeft-hRight)/3
  split.screen(rbind(c(hLeft,hLeft+hWidth+hInt*2/3,vBot, 1-vTop),
                     c(hLeft+hWidth-hInt*1/3,hLeft+2*hWidth+hInt*1/3,vBot, 1-vTop),
                     c(hLeft+2*hWidth-hInt*2/3,1-hRight,vBot, 1-vTop)))
  
  lwdMain = 5
  lwdDD = 5
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  
  
  
  screen(1)
  
  u10 = 2.4 # m/s
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwd.main.pub,
       axes = F,
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('D'['dry']~'['*mu*'m]'), ylab = expression('dF/dlog(D'['dry']*')'~'[m'^-2*'s'^-1*']'), col = 'cyan',
       font.lab = 2, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  title(expression('u'[10]~'= 2.4 m/s'), line = -1, cex.main = cex.main.pub)
  axis(1, at = (-2):2, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1),expression('10'^2)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(2, at = 1+(0:3)*2, labels = c(expression('10'^1),expression('10'^3),expression('10'^5),expression('10'^7)), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(2, at = 1:7, labels = rep('', 7), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  lines(log10(rVals), log10(yVals_SP13), lwd = lwd.main.pub, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwd.main.pub, col = 'darkviolet')
  # legend('topright', legend = c('GO03', 'SP13','OV14'),
  #        col = c('cyan', 'orange', 'darkviolet'),
  #        lwd = c(3,3,3), cex = leg.cex.l1, inset = 0.02, bg = 'white',
  #        title = expression('u'[10]~'= 2.4 m/s'))
  
  
  
  screen(2)
  
  u10 = 8 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwd.main.pub,
       axes = F, col = 'cyan',
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('D'['dry']~'['*mu*'m]'), ylab = '', # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       font.lab = 2, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  title(expression('u'[10]~'= 8 m/s'), line = -1, cex.main = cex.main.pub)
  axis(1, at = (-2):2, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1),expression('10'^2)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  lines(log10(rVals), log10(yVals_SP13), lwd = lwd.main.pub, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwd.main.pub, col = 'darkviolet')
  # legend('bottomleft', legend = c('GO03', 'SP13','OV14'),
  #        col = c('cyan', 'orange', 'darkviolet'),
  #        lwd = c(3,3,3), cex = leg.cex.l1, inset = 0.02, bg = 'white',
  #        title = expression('u'[10]~'= 8 m/s'))
  
  
  
  screen(3)
  
  u10 = 15 # m/s
  
  ReHw = sqrt(Cd) * u10 * Hs / vw
  yVals_OV14 = dFdlogD_OV14(rVals, ReHw)
  yVals_GO03 = dFdR_GO03(rVals)
  yVals_SP13 = rep(0.0, length(rVals))
  rValsLong = append(rVals, 11:30)
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  yVals_SP13 = append(yVals_SP13, rep(0.0, length(rValsLong) - length(rVals)))
  yVals_SP13[rValsLong > rMax_wet] = pmax(dFdR_SM93(rValsLong[rValsLong > rMax_wet]), yVals_SP13[rValsLong > rMax_wet])
  
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = lwd.main.pub,
       axes = F, col = 'cyan',
       ylim = c(1, 7), xlim = c(-2,2), 
       xlab = expression('D'['dry']~'['*mu*'m]'), ylab = '', # ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), 
       font.lab = 2, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  title(expression('              u'[10]~'= 15 m/s'), line = -1, cex.main = cex.main.pub)
  axis(1, at = (-2):2, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1),expression('10'^2)),
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(4, at = 1+(0:3)*2, labels = c(expression('10'^1),expression('10'^3),expression('10'^5),expression('10'^7)), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  axis(4, at = 1:7, labels = rep('', 7), 
       lwd = 1, cex.lab = cex.lab.pub, cex.axis = cex.axis.pub)
  lines(log10(rValsLong), log10(yVals_SP13), lwd = lwd.main.pub, col = 'orange')
  lines(log10(rVals), log10(yVals_OV14), lwd = lwd.main.pub, col = 'darkviolet')
  legend('bottomleft', legend = c('GO03', 'SP13','OV14'),
         col = c('cyan', 'orange', 'darkviolet'), 
         lwd = c(3,3,3), cex = 0.8, inset = 0.02, bg = 'white')
         # title = expression('u'[10]~'= 15 m/s')
  
  close.screen(all.screens = TRUE)
  dev.off()
}



# plot Qpub: overview plot with Gong and Spada for different salinities ----
if(plotQpub) {
  # postscript(paste(outDir,'figS01_ssemis_params_plotQ_salinity.eps', sep = '/'), 
  #            paper='special', width=7, height=2.5,horizontal=FALSE)
  pdf(paste(outDir,'figS01_ssemis_params_plotQ_salinity.pdf', sep = '/'), 
             paper='special', width=7, height=2.5)
  par(mar=c(2.3,2.8,0.2,1.2)+0.1, mgp = c(1.5,0.4,0))
  
  vTop=0.01
  vBot=0.01
  hInt=0.07
  hLeft=0.005
  hRight=0.005
  hWidth=(1-hLeft-hRight)/2
  split.screen(rbind(c(hLeft,hLeft+hWidth+hInt*2/3,vBot, 1-vTop),
                     c(hLeft+hWidth-hInt*2/3,1-hRight,vBot, 1-vTop)))
  
  lwdMain = 5
  lwdDD = 5
  
  # parameters
  Cd = 2.15 * 10^(-3)
  Hs = 1.23
  tmpSST = 283
  tmpSAL = 35
  vw = SWkviscosity(tmpSST,'K', tmpSAL, 'g/kg')
  
  
  
  screen(1)
  u10 = 8 # m/s
  
  yVals_GO03 = dFdR_GO03(rVals)
  
  plot(log10(rVals[rVals>0.06]), log10(yVals_GO03[rVals>0.06]), 
       type = 'l', lwd = 4, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = expression('dF/dlog(r'[80]*')'~'[m'^-2*'s'^-1*']'), col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  axis(2, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  lines(log10(rVals[rVals>0.06]), log10(37/35*yVals_GO03[rVals>0.06]), 
        lwd = lwdDD, col = '#4CCCFF', lty = 'dashed')
  lines(log10(rVals[rVals>0.06]), log10(37/35*yVals_GO03[rVals>0.06]), lwd = 1, col = '#4CCCFF')
  lines(log10(rVals[rVals>0.06]), log10(10/35*yVals_GO03[rVals>0.06]), 
        lwd = lwdDD, col = '#0098D4', lty = 'dotted')
  lines(log10(rVals[rVals>0.06]), log10(10/35*yVals_GO03[rVals>0.06]), lwd = 1, col = '#0098D4')
  # legend('bottomleft', legend = c('37 g/kg', '35 g/kg','10 g/kg'),
  #        col = c('#4CCCFF', 'black', '#0098D4'),
  #        lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
  #        cex = leg.cex.l1, inset = 0.02, bg = 'white',
  #        title = 'salinity')
  legend('topleft', legend = c(''),
         title = 'Gong, 2003', bty = 'n', cex = leg.cex.l2, inset = 0.02)
  
  
  
  screen(2)
  u10 = 8 # m/s
  tmpSST = 283
  
  yVals_SP13 = rep(0.0, length(rVals))
  yVals_SP13[c1] = dFdR_MA03_1(rVals[c1])
  yVals_SP13[c2] = dFdR_MA03_2(rVals[c2])
  yVals_SP13[c3] = dFdR_MA03_3(rVals[c3])
  yVals_SP13[c4] = dFdR_MO86(rVals[c4])
  
  plot(log10(rVals), log10(yVals_SP13), 
       type = 'l', lwd = lwdMain, 
       axes = F,
       ylim = c(3, 6), xlim = c(-2,1), 
       xlab = expression('r'[80]~'['*mu*'m]'), ylab = '', col = 'black',
       cex.lab = ax.cex.lab, font.lab = 2, cex.axis = ax.cex.ax)
  axis(1, at = (-2):1, labels = c(expression('10'^-2),expression('10'^-1),expression('10'^0),expression('10'^1)))
  lines(log10((37/35)^(1/3)*rVals), log10(yVals_SP13), 
        lwd = lwdDD, col = '#4CCCFF', lty = 'dashed')
  lines(log10((37/35)^(1/3)*rVals), log10(yVals_SP13), lwd = 1, col = '#4CCCFF')
  lines(log10((10/35)^(1/3)*rVals), log10(yVals_SP13), 
        lwd = lwdDD, col = '#0098D4', lty = 'dotted')
  lines(log10((10/35)^(1/3)*rVals), log10(yVals_SP13), lwd = 1, col = '#0098D4')
  legend('bottomleft', legend = c('37 g/kg', '35 g/kg','10 g/kg'),
         col = c('#4CCCFF', 'black', '#0098D4'),
         lwd = c(3,3,3), lty = c('dashed', 'solid', 'dotted'), 
         cex = leg.cex.l1, inset = 0.02, bg = 'white',
         title = 'salinity')
  legend('topright', legend = c(''), inset = 0.02, 
         title = 'Spada et al., 2013', bty = 'n', cex = leg.cex.l2)
  axis(4, at = 3:6, labels = c(expression('10'^3),expression('10'^4),expression('10'^5),expression('10'^6)))
  
  close.screen(all.screens = TRUE)
  dev.off()
}



# convert with: convert -density 400% ssemis_params_compare_logPlot.eps -background white -alpha off -depth 4 -strip ssemis_params_compare_logPlot.png